--[[
*******************************************************************

   LuaPlayer/PGE script translator
   -------------------------------
  Scripted using the PGE Lua API,this header script can be run
 with dofile(). Then call method System.LP2PGE() to allow the
 pseudo-LuaPlayer 0.2 API to be used in PGE Lua scripts.

  This can help to 'port' existing LuaPlayer scripts to PGE Lua.

  Some scripts work better than others. Fonts and transparency
 effects do not translate well.

*******************************************************************

  Notes/Caveats
  -------------

  System.md5sum() returns a dummy md5.

  screen.waitVblankStart() is approximate
     To Vsync page flipping, replace
       screen.waitVblankStart() ; screen.flip()
     with
       screen.flip(true)

  Image.load() only loads .PNG files

  pge.texture.toram() is unpredictable. Introducing a short
   pge.delay(), and tuning the garbage collector seems to help.

  pge.texture.tovram() is unpredictable.
   ( Automatic Lua memory management may not work in VRAM ?)

  Image:fontPrint() and screen:fontPrint()
     both draw an opaque black background. 
     An optional extra parameter can be added to specify the color.
     e.g.  screen:fontPrint(Font,x,y,str,textcolor,BACKGROUND_Color)
     (background alpha is always 255)

  The fontPrint mapping between LuaPlayer & PGE is very weak.
    Size and resolution are only loose approximations,and
    rendering is slow.

  VERA.TTF is embedded in this script for use in
       Font.createMonoSpaced() and Font.createProportional()
   (The copyright notice can be found in the TRUETYPE FONTS
     section in System.VERA).

  Font:setCharSize(width,height,dpiX,dpiY)
   is implemented as Font:setPixelSizes(width,height)

  image1:blit(x,y,image1,...), and image1:blit(x,y,screen,...)
     are unsupported.

  Color screen:pixel(x,y) is not supported. returns a default color

  The alpha bool in Image:blit() and screen:blit() is unsupported.

  blitting sub-images is unpredictable. Small images sometimes get
   scrambled.

  Alpha in colors is unpredictable. Usually doesn't work.

  Sound.load() only loads .WAV files. Some .wav types that work in
   LuaPlayer don't work in PGE Lua.

  GU methods are not supported
  SIO methods are not supported
  Battery methods are not supported.
  System.powerTick() is not supported
  IRDA methods are not supported.
  Music and Soundsystem methods are not supported.
  WLAN methods are not yet supported

  System.Quit() is supported.

  ( Apart from System.Quit(), the extra functions of the 
    LuaPlayer 0.2 extensions, Mod3 and HM, are not supported)

  To compare Colors, use the bool function
    Color.equal(colr1,colr2)
   to replace 
    colr1==colr2


  For fast graphics replace LuaPlayer graphics function calls
   with PGE script segments

  Use System.pgegfx() to clear VRAM, before any PGE script segment
    that uses the pge.texture or pge.gfx modules, or after any
    LuaPlayer graphics function calls.

  An Image object has a PGE texture as a property. It can be
    indexed using Image.PGETexture 
  Likewise: Timer.PGETimer,
            Color.PGEColor,
            Font.PGEFont

*******************************************************************
]]--


--** Bindings **--

--SYSTEM--

System = {}

System.LP2PGE = function()

  --System constants
  System.SCRW    = 480           --Screen width
  System.SCRH    = 272           --Screen height
  System.TMRES   = 1000          --Timer ticks/sec
  System.NEWSTR  = ""            --empty string
  System.FDV     = "/"           --file path divider
  System.FPWDF   = 8             --default TTF character width
  System.FPHDF   = 12            --default TTF character height
  System.FWDMX   = 24            --maximum TTF character width
  System.FHGMX   = 32            --maximum TTF character height
  System.TTFONT  = "VERA.TTF"    --TTF to load for Font creation
  System.FCHSPC  = 13            --Font Character spacing constant
  System.FHGFAC  = 26/25         --Font height adjustment factor
  System.FWDFC0  = 1.021         --Font Text width trimmer
  System.FBHGT   = 52            --Font reference height
  System.FBWID   = 32            --Font reference width
  System.FPROPR  = 1             --System proportional id
  System.FMSPAC  = 2             --System monospace id
  System.F_LOAD  = 3             --TTF id
  System.VOLTAGE = 3.6           --nominal battery voltage
  System.DOTDOT  = ".."          --parent folder identifier
  System.DRIVE1  = "ms0:"        --drive identifier
  System.FDV     = "/"           --filepath divider

  System.RPTH    = System.DRIVE1..System.FDV
  System.FBCOL   = pge.gfx.createcolor(0,0,0,255)  --Font background
  System.SPXDF   = pge.gfx.createcolor(255,0,0,255)
  System.DOTDIR  = {name=".",directory=true,size=0}
  System.DDOTDIR = {name=System.DOTDOT,directory=true,size=0}
 
  System.md5blk = ""            --md5 default string
  for i = 1,16 do
    System.md5blk = System.md5blk..string.byte(252)
  end

  --parameter types
  System.NUMBER = type(0)                --number type
  System.STRING = type(System.NEWSTR)    --string type
  System.TABLE  = type(System)           --table type
  System.BOOL   = type(true)             --Boolean type

  --System variables
  System.dpath = System.NEWSTR      --previous directory path
  System.flist = {}                 --file list
  System.quickImage = nil           --gfx enabled Image
  System.EbPath = pge.dir.getcwd()  --PGELua Eboot folder
  System.fpath = System.NEWSTR      --file path

--utilities

  System.filePath = function(fstr)
  --return normalised path string for file string (fstr)
  --file string may include drive id and directory id
  --defaults are current drive and root directory
 
    if type(fstr)~=System.STRING then fstr = System.NEWSTR end

    if string.find(fstr,System.FDV) then
      if string.find(string.lower(fstr),System.RPTH) then
        return fstr
      else
        if string.sub(fstr,1,1)==System.FDV then
          return System.DRIVE1..fstr
        end
      end
    end
    return pge.dir.getcwd()..System.FDV..fstr 
  end
  
  --methods
  
  System.currentDirectory=function(path)
    System.dpath = pge.dir.getcwd()
    if string.lower(System.dpath)==System.DRIVE1 then
      System.dpath = System.RPTH..System.NEWSTR
    end
    if path and type(path)==System.STRING and path~=System.NEWSTR then
      path = System.filePath(path)
      if string.sub(path,-2)==System.DOTDOT then
        pge.dir.chdir(System.DOTDOT)
        path = pge.dir.getcwd()
      end
      if pge.dir.exists(path) then pge.dir.chdir(path) end
    end
    return System.dpath
  end
  
  System.listDirectory = function(path)
    if (not path) or (type(path)~=System.STRING) or
       (not pge.dir.exists(path)) then
      path = pge.dir.getcwd()
      if string.lower(System.dpath)==System.DRIVE1 then
        System.dpath = System.RPTH..System.NEWSTR
      end
    else
      path = string.lower(System.filePath(path))
    end
    System.flist = {}
    System.dir = pge.dir.open(path)
    if System.dir then
      System.flist = System.dir:read()
      System.dir:close()
      for index, entry in ipairs(System.flist) do 
        entry.directory = entry.dir
      end 
    end
    table.insert(System.flist,1,System.DOTDIR)
    if path~=System.DRIVE1 and path~=System.RPTH then
      table.insert(System.flist,2,System.DDOTDIR)
    end
    return System.flist
  end
  
  System.createDirectory = pge.dir.mkdir
  System.removeDirectory = pge.dir.rmdir
  System.removeFile = pge.file.remove
  
  pge.usb.init()
  System.usbDiskModeActivate = pge.usb.activate
  System.usbDiskModeDeactivate = pge.usb.deactivate

  System.sleep  = function(ms) return pge.delay(ms*1000) end
  System.md5sum = function() return System.md5blk end
  System.powerTick = function() end

  System.powerIsPowerOnline = function() return false end
  System.powerIsBatteryExist = function() return false end
  System.powerIsBatteryCharging = function() return false end
  System.powerGetBatteryChargingStatus = function() return 0 end
  System.powerIsLowBattery = function() return false end
  System.powerGetBatteryLifePercent = function() return 0 end
  System.powerGetBatteryLifeTime = function() return 0 end
  System.powerGetBatteryTemp = function() return 0 end
  System.powerGetBatteryVolt = function() return System.VOLTAGE end

  System.sioInit  = function(baudrate) end
  System.sioWrite = function(string) end
  System.sioRead  = function() return System.NEWSTR end

  System.irdaInit  = function() end 
  System.irdaWrite = function(string) end
  System.irdaRead  = function() return System.NEWSTR end

  System.getFreeMemory = pge.utils.freeram

--CONTROLS--

  Controls=
  {
     --methods
     read,         --read controls
     isctrl,       --control metatype test
  
     --properties
     pad,
  }

  --methods

  Controls.read = function()
    pge.controls.update()

    local ctrl = {} ; setmetatable(ctrl,{__index=Controls})
    ctrl.pad = {}
    ctrl.pad.select   = pge.controls.held(PGE_CTRL_SELECT)
    ctrl.pad.start    = pge.controls.held(PGE_CTRL_START)
    ctrl.pad.up       = pge.controls.held(PGE_CTRL_UP)
    ctrl.pad.down     = pge.controls.held(PGE_CTRL_DOWN)
    ctrl.pad.left     = pge.controls.held(PGE_CTRL_LEFT)
    ctrl.pad.right    = pge.controls.held(PGE_CTRL_RIGHT)
    ctrl.pad.l        = pge.controls.held(PGE_CTRL_LTRIGGER)
    ctrl.pad.r        = pge.controls.held(PGE_CTRL_RTRIGGER)
    ctrl.pad.triangle = pge.controls.held(PGE_CTRL_TRIANGLE)
    ctrl.pad.circle   = pge.controls.held(PGE_CTRL_CIRCLE)
    ctrl.pad.cross    = pge.controls.held(PGE_CTRL_CROSS)
    ctrl.pad.square   = pge.controls.held(PGE_CTRL_SQUARE)
  
    ctrl.pad.analogX  = pge.controls.analogx()
    ctrl.pad.analogY  = pge.controls.analogy()
  
    return ctrl
  end
  
  function Controls.isctrl(ctr)
    return type(ctr)==System.TABLE and ctr.pad and 
           type(ctr.pad)==System.TABLE
  end
  
  --metamethods
  
  function Controls:select()
    if Controls.isctrl(self) then return self.pad.select end
  end
  function Controls:start()
    if Controls.isctrl(self) then return self.pad.start end
  end
  function Controls:up()
    if Controls.isctrl(self) then return self.pad.up end
  end
  function Controls:down()
    if Controls.isctrl(self) then return self.pad.down end
  end
  function Controls:left()
    if Controls.isctrl(self) then return self.pad.left end
  end
  function Controls:right()
    if Controls.isctrl(self) then return self.pad.right end
  end
  function Controls:triangle()
    if Controls.isctrl(self) then return self.pad.triangle end
  end
  function Controls:circle()
    if Controls.isctrl(self) then return self.pad.circle end
  end
  function Controls:cross()
    if Controls.isctrl(self) then return self.pad.cross end
  end
  function Controls:square()
    if Controls.isctrl(self) then return self.pad.square end
  end
  function Controls:l()
    if Controls.isctrl(self) then return self.pad.l end
  end
  function Controls:r()
    if Controls.isctrl(self) then return self.pad.r end
  end
  function Controls:analogX()
    if Controls.isctrl(self) then return self.pad.analogX end
  end
  function Controls:analogY()
    if Controls.isctrl(self) then return self.pad.analogY end
  end


--TIMER

  Timer =
  {
     --methods
     new,

     --properties
     PGETimer,
     starttime,
     stoptime,
     resettime,
     deltatime,
     stopped,
     rst,
  }

  --methods

  Timer.new = function(time1)
    if not time1 or type(time1)~=System.NUMBER then time1 = 0 end
  
    local tmr = {} ; setmetatable(tmr,{__index=Timer})
  
    tmr.PGETimer  = pge.timer.create()
    tmr.starttime = math.floor(time1)
    tmr.stoptime  = tmr.starttime
    tmr.resettime = tmr.starttime
    tmr.deltatime = 0
    tmr.stopped   = true
    tmr.rst       = true

    return tmr
  end

  --metamethods

  function Timer:time()
  --Returns in milliseconds since the timer started/resumed.
  
    local tmr = self
  
    if not tmr.stopped then
      tmr.deltatime = math.floor(tmr.PGETimer:peekdelta()*System.TMRES)
    end
    return tmr.deltatime+tmr.starttime
  end
  
  function Timer:start()
  --Starts to tick the timer (incrementing by one every millisecond),
  -- or resumes to tick after being stopped.
  -- Returns the current time() value.
  
    local tmr = self
  
    if tmr.stopped then
      tmr.PGETimer:update()
      tmr.stopped = false
      tmr.starttime = tmr.stoptime
      return tmr.starttime
    else
      tmr.stoptime = tmr:time()
      if not tmr.rst then tmr.starttime = 0 end
      tmr.rst = false
      tmr.PGETimer:update()
      return tmr.stoptime
    end
  
  end
  
  function Timer:stop()
  --Stops the timer.
  --Returns the current time().
  --Subsequent time() calls return the value when stopped.
  --If the timer is stopped, this call is the same as time().
    local tmr = self
  
    tmr.stoptime = tmr:time()
    tmr.stopped = true
    return tmr.stoptime
  end
  
  function Timer:reset(time1)
  --Resets the timer to 0 by default or startTime in milliseconds
  -- and holds the timer. Returns the time before resetted to the
  -- new value.
    if not time1 or type(time1)~=System.NUMBER then time1 = 0 end
  
    local tmr = self
  
    tmr.resettime = tmr:stop()
    tmr.starttime = math.floor(time1)
    tmr.stoptime  = tmr.starttime
    tmr.deltatime = 0
    tmr.rst       = true
    tmr.stopped   = true

    return tmr.resettime
  end
  


--COLOURS--
  Color =
  {
     --methods
     new,
     equal,
  
     --properties
     PGEColor,
     ctab,
  }
  
  Color.new = function(r,g,b,a)
  --Creates a new color object with the specified RGBA values.
    if not r or type(r)~=System.NUMBER then r = 0 end
    if not g or type(g)~=System.NUMBER then g = 0 end
    if not b or type(b)~=System.NUMBER then b = 0 end
    if not a or type(a)~=System.NUMBER then a = 255 end
  
    local clr = {} ; setmetatable(clr,{__index=Color})
    clr.PGEColor = pge.gfx.createcolor(r,g,b,a)
    clr.ctab = {r=r,g=g,b=b,a=a}
    return clr
  end
  
  Color.equal = function(c1,c2)
    return c1.ctab.r==c2.ctab.r and
           c1.ctab.g==c2.ctab.g and
           c1.ctab.b==c2.ctab.b and
           c1.ctab.a==c2.ctab.a 
  end
  
  --metamethods
  function Color:colors() return self.ctab end
  

--TRUETYPE FONTS--

  System.VERA=
    "\0\1\0\0\0\16\1\0\0\4\0\0OS\47\50_*\0\0,\0\0\0VPCLT!?\14"
  .."\0\0\0\0\0\54cmap\0\0\0\0\3Xcvt \7\12\0\0\31\8\0\0"
  .."\2\48fpgmp(\22\0\0(T\0\0\0gasp\0\7\0\7\0\0\4\0\0\0\12glyf"
  .."\0\0(\0\0thdmx\51\50`\0\0\0\0\21Hheadم'\0\0\16\0"
  .."\0\0\54hhea\12?\3\0\0\8\0\0\0$hmtx\10ε`\0\0\0\0\0\4\52lo"
  .."ca\1\0\0\0\0\2\28maxp\6\7\0\0\0\0\0 name`\0\0\1\12"
  .."\0\0\29postn\93\0\0\52\0\0\2prep:\7\0\0!\56\0\0\7\27\0"
  .."\0\0\22\1\14\0\1\0\0\0\0\0\0\0:\0\0\0\1\0\0\0\0\0\1\0\24\0:\0"
  .."\1\0\0\0\0\0\2\0\5\0h\0\1\0\0\0\0\0\3\0\24\0:\0\1\0\0\0\0\0\4"
  .."\0\24\0:\0\1\0\0\0\0\0\5\0\12\0m\0\1\0\0\0\0\0\6\0\27\0R\0\1"
  .."\0\0\0\0\0\7\0\48\0\0\1\0\0\0\0\0\8\0\14\8u\0\1\0\0\0\0\0\11"
  .."\0\24\9\0\1\0\0\0\0\0\13\9\19\0y\0\3\0\1\4\9\0\0\0t\9\0\3\0"
  .."\1\4\9\0\1\0\48\10\24\0\3\0\1\4\9\0\2\0\10\10t\0\3\0\1\4\9\0"
  .."\3\0\48\10\24\0\3\0\1\4\9\0\4\0\48\10\24\0\3\0\1\4\9\0\5\0\24"
  .."\10~\0\3\0\1\4\9\0\6\0\54\10H\0\3\0\1\4\9\0\7\0`\11\16\0\3\0"
  .."\1\4\9\0\8\0\28\26\0\3\0\1\4\9\0\11\0\48\28\0\3\0\1\4\9\0\13"
  .."\18&\10Copyright (c) \50\48\48\51 by Bitstream, Inc\46 All "
  .."Rights Reserved\46Bitstream Vera Sans MonoBitstreamVeraSansM"
  .."ono\45RomanRelease \49\46\49\48Copyright (c) \50\48\48\51 by"
  .." Bitstream, Inc\46\13\10All Rights Reserved\46\13\10Bitstrea"
  .."m Vera is a trademark of Bitstream, Inc\46\13\10\13\10Permis"
  .."sion is hereby granted, free of charge, to any person obtain"
  .."ing a copy of the fonts accompanying this license (\34Fonts\34"
  ..") and associated documentation files (the \34Font Software\34"
  .."), to reproduce and distribute the Font Software, including "
  .."without limitation the rights to use, copy, merge, publish, "
  .."distribute, and\47or sell copies of the Font Software, and t"
  .."o permit persons to whom the Font Software is furnished to d"
  .."o so, subject to the following conditions:\13\10\13\10The ab"
  .."ove copyright and trademark notices and this permission noti"
  .."ce shall be included in all copies of one or more of the Fon"
  .."t Software typefaces\46\13\10\13\10The Font Software may be "
  System.VERA=System.VERA
  .."modified, altered, or added to, and in particular the design"
  .."s of glyphs or characters in the Fonts may be modified and a"
  .."dditional glyphs or characters may be added to the Fonts, on"
  .."ly if the fonts are renamed to names not containing either t"
  .."he words \34Bitstream\34 or the word \34Vera\34\46\13\10\13\10"
  .."This License becomes null and void to the extent applicable "
  .."to Fonts or Font Software that has been modified and is dist"
  .."ributed under the \34Bitstream Vera\34 names\46\13\10\13\10T"
  .."he Font Software may be sold as part of a larger software pa"
  .."ckage but no copy of one or more of the Font Software typefa"
  .."ces may be sold by itself\46\13\10\13\10THE FONT SOFTWARE IS"
  .." PROVIDED \34AS IS\34, WITHOUT WARRANTY OF ANY KIND, EXPRESS"
  .." OR IMPLIED, INCLUDING BUT NOT LIMITED TO ANY WARRANTIES OF "
  .."MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINF"
  .."RINGEMENT OF COPYRIGHT, PATENT, TRADEMARK, OR OTHER RIGHT\46"
  .." IN NO EVENT SHALL BITSTREAM OR THE GNOME FOUNDATION BE LIAB"
  .."LE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, INCLUDING ANY "
  .."GENERAL, SPECIAL, INDIRECT, INCIDENTAL, OR CONSEQUENTIAL DAM"
  .."AGES, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, A"
  .."RISING FROM, OUT OF THE USE OR INABILITY TO USE THE FONT SOF"
  .."TWARE OR FROM OTHER DEALINGS IN THE FONT SOFTWARE\46\13\10\13"
  .."\10Except as contained in this notice, the names of Gnome, t"
  .."he Gnome Foundation, and Bitstream Inc\46, shall not be used"
  .." in advertising or otherwise to promote the sale, use or oth"
  .."er dealings in this Font Software without prior written auth"
  .."orization from the Gnome Foundation or Bitstream Inc\46, res"
  .."pectively\46 For further information, contact: fonts at gnom"
  .."e dot org\46http:\47\47www\46bitstream\46com\0C\0o\0p\0y\0r\0"
  .."i\0g\0h\0t\0 \0(\0c\0)\0 \0\50\0\48\0\48\0\51\0 \0b\0y\0 \0B"
  .."\0i\0t\0s\0t\0r\0e\0a\0m\0,\0 \0I\0n\0c\0\46\0 \0A\0l\0l\0 \0"
  .."R\0i\0g\0h\0t\0s\0 \0R\0e\0s\0e\0r\0v\0e\0d\0\46\0B\0i\0t\0s"
  .."\0t\0r\0e\0a\0m\0 \0V\0e\0r\0a\0 \0S\0a\0n\0s\0 \0M\0o\0n\0o"
  System.VERA=System.VERA
  .."\0B\0i\0t\0s\0t\0r\0e\0a\0m\0V\0e\0r\0a\0S\0a\0n\0s\0M\0o\0n"
  .."\0o\0\45\0R\0o\0m\0a\0n\0R\0e\0l\0e\0a\0s\0e\0 \0\49\0\46\0\49"
  .."\0\48\0C\0o\0p\0y\0r\0i\0g\0h\0t\0 \0(\0c\0)\0 \0\50\0\48\0\48"
  .."\0\51\0 \0b\0y\0 \0B\0i\0t\0s\0t\0r\0e\0a\0m\0,\0 \0I\0n\0c\0"
  .."\46\0\13\0\10\0A\0l\0l\0 \0R\0i\0g\0h\0t\0s\0 \0R\0e\0s\0e\0"
  .."r\0v\0e\0d\0\46\0\13\0\10\0B\0i\0t\0s\0t\0r\0e\0a\0m\0 \0V\0"
  .."e\0r\0a\0 \0i\0s\0 \0a\0 \0t\0r\0a\0d\0e\0m\0a\0r\0k\0 \0o\0"
  .."f\0 \0B\0i\0t\0s\0t\0r\0e\0a\0m\0,\0 \0I\0n\0c\0\46\0\13\0\10"
  .."\0\13\0\10\0P\0e\0r\0m\0i\0s\0s\0i\0o\0n\0 \0i\0s\0 \0h\0e\0"
  .."r\0e\0b\0y\0 \0g\0r\0a\0n\0t\0e\0d\0,\0 \0f\0r\0e\0e\0 \0o\0"
  .."f\0 \0c\0h\0a\0r\0g\0e\0,\0 \0t\0o\0 \0a\0n\0y\0 \0p\0e\0r\0"
  .."s\0o\0n\0 \0o\0b\0t\0a\0i\0n\0i\0n\0g\0 \0a\0 \0c\0o\0p\0y\0"
  .." \0o\0f\0 \0t\0h\0e\0 \0f\0o\0n\0t\0s\0 \0a\0c\0c\0o\0m\0p\0"
  .."a\0n\0y\0i\0n\0g\0 \0t\0h\0i\0s\0 \0l\0i\0c\0e\0n\0s\0e\0 \0"
  .."(\0\34\0F\0o\0n\0t\0s\0\34\0)\0 \0a\0n\0d\0 \0a\0s\0s\0o\0c\0"
  .."i\0a\0t\0e\0d\0 \0d\0o\0c\0u\0m\0e\0n\0t\0a\0t\0i\0o\0n\0 \0"
  .."f\0i\0l\0e\0s\0 \0(\0t\0h\0e\0 \0\34\0F\0o\0n\0t\0 \0S\0o\0f"
  .."\0t\0w\0a\0r\0e\0\34\0)\0,\0 \0t\0o\0 \0r\0e\0p\0r\0o\0d\0u\0"
  .."c\0e\0 \0a\0n\0d\0 \0d\0i\0s\0t\0r\0i\0b\0u\0t\0e\0 \0t\0h\0"
  .."e\0 \0F\0o\0n\0t\0 \0S\0o\0f\0t\0w\0a\0r\0e\0,\0 \0i\0n\0c\0"
  .."l\0u\0d\0i\0n\0g\0 \0w\0i\0t\0h\0o\0u\0t\0 \0l\0i\0m\0i\0t\0"
  .."a\0t\0i\0o\0n\0 \0t\0h\0e\0 \0r\0i\0g\0h\0t\0s\0 \0t\0o\0 \0"
  .."u\0s\0e\0,\0 \0c\0o\0p\0y\0,\0 \0m\0e\0r\0g\0e\0,\0 \0p\0u\0"
  .."b\0l\0i\0s\0h\0,\0 \0d\0i\0s\0t\0r\0i\0b\0u\0t\0e\0,\0 \0a\0"
  .."n\0d\0\47\0o\0r\0 \0s\0e\0l\0l\0 \0c\0o\0p\0i\0e\0s\0 \0o\0f"
  .."\0 \0t\0h\0e\0 \0F\0o\0n\0t\0 \0S\0o\0f\0t\0w\0a\0r\0e\0,\0 "
  .."\0a\0n\0d\0 \0t\0o\0 \0p\0e\0r\0m\0i\0t\0 \0p\0e\0r\0s\0o\0n"
  .."\0s\0 \0t\0o\0 \0w\0h\0o\0m\0 \0t\0h\0e\0 \0F\0o\0n\0t\0 \0S"
  .."\0o\0f\0t\0w\0a\0r\0e\0 \0i\0s\0 \0f\0u\0r\0n\0i\0s\0h\0e\0d"
  .."\0 \0t\0o\0 \0d\0o\0 \0s\0o\0,\0 \0s\0u\0b\0j\0e\0c\0t\0 \0t"
  .."\0o\0 \0t\0h\0e\0 \0f\0o\0l\0l\0o\0w\0i\0n\0g\0 \0c\0o\0n\0d"
  .."\0i\0t\0i\0o\0n\0s\0:\0\13\0\10\0\13\0\10\0T\0h\0e\0 \0a\0b\0"
  System.VERA=System.VERA
  .."o\0v\0e\0 \0c\0o\0p\0y\0r\0i\0g\0h\0t\0 \0a\0n\0d\0 \0t\0r\0"
  .."a\0d\0e\0m\0a\0r\0k\0 \0n\0o\0t\0i\0c\0e\0s\0 \0a\0n\0d\0 \0"
  .."t\0h\0i\0s\0 \0p\0e\0r\0m\0i\0s\0s\0i\0o\0n\0 \0n\0o\0t\0i\0"
  .."c\0e\0 \0s\0h\0a\0l\0l\0 \0b\0e\0 \0i\0n\0c\0l\0u\0d\0e\0d\0"
  .." \0i\0n\0 \0a\0l\0l\0 \0c\0o\0p\0i\0e\0s\0 \0o\0f\0 \0o\0n\0"
  .."e\0 \0o\0r\0 \0m\0o\0r\0e\0 \0o\0f\0 \0t\0h\0e\0 \0F\0o\0n\0"
  .."t\0 \0S\0o\0f\0t\0w\0a\0r\0e\0 \0t\0y\0p\0e\0f\0a\0c\0e\0s\0"
  .."\46\0\13\0\10\0\13\0\10\0T\0h\0e\0 \0F\0o\0n\0t\0 \0S\0o\0f\0"
  .."t\0w\0a\0r\0e\0 \0m\0a\0y\0 \0b\0e\0 \0m\0o\0d\0i\0f\0i\0e\0"
  .."d\0,\0 \0a\0l\0t\0e\0r\0e\0d\0,\0 \0o\0r\0 \0a\0d\0d\0e\0d\0"
  .." \0t\0o\0,\0 \0a\0n\0d\0 \0i\0n\0 \0p\0a\0r\0t\0i\0c\0u\0l\0"
  .."a\0r\0 \0t\0h\0e\0 \0d\0e\0s\0i\0g\0n\0s\0 \0o\0f\0 \0g\0l\0"
  .."y\0p\0h\0s\0 \0o\0r\0 \0c\0h\0a\0r\0a\0c\0t\0e\0r\0s\0 \0i\0"
  .."n\0 \0t\0h\0e\0 \0F\0o\0n\0t\0s\0 \0m\0a\0y\0 \0b\0e\0 \0m\0"
  .."o\0d\0i\0f\0i\0e\0d\0 \0a\0n\0d\0 \0a\0d\0d\0i\0t\0i\0o\0n\0"
  .."a\0l\0 \0g\0l\0y\0p\0h\0s\0 \0o\0r\0 \0c\0h\0a\0r\0a\0c\0t\0"
  .."e\0r\0s\0 \0m\0a\0y\0 \0b\0e\0 \0a\0d\0d\0e\0d\0 \0t\0o\0 \0"
  .."t\0h\0e\0 \0F\0o\0n\0t\0s\0,\0 \0o\0n\0l\0y\0 \0i\0f\0 \0t\0"
  .."h\0e\0 \0f\0o\0n\0t\0s\0 \0a\0r\0e\0 \0r\0e\0n\0a\0m\0e\0d\0"
  .." \0t\0o\0 \0n\0a\0m\0e\0s\0 \0n\0o\0t\0 \0c\0o\0n\0t\0a\0i\0"
  .."n\0i\0n\0g\0 \0e\0i\0t\0h\0e\0r\0 \0t\0h\0e\0 \0w\0o\0r\0d\0"
  .."s\0 \0\34\0B\0i\0t\0s\0t\0r\0e\0a\0m\0\34\0 \0o\0r\0 \0t\0h\0"
  .."e\0 \0w\0o\0r\0d\0 \0\34\0V\0e\0r\0a\0\34\0\46\0\13\0\10\0\13"
  .."\0\10\0T\0h\0i\0s\0 \0L\0i\0c\0e\0n\0s\0e\0 \0b\0e\0c\0o\0m\0"
  .."e\0s\0 \0n\0u\0l\0l\0 \0a\0n\0d\0 \0v\0o\0i\0d\0 \0t\0o\0 \0"
  .."t\0h\0e\0 \0e\0x\0t\0e\0n\0t\0 \0a\0p\0p\0l\0i\0c\0a\0b\0l\0"
  .."e\0 \0t\0o\0 \0F\0o\0n\0t\0s\0 \0o\0r\0 \0F\0o\0n\0t\0 \0S\0"
  .."o\0f\0t\0w\0a\0r\0e\0 \0t\0h\0a\0t\0 \0h\0a\0s\0 \0b\0e\0e\0"
  .."n\0 \0m\0o\0d\0i\0f\0i\0e\0d\0 \0a\0n\0d\0 \0i\0s\0 \0d\0i\0"
  .."s\0t\0r\0i\0b\0u\0t\0e\0d\0 \0u\0n\0d\0e\0r\0 \0t\0h\0e\0 \0"
  .."\34\0B\0i\0t\0s\0t\0r\0e\0a\0m\0 \0V\0e\0r\0a\0\34\0 \0n\0a\0"
  .."m\0e\0s\0\46\0\13\0\10\0\13\0\10\0T\0h\0e\0 \0F\0o\0n\0t\0 \0"
  System.VERA=System.VERA
  .."S\0o\0f\0t\0w\0a\0r\0e\0 \0m\0a\0y\0 \0b\0e\0 \0s\0o\0l\0d\0"
  .." \0a\0s\0 \0p\0a\0r\0t\0 \0o\0f\0 \0a\0 \0l\0a\0r\0g\0e\0r\0"
  .." \0s\0o\0f\0t\0w\0a\0r\0e\0 \0p\0a\0c\0k\0a\0g\0e\0 \0b\0u\0"
  .."t\0 \0n\0o\0 \0c\0o\0p\0y\0 \0o\0f\0 \0o\0n\0e\0 \0o\0r\0 \0"
  .."m\0o\0r\0e\0 \0o\0f\0 \0t\0h\0e\0 \0F\0o\0n\0t\0 \0S\0o\0f\0"
  .."t\0w\0a\0r\0e\0 \0t\0y\0p\0e\0f\0a\0c\0e\0s\0 \0m\0a\0y\0 \0"
  .."b\0e\0 \0s\0o\0l\0d\0 \0b\0y\0 \0i\0t\0s\0e\0l\0f\0\46\0\13\0"
  .."\10\0\13\0\10\0T\0H\0E\0 \0F\0O\0N\0T\0 \0S\0O\0F\0T\0W\0A\0"
  .."R\0E\0 \0I\0S\0 \0P\0R\0O\0V\0I\0D\0E\0D\0 \0\34\0A\0S\0 \0I"
  .."\0S\0\34\0,\0 \0W\0I\0T\0H\0O\0U\0T\0 \0W\0A\0R\0R\0A\0N\0T\0"
  .."Y\0 \0O\0F\0 \0A\0N\0Y\0 \0K\0I\0N\0D\0,\0 \0E\0X\0P\0R\0E\0"
  .."S\0S\0 \0O\0R\0 \0I\0M\0P\0L\0I\0E\0D\0,\0 \0I\0N\0C\0L\0U\0"
  .."D\0I\0N\0G\0 \0B\0U\0T\0 \0N\0O\0T\0 \0L\0I\0M\0I\0T\0E\0D\0"
  .." \0T\0O\0 \0A\0N\0Y\0 \0W\0A\0R\0R\0A\0N\0T\0I\0E\0S\0 \0O\0"
  .."F\0 \0M\0E\0R\0C\0H\0A\0N\0T\0A\0B\0I\0L\0I\0T\0Y\0,\0 \0F\0"
  .."I\0T\0N\0E\0S\0S\0 \0F\0O\0R\0 \0A\0 \0P\0A\0R\0T\0I\0C\0U\0"
  .."L\0A\0R\0 \0P\0U\0R\0P\0O\0S\0E\0 \0A\0N\0D\0 \0N\0O\0N\0I\0"
  .."N\0F\0R\0I\0N\0G\0E\0M\0E\0N\0T\0 \0O\0F\0 \0C\0O\0P\0Y\0R\0"
  .."I\0G\0H\0T\0,\0 \0P\0A\0T\0E\0N\0T\0,\0 \0T\0R\0A\0D\0E\0M\0"
  .."A\0R\0K\0,\0 \0O\0R\0 \0O\0T\0H\0E\0R\0 \0R\0I\0G\0H\0T\0\46"
  .."\0 \0I\0N\0 \0N\0O\0 \0E\0V\0E\0N\0T\0 \0S\0H\0A\0L\0L\0 \0B"
  .."\0I\0T\0S\0T\0R\0E\0A\0M\0 \0O\0R\0 \0T\0H\0E\0 \0G\0N\0O\0M"
  .."\0E\0 \0F\0O\0U\0N\0D\0A\0T\0I\0O\0N\0 \0B\0E\0 \0L\0I\0A\0B"
  .."\0L\0E\0 \0F\0O\0R\0 \0A\0N\0Y\0 \0C\0L\0A\0I\0M\0,\0 \0D\0A"
  .."\0M\0A\0G\0E\0S\0 \0O\0R\0 \0O\0T\0H\0E\0R\0 \0L\0I\0A\0B\0I"
  .."\0L\0I\0T\0Y\0,\0 \0I\0N\0C\0L\0U\0D\0I\0N\0G\0 \0A\0N\0Y\0 "
  .."\0G\0E\0N\0E\0R\0A\0L\0,\0 \0S\0P\0E\0C\0I\0A\0L\0,\0 \0I\0N"
  .."\0D\0I\0R\0E\0C\0T\0,\0 \0I\0N\0C\0I\0D\0E\0N\0T\0A\0L\0,\0 "
  .."\0O\0R\0 \0C\0O\0N\0S\0E\0Q\0U\0E\0N\0T\0I\0A\0L\0 \0D\0A\0M"
  .."\0A\0G\0E\0S\0,\0 \0W\0H\0E\0T\0H\0E\0R\0 \0I\0N\0 \0A\0N\0 "
  .."\0A\0C\0T\0I\0O\0N\0 \0O\0F\0 \0C\0O\0N\0T\0R\0A\0C\0T\0,\0 "
  .."\0T\0O\0R\0T\0 \0O\0R\0 \0O\0T\0H\0E\0R\0W\0I\0S\0E\0,\0 \0A"
  System.VERA=System.VERA
  .."\0R\0I\0S\0I\0N\0G\0 \0F\0R\0O\0M\0,\0 \0O\0U\0T\0 \0O\0F\0 "
  .."\0T\0H\0E\0 \0U\0S\0E\0 \0O\0R\0 \0I\0N\0A\0B\0I\0L\0I\0T\0Y"
  .."\0 \0T\0O\0 \0U\0S\0E\0 \0T\0H\0E\0 \0F\0O\0N\0T\0 \0S\0O\0F"
  .."\0T\0W\0A\0R\0E\0 \0O\0R\0 \0F\0R\0O\0M\0 \0O\0T\0H\0E\0R\0 "
  .."\0D\0E\0A\0L\0I\0N\0G\0S\0 \0I\0N\0 \0T\0H\0E\0 \0F\0O\0N\0T"
  .."\0 \0S\0O\0F\0T\0W\0A\0R\0E\0\46\0\13\0\10\0\13\0\10\0E\0x\0"
  .."c\0e\0p\0t\0 \0a\0s\0 \0c\0o\0n\0t\0a\0i\0n\0e\0d\0 \0i\0n\0"
  .." \0t\0h\0i\0s\0 \0n\0o\0t\0i\0c\0e\0,\0 \0t\0h\0e\0 \0n\0a\0"
  .."m\0e\0s\0 \0o\0f\0 \0G\0n\0o\0m\0e\0,\0 \0t\0h\0e\0 \0G\0n\0"
  .."o\0m\0e\0 \0F\0o\0u\0n\0d\0a\0t\0i\0o\0n\0,\0 \0a\0n\0d\0 \0"
  .."B\0i\0t\0s\0t\0r\0e\0a\0m\0 \0I\0n\0c\0\46\0,\0 \0s\0h\0a\0l"
  .."\0l\0 \0n\0o\0t\0 \0b\0e\0 \0u\0s\0e\0d\0 \0i\0n\0 \0a\0d\0v"
  .."\0e\0r\0t\0i\0s\0i\0n\0g\0 \0o\0r\0 \0o\0t\0h\0e\0r\0w\0i\0s"
  .."\0e\0 \0t\0o\0 \0p\0r\0o\0m\0o\0t\0e\0 \0t\0h\0e\0 \0s\0a\0l"
  .."\0e\0,\0 \0u\0s\0e\0 \0o\0r\0 \0o\0t\0h\0e\0r\0 \0d\0e\0a\0l"
  .."\0i\0n\0g\0s\0 \0i\0n\0 \0t\0h\0i\0s\0 \0F\0o\0n\0t\0 \0S\0o"
  .."\0f\0t\0w\0a\0r\0e\0 \0w\0i\0t\0h\0o\0u\0t\0 \0p\0r\0i\0o\0r"
  .."\0 \0w\0r\0i\0t\0t\0e\0n\0 \0a\0u\0t\0h\0o\0r\0i\0z\0a\0t\0i"
  .."\0o\0n\0 \0f\0r\0o\0m\0 \0t\0h\0e\0 \0G\0n\0o\0m\0e\0 \0F\0o"
  .."\0u\0n\0d\0a\0t\0i\0o\0n\0 \0o\0r\0 \0B\0i\0t\0s\0t\0r\0e\0a"
  .."\0m\0 \0I\0n\0c\0\46\0,\0 \0r\0e\0s\0p\0e\0c\0t\0i\0v\0e\0l\0"
  .."y\0\46\0 \0F\0o\0r\0 \0f\0u\0r\0t\0h\0e\0r\0 \0i\0n\0f\0o\0r"
  .."\0m\0a\0t\0i\0o\0n\0,\0 \0c\0o\0n\0t\0a\0c\0t\0:\0 \0f\0o\0n"
  .."\0t\0s\0 \0a\0t\0 \0g\0n\0o\0m\0e\0 \0d\0o\0t\0 \0o\0r\0g\0\46"
  .."\0h\0t\0t\0p\0:\0\47\0\47\0w\0w\0w\0\46\0b\0i\0t\0s\0t\0r\0e"
  .."\0a\0m\0\46\0c\0o\0m\0\0\0\0\0\0\0\1\0\0f\0\0\0\0\2"
  .."\127\0\2\0\2\0\2\0\2\0\2\0\0\0\0\2\0\0\0\1\1\1\0\0"
  .."\0\0\0\0\1\10\3\1\55\0\0\0\0\0X\4!\0\0\0\0\2\0\2\0"
  .."\3\0u\3\0\0\0\0u\3\1\57\3\0\1\0!\1\0\0\0\2\0\2\0"
  .."\2\0\2\0\2\3\0\0\3\0{\3\3X\1\31\1m\0\1\0\0\0{\0\1o\0"
  .."\127\2{\0\2R\0\0\4\0\0\0\0\0\0\0\0o\0\0\0\0\1\0"
  .."\0\0\0\0\2\0Z\0\0\0\4!\0\0\14\0\2\0\2\0\2\1\0\0\127"
  System.VERA=System.VERA
  .."\2\2=\2f\0\0\0\0\0\1\0\0s\4\0\1\10\0\0\5\2+\0\0"
  .."\0\0\0\0b\0\5\5\0\2\127\5\5\5\0\0\0\0\29\6\6\20\7#"
  .."\1\0\0\0\1\1\49\2N\0\1\10\0{\0T\3\92\3q\3\1\4#\4w\3"
  .."\0\2\0\3`\0j\0\5\6\20\0\7#\0\6f\1y\4`\4`\4`\4{\0\0\0{\2"
  .."w\4`\1\0\6\20\7b\3\0{\2!\0\0\0\127\2{\0\0\0\2R\5N\5N\4"
  .."\0f\0\0\0f\0\0\0f\0\0\6\16\0\3\0\0\2\1H\4F\3?\0"
  .."\0{\4L\0\0\0\0\0'\0o\0\0\0o\3\53\0j\0o\0{\5\5\5\5\0\0"
  .."\0\45\5\3\2{\0\0\127\2\1\51\2=\0\2f\1\0\2\0\0o\3D\0"
  .."\55\0f\0\29\5\0\1\6\20\0\0\7}\0s\5\0\0\20\0\2\1\21\93"
  .."\5A\28\1\21\0\0\3\1\21\0\0\4\1\20\0\0\3\1\19\0\0\3\1\18\0"
  .."\18\0\3\1\17\0\0\3\1\16\0\0\3\1\15\0\0\3\1\14\0\0\3\1\13"
  .."G\5A%\1\13\0}\0\3\1\12\0%\0\3\1\11\0\50\0\3\1\10\0\0\3\1\9"
  .."\0\0\3\1\8\0\14\0\3\1\7\0\0\3\1\6\0%\0\3\1\5\0\0\3\1\4\0\14"
  .."\0\3\1\3\0%\0\3\1\2\0\0\3\1\1@Y\3\3}\3\3\3\50\3\3"
  .."}\3\5\3\4Y\5\3\4&\5Y\3@\4&\3\47\5\3\47"
  .."\3\3\3\50\3\20\3\3G\5\3@\4G\3d\5\3d\3"
  .."\3\27\5\3\27\3\3k\3\3\3\25\5\3\25\3ߖ\3"
  .."\3\3\21\5\3\21\3ږ\3\21\5\3؍\11\5\21\3}\3:\3"
  .."\11\5:\3\3\10\5\3\10\3\3\3ϊ\17\5\28\3\22\3"
  .."\3̖\3ˋ%\5\3\3}\3\3\3\3Ś\13\5\3\3\3\3"
  .."\11\5\20\3\12\3\5\3\93\5\3\4%\5\93\3@\4%\3"
  .."\3\3A\5\3A\5\3\13\5\3d\3d\3\14\3\18\3\3"
  .."@\3\3\3\18\3\3\14\5\50\3\14\3\17\5(\3\17\3"
  .."\45\5}\3\45\3\3\3\3\25\5d\3\16\5\25\3\16\3"
  .."\10\3\3\13\5\3\13\3\46\5\3\46\3A\5\3\5\3"
  .."\93\5\3\4%\5\93\3@\4\3\3%\5\3%\3%\5A\3"
  .."\11\5\20\3\11\3%\5d\3\17\5%\3\17\3\3\3\3\17"
  .."\5\3\17\3\3\3\17B\5S\3\3x\3\127~}\5\127\3~}\3}\30"
  .."\3|\3{\14\3z\3w\3v\3ut\12\5u\15\3u\1\0@\4t\12\3t\4s\18"
  .."\3s@\4r\3q\3p\3onS\5o\3nm(\5nS\3m(\3l\3k\50\3j\3i\50\3"
  .."h\3g\3f\3e\3d\3cb\30\5c\3b\0\16\5b\30\3a\3`\3_\3^Z\11"
  .."\5^\14\3\93d\3\92\3\91Z\11\5\91\20\3Z\11\3Y\3X\20\3W\3V\3"
  System.VERA=System.VERA
  .."U\27\25\5U\50\3T\3S\3R\3Q}\3P\3O\20\3N\3M\1\45\5M\3L\3"
  .."K(\3JI\24\5J\55\3IC\18\5I\24\3HE\24\5H\3GC\18\5Gd\3FE\24\5F"
  .."\3E\24\3DC\18\5D\55\3CB\17\5C\18\3C\2@@\9\4BA\15\5B\17\3B"
  .."\2\0@\9\4A@\14\5A\15\3A\1@\9\4@?\12\5@\14\3@\1@\9\4?\12\9"
  .."\5?\12\3?\1@@d\4>\3=\1\45\5=\3<\3;(\3:\3\57\17B\5\57d\3"
  .."\56\49\26\5\56K\3\55\3\54\45\20\5\54\3\53K\3\52\48\26\5\52"
  .."K\3\51\48\26\5\51\3\50\17B\5\50\3\49\45\20\5\49\26\3\48\26"
  .."\3\47\45\20\5\47\24\3\46\9\22\5\46\3\45,\19\5\45\20\3\45\2"
  .."@\9\4,\16\17\5,\19\3,\2@@\4+*%\5+\3*\9\22\5*%\3)\2:\5)\3"
  .."(\3'\3&\15\3%\22B\5%E\3$\15\3#\3\34\15\15\5\34\3! \45\5!"
  .."}\3 \45\3\31K\3\30\17B\5\30\3\29\3\28\27\25\5\28\3\27\0\16"
  .."\5\27\25\3\26\3\25\3\24\3\23\22B\5\23F\3\22\21\45\5\22B\3"
  .."\21\20\16\5\21\45\3\20\16\3\19\0\16\5\19\20\3\18\17B\5\18\3"
  .."\17\1\45\5\17B\3\16\15\15\5\16\17\3\16\2\0@\9\4\15\14\12\5\15"
  .."\15\3\15\1@\9\4\14\13\10\5\14\12\3\14\1@\9\4\13\12\9\5\13"
  .."\10\3\13\1@\4\12\9\3\12\1\0@\55\4\11\3\10\9\22\5\10\3\9"
  .."\22\3\8\16\3\7\3\6\1\45\5\6\3\5\20\3\3\2:\5\3\3\2\1\45\5\2"
  ..":\3\1\0\16\5\1\45\3\0\16\3\1\1d\1++++++++++++++++++++++++"
  .."++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++"
  .."++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++"
  .."+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++\0"
  .."++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++"
  .."++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++"
  .."++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++"
  .."+++++++++++\29\0\6\5\4\3\2\1\0, \16\2%Id@QX Y!\45,\2%Id"
  .."@QX Y!\45, \16\7 \0P\13y PX\4\27\5Y\5\28\3%\8\4%#"
  .." \0P\13y PX\4\27\5Y\5\28\3%\8\45,KPX \1\23EDY!\45,"
  .."\2%E`D\45,KSX\2%\2%EDY!!\45,ED\45\0\2\0h\4h\5\0\3\0\7\0"
  .."\31\0\4\1\20\0\0\0\6\1\20\1\8\5\2\4\0\47\49\0\16\48"
  .."\19\17!\17%!\17!h\4\0s\3\27\7\14r\6)\0\0\2\2\4\0\0\2"
  .."\5\0\5\0\9\0\31@\15\3\6\0\8\4\3\7\1\3\6\0\10\16<\50\57"
  .."\57\49\0\47\48\1\51\17\3#\3\17\51\21#\2\4\21\21\5q"
  System.VERA=System.VERA
  .."\1e\0\2\1R\3\3\127\5\0\3\0\7\0\29@\14\5\1\4\0\8\0\4\2"
  .."\6\4\4\8\16\49\0\16<\50\48\1\17#\17#\17#\17\3\127Ѯ\5"
  .."\2+\2+\0\2\0\2\0\0\4\5\0\27\0\31\0J@\48\28\23\7\3\0\25"
  .."\5\1\30\21\9\19\15\11\17\13\31\30\29\28\27\26\24\23\22\19\18"
  .."\17\16\15\14\13\12\10\9\8\5\4\3\2\1\0\26\6\20 \16\23\57\49"
  .."\0\47<<<<<<<\50\50\50\48\1\3\51\19\51\3\51\21!\3\51\21!"
  .."\3#\19#\3#\19!\53!\19!\53!\19\1#\3\51\2hiiThiih"
  .."\1)T\1\47h\1\8T\5a\1ab\1b\1\1N\1\0\3"
  .."\0\4Z\6\20\0\6\0\13\0\47\0d@\57\8($\0\7)\24\4%\20\47\16\23"
  .."\19\1%$\31(\30\20\19\1\14!\30\16\4\6$\8,\5\0\11\6\27\19"
  .."\5( \14\3\0\7\30\23\15\3\7\48\16\23<\23\50<\16\49\0\47"
  .."\50\16\17\18\57\17\57\17\18\23\57\17\18\57\48\1\17\54"
  .."\54\53\52&'\17\6\6\21\20\22\19#\3&&'\53\22\22\23\17&&\53\52\54"
  .."\55\53\51\23\22\22\23\21&&'\17\22\22\21\20\6\7\2n|phumd\1"
  .."fbdcӿd\1OTUP\2DN\3td\93g\1\4p^Vd\1\45\5\46)"
  ..">B\2\1\31\14\5\30\26+\47\4Q\31\9\0\0\5\0!\0\0\4"
  .."\5\0\11\0\26\0\30\0*\0\57\0V@\47\30\55\29(\34\28\15\27\3\9"
  .."\15\34\55(\46\15\3\24\28\27+\31\30\29\6\10\21\11\0\10"
  .."\12%\10\52\11\31\10+\12:\16\16\57\57\17\18\57\57\49\0"
  .."\47\16\17\57\17\57\17\18\57\18\57\48\1\20\22\51\50\54"
  .."\53\52&#\34\6\7\52\54\51\50\22\23\22\22\21\20\6#\34&\1'\1\23"
  .."%\20\22\51\50\54\53\52&#\34\6\7\52\54\51\50\22\23\22\22\21\20"
  .."\6#\34&\2iNMklLNi@s\46\46\50H#\4\18)\23iOMllMMk"
  .."@u\45\45\49\1?NjkMMljO\48\46\47t?\1\26`\1`OikMMkj"
  .."N\48\45\45uA\0\0\2\0\57\4\5\0*\0\55\0@b\17\16\2\18"
  .."\15\23\12\13\12\14\23\13\13\12\45,\2\46+\23\0\1\0\50\51\52\53"
  .."\54\5\49\55\23\1\1\0B\55\12\9\6\1\5\7\15\49\13\24\0+\3\34\7\49"
  .."\18\34!%\30\18\7\13\0(\1\7\6\3!\12\8\4\55+!\24(\27\15!\4"
  .."\19\8(\18!\27\8\13\16\27\46\18\21\56\16\16\16\17\57\17"
  .."\18\57\17\57\57\17\18\57\18\23\57\17\57\49\0\47\16\17"
  .."\18\23\57\17\18\57\17\23\57\48KSX\7\16\14\17\23\57\7\16\14"
  .."\17\23\57\7\16\5\7\16\5\17\23\57Y\34\1\1\54\54\53\52''\51\21"
  System.VERA=System.VERA
  .."\20\6\7\23#'\6\6#\34\0\53\52\54\55&&\53\52\54\51\50\22\23\21"
  .."&&#\34\6\21\20\22\7\6\6\21\20\22\51\50\54\55\54\54\55\2#\1'"
  .."&\3\1JKNSj抋\50\48ǭAF;}Eap:\54\92\91ț*\92,\27#\16\3"
  .."\49h F\7'XmFD\1\13̉dHG\24\23'%\91M;I\92\24"
  .."\23\15\23\13\0\1\2\16\3\2\5\0\3\0\18\1\0\4\0\4\2\4\16"
  .."\49\0\16\48\1\17#\17\2\5\2+\0\0\1\1\3u\6\18\0\13\0"
  .."\31@\15\6\0\14\13\7\0\3\18\6\0\24\10\14\16\50\17\57\57\49"
  .."\0\16\48\1\6\2\21\20\18\23#&\2\53\52\18\55\3u\6\18"
  ..";:\1\1\0\1\1\92\3'\6\18\0\13\0\31@\15\7\0\14"
  .."\7\1\11\8\0\24\4\18\11\14\16\50\17\57\57\49\0\16\48\1\51"
  .."\22\18\21\20\2\7#\54\18\53\52\2\1\92\6\18<<\1"
  .."\1\0\0\1\0\2J\4+\5\0\17\0N@,\16\13\11\0\4\12\9\7\4\2\4"
  .."\8\3\5\17\12\10\1\14\18\8\12\10\3\9\6\17\3\1\3\2\0\25\15\4"
  .."\11\9\25\13\6\18\16<\50<\50\23\57\17\18\23\57\49\0\16<"
  .."\50\50\23\57\18\23\57\48\1\5\5\7%\17#\17\5'%%\55\5\17\51\17"
  .."%\4+\1f\57s\57\1f\57\1Ps\1P\4b\1ybc\1y\0"
  .."\1\0X\0q\4y\4\0\11\0'@\20\0\9\1\5\7\3\12\2\26\4\0\28\8\26"
  .."\10\6\12\16<<\49\0\16<<\48\1\17!\21!\17#\17!\53!\17\2"
  .."\1CD\1\4DD\1\1\0\1\1\2\1\47\0\5\0\24@\11\3"
  .."\0\6\3\4\1\29\0\6\16\49\0\16\48\1\51\21\3#\19\1Śc\1"
  .."\47\1\127\0\0\1\1d\1\3m\2\0\3\0\17\0\2\4\1\0\4\16\49"
  .."\0\16\48\1!\21!\1d\2\9\2\0\1\1\0\0\2\1\49\0\3\0\16\0"
  .."\2\1\29\0\4\16\49\0\47\48\1\51\17#\1\1\49\0\1\0fB\4"
  .."\55\5\0\3\0\24@\11\2\0\4\1\30\0\2\30\3\4\16\49\0\16\48"
  .."\1\51\1#\3y\5m\0\3\0\4L\5\0\11\0\23\0#\1\10@\26\3"
  .."\9\18\30\12\24\30$\21\30\27\6!\0\27\34\15\30!\31$\16"
  .."\16\49\0\16\16\48@\47\0\47\1\47\2\47\3\47\4\47\5\47"
  .."\6\47\7\47\8\47\9\47\10\47\11?\0?\1?\2?\3?\4?\5?\6?\7?\8?\9?"
  .."\10?\11O\0O\1O\2O\10O\11_\0_\1_\2_\10_\11\0\1\2\3\4\5"
  .."\6\7\8\9\10\11\0\1\2\3\4\5\6\7\8\9\10\11\0"
  .."\1\2\3\4\5\6\7\8\9\10\11F\47\0\47\1\47\2\47\3\47\4"
  .."\47\5\47\6\47\7\47\8\47\9\47\10\47\11_\0_\1_\2_\3_\4_\5_\6_\7"
  System.VERA=System.VERA
  .."_\8_\9_\10_\11\0\1\2\3\4\5\6\7\8\9\10\11$\93\1\93"
  .."\1\52\54\51\50\22\21\20\6#\34&\19\34\2\17\16\18\51\50\18\17\16"
  .."\2'\50\18\17\16\2#\34\2\17\16\18\1M\54\56PO\57\56K"
  .."\2\55PP\55\56NL\2\1\48\1\54\1\55\1\48x"
  .."x\1\1~\1\127\1\0\1\0\0\0\4F\5\0\10\0&@\20\3\4\2\5\7"
  .."\0\9\8#\6\30\3\0#\1\11\16\49\0\47\50\48%!\17\5\53"
  .."%\51\17!\21!\1\14\1:\1P\1\54Ȫ\4uLJժ\0\0\1\0\0\0\4#\5"
  .."\0\28\0Q@)\0\28%\5\6\5\24\25\26\3\23\27%\6\6\5B\16\17\13\20"
  .."\4\0\2\0\16\10\2\1\10\30\23\34\16\3$\29\16\17\18\57\49"
  .."\0\47\50\48KSX\7\16\5\17\23\57\7\16\5\23\50Y\34%!\21!"
  .."\53\54\0\55\54\54\53\52&#\34\6\7\53\54\54\51\50\4\21\20\6\7\6"
  .."\6\1u\2u\1\24\53dF\91pga\1\11Yd\56ժ\1\46>zO}BC"
  .."\49\50`tA\0\0\1\0\4\55\5\0(\0G@)\0\19\21\10\9\13"
  .."\6\31 \28#\6\21)\22\19\0\3\20\25\30&\16\30\3\34\31\20"
  .."\9\31)\16\17\23\57\49\0\16\16\16\57\48\1\22"
  .."\22\21\20\4#\34&'\53\22\22\51\50\54\53\52&##\53\51\50\54\53\52"
  .."&#\34\6\7\53\54\54\51\50\4\21\20\6\3\8ggfbY"
  .."hyI\1\5\3\31'Ǖ&$\53\52zms{((  ۵{\0\0\2\0f\0\0"
  .."\4o\5\0\2\0\13\0B@\31\1\13\3\13\0\3\3\13B\0\3\11\7\5\1\3\9"
  .."\1\12\10\0\30\8\4\6\15\12$\14\16<\50\17\57\49\0\47<\50"
  .."\18\57\48KSX\7\16\4\7\16\5Y\34\1\1!\3\51\17\51\21#\17#\17!"
  .."\53\2)\1!\5\29\3\51\1d\0\0\1\0\4\45\5\0"
  .."\29\0=@\34\4\7\29\26\7\17\16\20\13\2\0\13\7\30\3\30\0"
  .."\23\30\1\10\34\0\16\31\30\16\16\49\0\16\16\16"
  .."\18\57\48\19!\21!\17\54\54\51\50\0\21\20\0#\34&'\53\22\22\51"
  .."\50\54\53\52&#\34\6\7\2+W,\1\16wN\92aQF\5ժ"
  .."\16\15  \50\49%%\0\2\0\4L\5\0\24\0$\0=@#\7\31"
  .."\25\10\31\16\10\4\1\0\4\22\16%\34\30\0&\13\34\7\6\28"
  .."\1\19\31%\16\49\0\16\16\16\16\17\57\48\1\21&&#"
  .."\34\2\17\54\54\51\50\18\21\20\2# \2\17\16\0!\50\22\1\34\6\21"
  .."\20\22\51\50\54\53\52&\3?M\48n\1#\1\20J݁"
  .."\5%'dk\1u\1\1z\1\31l\0\1\0\0\0\4\55"
  System.VERA=System.VERA
  .."\5\0\6\0\53@\25\5%\2\3\2\3%\4\5\4B\5\0\3\5\3\1\4\1\34\0\31"
  .."\7\16\17\57\57\49\0\47\48KSX\7\16\5\7\16\5Y\34\19!\21"
  .."\1#\1!\3\2\8\53\5V\5+\0\0\3\0\4N\5\0\11\0#\0\47"
  .."\0C@%\24\12\0'\6\30\45\18\30'\48\24\12$*\30\21$\30\15\9"
  .."\30\21\27\34\3\30\15!\31\48\16\16\16\17\57\57\49\0\16"
  .."\16\16\57\57\48\1\34\6\21\20\22\51\50\54\53\52&%&&\53\52"
  .."\54\51\50\22\21\20\6\7\22\22\21\20\4#\34$\53\52\54\19\20\22\51"
  .."\50\54\53\52&#\34\6\2hʁ򑁖Myz\127{y"
  .."\2ŗT!\127Ѳ\127!!ȟɠ\1bx~~xz\0\0\2\0\127"
  .."\4F\5\0\11\0$\0;@\34\19\6\0\22\16\13\12\16\34\6\28\34"
  .."%\19\6\3\1\31\34\9\30\12&\25\31%\16\49\0\16\16\16"
  .."\17\57\48\1\50\54\53\52&#\34\6\21\20\22\3\53\22\22\51\50\18"
  .."\17\6\6#\34\2\53\52\18\51 \18\17\16\0!\34&\2T?M\47"
  .."n\1\4I\2%'\1!\1\25dk\1\10\1\9o"
  .."s\31\0\0\2\1\0\0\2\4'\0\3\0\7\0\27@\13\2\0\4\6\5\1\29\4"
  .."\0\8\16<\50\49\0\47\48\1\51\17#\17\51\17#\1\4'\57"
  .."\0\0\2\1\2\4'\0\5\0\9\0%@\19\8\6\3\0\6\10\3\4\0\29"
  .."\1\7\29\6\10\16\49\0\16\16\48\1\51\21\3#\19\3\51\17"
  .."#\1Śc\13\1\47\1\127\3\0\0\1\0X\0\4y\4w\0\6\0!@\18"
  .."\5\4\2\1\0\5\3\6\7\1\2\0(\4'\7\16\50\57\49\0\16\23\57\48"
  .."\9\2\21\1\53\1\4y\3R\4!\3÷\1\1\0\0\2\0X\1`\4y\3"
  .."\0\3\0\7\0\27@\12\4\6\2\0\8\5\1\4\0\8\16<\50\49\0\16"
  .."\48\19!\21!\17!\21!X\4!\4!\2\12\2B\0\1\0X\0\4y\4w\0\6"
  .."\0!@\18\6\5\3\2\0\5\4\1\7\6\2(\4\0'\7\16<\57\49\0\16\23"
  .."\57\48\19\53\1\21\1\53\1X\4!\3R\3^^\1=\0\2\0\0\0\4\16"
  .."\5\0\30\0\34\0{@B\11\10\9\8\7\5\12\6%\25\26\25\3\4\2\2\5%\26"
  .."\26\25B\29\26\5\2\4\6\25\15\0\31\16\15\12\19\31!\6 \25\22"
  .."\9\5\1\0\26 \9\0\3\1\9)\22\15\1 \3\31#\16\16\17\18\57"
  .."\17\18\57\17\18\57\18\57\49\0\47\16\17\57\57\23\57\48K"
  .."SX\7\16\4\17\23\57\7\16\4\17\23\57Y\34\1#\53\52\54\55\55\54"
  .."\54\53\52&#\34\6\7\53\54\54\51\50\22\21\20\6\7\7\6\6\21\21\3"
  .."\51\21#\2=TZ>\47mNb^hC^XE&\1bRY;X\49YnED\57\56"
  System.VERA=System.VERA
  .."L\92VBT=\47\0\2\0\27\4\5s\0\11\0\52\0p@\49(+$\26\23"
  .."\3\14\12\9\27\52\3\23\9\12\17'$+\23\30\49+\53'\13\6(\12\0"
  .."\6+\20\0\26\13\46\12\20!+\12\45\46\53\16\16<\16\17\18"
  .."\57\17\18\57\49\0\16\16\16\57\57\17\18\57\17\18\57"
  .."\17\18\57\48@\13\5\6\7\19\20\21\6\1\93\1\52&#\34\6\21\20"
  .."\22\51\50\54\19#\53\14\1#\34&\53\52\54\51\50\22\23\53\52&#\34"
  .."\0\17\16\0!\50\54\55\23\14\1# \0\17\16\0!\50\18\21\4\14kk"
  .."kk%RӡP$\1J\1\18\54l\57\48?{:\93\1x\1<\2!"
  .."o?DF=?z\20\21\25\24\1\1\1\1\0\2\0"
  .."%\0\0\4\5\0\2\0\10\0@A\0%\1\0\4\5\4\2%\5\4\7%\5\4\6%\5\5\4"
  .."\9%\3\10\8%\3\10\1%\10\3\10\0%\2\0\3\3\10B\0\3\7\1\3\9\5\9"
  .."\8\7\6\4\3\2\1\0\9\5\47\10\11\16\23\57\49\0\47<\18\57\48"
  .."KSX\7\16\8\7\16\5\7\5\7\5\7\16\5\7\5\7\5\7\16\8Y\34"
  .."\7\3\1\1\93@\26\10\0\15\0\0\0\4\3\1\11\2\4\3\12\4\9\7\6\8"
  .."\1\2\8\93\0\93\1\3!\1\51\1#\3!\3#\2h\1\1nl\5#\4\3"
  .."+\1{\0\0\3\0\0\0\4q\5\0\8\0\17\0 \0=@#\25\0\10\9\18"
  .."\1\10\31\17\11\25\31\19\8\2\5\0\14\30\22\5\50\28\49\9\0\30"
  .."\18\48!\16\50\17\23\57\57\57\49\0\47\16\57\48\1\17"
  .."\51\50\54\53\52&#\3\17\51\50\54\53\52&#%!\50\22\21\20\6\7\22"
  .."\22\21\20\4!!\1qﰖ뒃J\1F\2{\2f>p}"
  .."qdƵ\20\22Ϡ\0\1\0\4\49\5\0\25\0\46@\26\25\0\22\3"
  .."\13\12\16\9\3\26\19\50\12\0\49\6\48\26\16\50\49\0\16"
  .."\16\48%\6\6# \0\17\16\0!\50\22\23\21&&#\34\2\17\16\18"
  .."\51\50\54\55\4\49M\91\1?\1\29\91MJVXI\53))\1\1p"
  .."\1n\1))=@@=\0\2\0\0\0\4R\5\0\8\0\17\0(@\21\6\9"
  .."\0\15\6\0\15\9\7\3\50\12\49\7\30\16\48\18\16\17\57\57\57"
  .."\57\49\0\47\48%\50\54\17\16&!#\17\19 \0\17\16\0!!\17\1"
  .."\0`d\1V\1DѦ\1H\1Kw\5\47\5\0\1\0\0\0\4N\5"
  .."\0\11\0)@\22\6\4\2\0\8\4\10\1\5\9\49\7\3\30\0\51\12\16"
  .."\50\49\0\47\16\48\19!\21!\17!\21!\17!\21!\3vT\2"
  .."r\2w\5ժF\0\0\1\0\0\0\4X\5\0\9\0$@\19\6\4\2\0\4"
  .."\8\5\1\49\7\3\30\0\52\10\16\50\49\0\47\16\48\19!\21"
  System.VERA=System.VERA
  .."!\17!\21!\17#\3o\92\2e\5ժH\55\0\1\0f\4P\5\0\29\0"
  .."<@!\25\26\0\22\3\26\28\22\3\13\12\16\9\3\30\27\25\30\12"
  .."\0\54\19\50\6\53\30\16\49\0\16\16\17\18\57\17\57"
  .."\48%\6\6# \0\17\16\0!\50\22\23\21&&#\34\2\17\16\18\51\50\54\55"
  .."\17#\53!\4PQv\1@\1\29^PQ_ſCe)\1{KM\1\1o\1n\1\53"
  .."\54MI\31!\1\0\1\0\0\0\4H\5\0\11\0&@\20\8\2\4\0"
  .."\10\6\7\3\30\5\49\9\1\30\0\48\12\16\50\50\49\0\47<\50"
  .."\48\19\51\17!\17\51\17#\17!\17#\2)\5\2d+\2\57\0"
  .."\0\1\0\0\0\4\6\5\0\11\0%@\19\10\2\0\8\4\6\5\1\55\3\30\7"
  .."\0\55\9\12\16\50\50\49\0\47\50\50\48\19!\21!\17!\21!\53"
  .."!\17!\3=\1\57\1\57\5ժ\127\4\0\0\1\0m\3\5\0\17"
  .."\0,@\23\12\7\8\1\0\4\15\8\10\15\18\9\7\30\11\0\53\18\16"
  .."\49\0\16\16\17\57\57\48\55\53\22\22\51\50\54\53\17"
  .."!\53!\17\16\6#\34&m\91hq\2G`=QQ\3D\18,\0\0\1\0"
  .."\0\0\4\5\0\11\0@!\8%\9\8\5\6\5\7%\6\5B\8\5\2\3\3\0\10\6"
  .."\8\5\4\3\6\1\9\1\30\0\48\12\16\50\16\23\57\49\0\47<\50\23"
  .."\57\48KSX\7\5\7\16\8Y\34\8\4\1\1\93@L\7\5\22\5\23\8&\5&\8"
  .."\54\2F\2U\2W\8X\9d\2z\5y\8{\9\14\2\3\1\4\7\5\0\6\2\7\22\5\23"
  .."\8'\5,\6+\7&\8:\3I\3G\6G\7\91\3W\5X\6X\7W\8k\3z\3x\7\23\93\0"
  .."\93\19\51\17\1\51\9\1#\1\7\17#\2w\2V\25\5h\2"
  .."\2\0\1\0\0\0\4s\5\0\5\0\24@\12\2\0\4\1\30\3\49\0\52\6"
  .."\16\49\0\47\48\19\51\17!\21!\2d\5ժ\0\0\1\0V\0\0\4"
  .."y\5\0\12\0@,\8\2\3\2\7\3\3\2\10\1\2\1\9\2\2\1B\10\7\2\3\0\8"
  .."\3\0\11\5\9\8\3\2\1\5\10\6\6\4\47\10\6\0\48\13\16\17\23"
  .."\57\49\0\47<\50\17\23\57\48KSX\7\16\5\7\16\4\7\16\4\7\16"
  .."\5Y\34\15\10\1\0\93@$\5\8\10\9\23\1\24\3\23\8\24\9&\1)\3&\8"
  ..")\9\54\1\57\3\54\8\56\9\14\15\7\15\7\15\10\3\93\1\93\19!\9\1"
  .."!\17#\17\1#\1\17#V\1\14\1\2\1\4\1\15\5\8\2+\5'\3"
  .."\19\0\1\0\0\0\4F\5\0\9\0m@\28\7\1\2\1\2\6\7\6B\7\2\3\0\8"
  .."\5\6\1\7\2\17\4\49\7\17\0\48\10\16\17\57\57\49\0\47<\50"
  .."\57\57\48KSX\7\16\4\7\16\4Y\34\23\1\1\1\93@&\23\2\24\7)\2"
  .."&\7\56\7W\2d\2j\7u\2z\7\10\24\6&\1)\6F\1I\6W\1g\1h\6\8\93\0\93"
  System.VERA=System.VERA
  .."\19!\1\17\51\17!\1\17#\1\0\1\0\8\5\51\4+\4\51\0\2"
  .."\0u\4\92\5\0\11\0\23\0#@\19\9\15\3\21\15\24\0\50\12\54"
  .."\6\50\18\53\24\16\49\0\16\16\48\1\16\2#\34\2\17\16\18"
  .."\51\50\18\19\16\2#\34\2\17\16\18\51\50\18\3"
  .."\2\1I\1\26\1\25\1Iz\1~\1\1\1\0\2\0\0\0\4u"
  .."\5\0\8\0\19\0+@\24\1\16\0\9\18\16\10\8\2\4\0\5\50\13\56\17"
  .."\0\30\9\51\20\16\50\17\23\57\49\0\47\48\1\17\51\50\54"
  .."\53\52&#%!\50\4\21\20\4##\17#\1ꌝL\1\1\2\5\47ϔ"
  .."\0\0\2\0u\4\92\5\0\17\0\29\0=@ \0\30\16\17\15\27"
  .."\3\21\9\3\17\30\17\24\16\12\15\0\24\18\50\12\54\24\50\6\53"
  .."\30\16\17\57\57\17\57\17\57\49\0\16\16\57\18\57\18\57"
  .."\48\5\34\6#\34\2\17\16\18\51\50\18\17\16\2\7\23\7\19\16\2#\34"
  .."\2\17\16\18\51\50\18\2\7\26\8ȗ\16\27\2\1\1"
  .."\1\1yHd\3\1I\1\26\1\25\0\2\0\0\0\4\5\0"
  .."\19\0\28\0j@\56\9\8\7\3\10\6%\3\4\3\5%\4\4\3B\6\4\0\21\3\4\21"
  .."\9\20\13\11\4\5\17\22\9\6\3\10\3\17\0\28\14\3\10\25\50\4\17"
  .."\49\20\10\30\12\48\29\16\50\17\23\57\17\57\17\23\57\17\57"
  .."\49\0\47<\18\57\18\57\18\57\48KSX\7\16\5\7\16\14\17\23"
  .."\57Y\34\1\22\22\23\19#\3&&##\17#\17!\50\4\21\20\6\1\17\51\50"
  .."\54\53\52&#\2NnRٲM{c\1\1\6ݑ\2\20oh\1y\93"
  .."\5Ҕ\2Y\0\1\0\4J\5\0'\0@=\13\12\2\14\11%\30\31"
  .."\30\8\9\2\7\10%\31\31\30B\10\11\30\31\4\1\21\20\24\17\1\0"
  .."\4%\17(\30\10\11\31\27\7\0&\27\57\14\49\20\7\57\34\48(\16"
  .."\17\18\57\57\57\57\49\0\16\16\17\23\57\48KSX\7"
  .."\16\14\17\23\57\7\16\14\17\23\57Y\34\8\2\1\1\93@\10\7\0\7"
  .."\1\7\2\3\7\2\1\93\0\93\1\21\46\1#\34\6\21\20\22\31\1\30\1\21"
  .."\20\4#\34&'\53\30\1\51\50\54\53\52&\47\1\46\1\53\52$\51\50\22"
  .."\3\92^mjikshulм\1\13V\5;<qch#\24\49ҵ"
  .."\45\45ID{pv \25\47'\0\1\0\47\0\0\4\5\0\7\0\28@\14\6\2"
  .."\0\4\1:\3\30\0:\5\8\16\49\0\47\50\48\19!\21!\17#\17!"
  .."\47\4s\45+\5ժ\5+\0\0\1\0\4=\5\0\30\0,@\24\15\3\19\16"
  .."\0\3\1\9\25\17\1\31\15\30\18\49\2\30\0\48\31\16\49\0\16"
  System.VERA=System.VERA
  .."\50\17\23\57\57\57\48\19\17\51\17\20\22\23\22\22\51\50\54"
  .."\55\54\54\53\53\17\51\17\20\6\7\6\6#\34&'&&\12\15 yVWx!\15"
  .."\12\57FBjiCE:\2=\3\12m\93\25;<<;\25\92l^\3h?;::;>\0"
  .."\1\0\57\0\0\4\5\0\6\0L@)\1%\2\3\2\0%\6\0\3\3\2\0%\1\0\4\5\4"
  .."\6%\5\5\4B\0\5\1\3\6\4\3\1\0\5\2\47\5\48\7\16\23\57\49\0\47"
  .."\50\57\48KSX\7\16\5\7\16\8\7\16\8\7\16\5Y\34%\1\51\1#\1"
  .."\51\2h\1_KKѪ\5++\5\0\0\1\0\0\0\0\4\5\0\12\0@D\5\6\5"
  .."\9\10\9\4\10\9\3\10\11\10\2\1\2\11\11\10\6%\7\8\7\5%\4\5\8\8"
  .."\7\2%\3\2\12\0\12\1%\0\12B\10\5\2\3\8\3\6\0\11\8\12\11\10\9"
  .."\8\6\5\4\3\2\1\11\7\0\47\23\57\49\0\47<<\17\23\57\48KSX\7"
  .."\5\7\16\8\7\16\8\7\16\5\7\16\8\7\16\5\7\5\7\16\8Y\34"
  .."\24\9\1\1\93@^\31\3\31\4\31\10\47\3\47\4+\10?\3?\4\56\10Z\2"
  .."Z\5\11\23\11&\2*\3%\4*\5(\8+\9%\11&\12\53\2:\3\53\4:\5;\8:\9"
  .."\52\11\54\12T\0T\1Z\2X\3W\4V\5\91\6\91\7R\8W\9X\11\93\12g\8h"
  .."\12y\3v\4y\9v\11#\93\0\93\17\51\27\1\51\27\1\51\3#\11\1#ŏ"
  .."߿ʿ\5D\3\34\4+\3w\0\1\0\18\0\0\4\5\0\11\0@K\9"
  .."%\10\11\10\8%\7\8\11\11\10\8%\9\8\5\6\5\7%\6\6\5\3%\4\5\4\2%"
  .."\1\2\5\5\4\2%\3\2\11\0\11\1%\0\0\11B\11\8\5\2\4\3\0\9\6\11\8"
  .."\7\5\2\5\0\4;\6\47\0;\10\48\12\16\17\23\57\49\0\47<\50\23"
  .."\57\48KSX\7\16\5\7\16\8\7\16\8\7\16\5\7\16\5\7\16\8\7\16"
  .."\8\7\16\5Y\34\55\2\1\0\93@\56\13\5\4\11\24\5'\1(\3)\5&\11"
  .."X\11x\2y\5w\11\11\0\2\0\2\15\8\15\8\20\2\26\8!\2%\5+\8%\11\53"
  .."\2U\2Y\8X\11e\2s\2\16\93\1\93\19\51\9\1\51\9\1#\9\1#\1V\1H\1"
  .."NA\1u\1\5\2\51B\2}\3\23\0\0\1\0%\0\0\4\5\0"
  .."\8\0Y@\46\3%\4\5\4\2%\1\2\5\5\4\2%\3\2\8\0\8\1%\0\0\8B\2\3\0"
  .."\6\2\7\3\5\4\1\7\0\4<\5\30\0<\7\9\16\17\18\57\17\18\57\17"
  .."\57\49\0\47\50\57\48KSX\7\16\5\7\16\8\7\16\8\7\16\5Y\34"
  .."\19\51\1\1\51\1\17#\17%\1l\1k!\5m\2b\2\0\1\0\0\0"
  .."\4\5\0\9\0E@\28\8%\2\3\2\3%\7\8\7B\8\0\3\5\8\3\0\1\4\47"
  .."\0\6\48\10\16\17\57\57\49\0\47\48KSX\7\16\5\7\16\5Y"
  .."\34\8\8\1\1\93\7\3\1\93\19!\21\1!\21!\53\1!\3\3\34\11"
  .."\2\31\5՚o\4\0\0\1\1\3w\6\20\0\7\0\30@\15\4\6\2\0"
  System.VERA=System.VERA
  .."\8\5\1\3=\0\8\16\50\49\0\16\48\1!\21#\17\51\21!\1\1"
  .."X\6\20\0\1\0fB\4\55\5\0\3\0\24@\11\1\0\4\1\30\2\0"
  .."\30\3\4\16\49\0\16\48\1\1#\1\1%\3\18\5m\6\0\0\1\1"
  .."Z\3\2\6\20\0\7\0\30@\15\3\1\5\0\8\0=\6\2\4\8\16\50\49"
  .."\0\16\48\1\17!\53\51\17#\53\3\2X\6\20ޏ\6\4\0\1\0H\3"
  .."\4\5\0\6\0\24@\10\3\4\1\0\7\3\1\5\7\16\57\49\0\16\50"
  .."\57\48\1\1#\1\1#\1\2\1Ȳ\1\5\1u\2\45\0\0\1\0\0\29"
  .."\4\0m\0\3\0\15\0\1\4\0\2\47\49\0\16\48\1\21!\53\4\0\0"
  .."mPP\0\0\1\1\23\4\2\6f\0\3\0\49@\9\1\0\4\1<\3\4\16\49\0"
  .."\16\48\0K\9TK\14T\91X\0\4\0\1\0\4\0\4\0@\56\17\55\56Y"
  .."\9\1#\1\1\1\25\6f\1x\0\2\0\4#\4{\0\11\0)\0n@*\10\7\0"
  .."\26 \12\24\15\7\0\24\7\18! \29$\18\24\13\1\24\4\25\14"
  .."\10\6\12D \4\6\21>*\16\50\50\17\57\57\49\0\47\16"
  .."\16\17\57\17\57\18\57\17\18\57\48@\29\48\31\48 \48!\48\34\0"
  .."\1\2\10\11\22\23\24\25\26\14\93\1#\34\6\21\20\22\51"
  .."\50\54\55\53\55\17#\53\14\1#\34&\53\52\54;\1\53\46\1#\34\6\7"
  .."\53>\1\51\50\22\23\30\1\2=zl\1;\1^\91fX="
  .."& \2\51qpepӺ)Ld_\29y\54\52''RR\50\0\0\2\0\4X\6"
  .."\20\0\11\0\28\0\48@\26\24\12\9\3\15\9\21\15\27\25\0\18\18"
  .."G\24\12\6\6\26F\29\16\50\50\49\0\47\16\17\57\57\48\1"
  .."\52&#\34\6\21\20\22\51\50\54\1\54\54\51\50\18\17\16\2#\34&'\21"
  .."#\17\51\3,fd\46\2\47\2xRXW"
  .."S\6\20\0\0\1\0\4%\4{\0\25\0\47@\26\12\13\16\0\25\22"
  .."\3\16\9\3\26\19\18\12\0\6F\26\16\50\49\0\16\16\16"
  .."\48%\6\6# \0\17\16\0!\50\22\23\21&&#\34\6\21\20\22\51\50\54"
  .."\55\4%JR\1%\1\4QNI\93`A\57++\1\56\1\20\1\20\1\56"
  .."*,A:;>\0\0\2\0{\4\18\6\20\0\16\0\28\0\48@\26\5\0\20\26"
  .."\14\20\8\14\1\3\23\4\0\6\2G\17\18\11H\29\16\50\50\49"
  .."\0\47\16\17\57\57\48\1\17\51\17#\53\6\6#\34\2\17\16\18\51"
  .."\50\22\1\20\22\51\50\54\53\52&#\34\6\3Z\46de\15"
  .."\3\2CSW\1;\1\21\1\17\1\55W\11\0\0\2\0{\4X\4"
  .."{\0\21\0\28\0E@&\0\22\3\1\10\9\6\22\1\6\13\1\25\19\13"
  System.VERA=System.VERA
  .."\29\3\2\28\16\9\22\6\0I\28\18\16H\29\16\17\18\57\57\49"
  .."\0\16\16\16\16\18\57\17\57\48\1\21!\21\20\22\51\50\54"
  .."\55\21\6\6# \0\17\16\0\51\50\18\7&&#\34\6\7\4X㿮Xmi\91"
  .."\1 \4\16\2^Z\6\56\57++\1\57\1\19\1\12\1@Ţ"
  .."\0\1\0\0\0\4'\6\20\0\19\0\52@\26\5\16\1\12\8\6\1\0\14\6"
  .."\10\2\19\7\0\9\5\6\13\15\11\20\16<<\50\57\57\49\0\47\50"
  .."\16\50\18\57\57\48\1\21#\34\6\21\21!\21!\17#\17!\53!\53\52"
  .."\54\51\4'cM\1\127\1+\6\20Qgc\47\3яN\0\0\2\0{H"
  .."\4\18\4{\0\11\0)\0H@'\25\12\30\27'\9\3\18\19\22\9\30\22\15"
  .."\3$\30\15(*'\25\0\6\12G\6\18\18!H*\16\50\50\49\0\16"
  .."\16\16\16\17\18\57\57\17\57\57\48\1\52&#\34\6\21\20"
  .."\22\51\50\54\19\20\2#\34&'\53\22\22\51\50\54=\2\6\6#\34\2\17"
  .."\16\18\51\50\22\23\53\51\3Z\127LSbC,ml\47"
  .."\2\57\28\27\46,\8}^\92\1:\1\7\1\8\1:VZ\0\0\1"
  .."\0\0\0\4\27\6\20\0\19\0,@\24\9\14\3\0\3\1\6\17\12\10\1\2"
  .."\6\0J\13\9\6\11F\20\16\50\49\0\47<\17\23\57\57\48\1\17"
  .."#\17\52&#\34\6\21\17#\17\51\17\54\54\51\50\22\4\27jq\49"
  .."s\2J\2\6\20`c\0\0\2\0\0\0\4D\6\20\0\9\0\13\0"
  .."\46@\25\8\0\12\10\0\6\2\4\3L\11\1\6\5L\0K\10\7\14\16<"
  .."<\49\0\47\50\16\48\1!\17!\21!\53!\17!\1\51\21#\1\0\1"
  .."\1mn\1m\1\31\4`\47\3B\2C\0\0\2\0V\3\16\6\20\0\13"
  .."\0\17\0\56@\29\5\0\1\10\8\1\3\16\14\3\8\18\11\8\2\9\2\15"
  .."\4\6\14\0\18\16<\50\18\57\57\49\0\16\16\16\17\57\57"
  .."\48\5\17!\53!\17\20\6##\53\51\50\54\17\51\21#\2X\1ZZ"
  .."\20\3Ӝ}\6\0\0\1\0\0\0\4\6\20\0\11\0@:\8\23\9\8\5"
  .."\6\5\7\23\6\6\5\9\23\3\2\8\23\7\8\3\2\5\23\6\5\2\3\2\4\23\3\3"
  .."\2B\8\5\2\3\3\0\10\6\8\5\4\3\6\9\1\6\6D\0E\12\16\50\17\23"
  .."\57\49\0\47<\23\57\48KSX\7\16\5\7\16\8\7\8\7\4\7\16\5"
  .."\7\16\8Y\34\8\7\1\1\93@R\6\2\8\8\22\2\24\5\24\8\53\2\52\5\54"
  .."\8F\2f\2u\2v\5\12\9\3\8\8\25\3\23\4\24\5\25\6\26\7\24\8(\3'\5"
  .."(\7;\3;\4\55\5\57\7\55\8J\3I\7Y\6Y\7k\3i\4i\6i\7y\3x\5y\6y\7"
  .."\28\93\0\93\19\51\17\1\51\9\1#\1\7\17#\1G\1b\6\20"
  System.VERA=System.VERA
  .."{\1ZF\2B?\0\1\0\0\0\4\10\6\31\0\13\0&@\19\9\0\3\10\12"
  .."\3\5\3\6\4\0\6\11L\9\14\16\57\57\49\0\47\17\57\57\48"
  .."\1\20\22\51\51\21#\34&\53\17!\53!\2\127\91Y饵\1\1|~"
  .."\3\0\1\0m\0\0\4o\4{\0\34\0@'\24\18\15\9\4\7\0\29\27\6\7\21"
  .."\12 \3\27\25\16\7\0\17\15\8M\6N\17M\15N\28\24M\26E#\16<"
  .."\17\18\57\49\0\47<<<\50\17\57\17\57\57\17\23\57\48@G\48"
  .."\4\48\5\48\6\48\7\48\8\48\9\48\10\48\11?\22?\23?\24?\25?\26?"
  .."\27?\28?\29?\30\3\4\5\6\7\8\9\10\11\22\23\24\25"
  .."\26\27\28\29\30#\1\93\1K\12TK\17T\91K\22T\91X\0#\0@"
  .."\0\1\0#\0#\56\17\55\56Y\1K\16TX\0#\0\1\0#\0#\0@\56\17\55"
  .."\56Y\1>\1\51\50\22\25\1#\17\52&#\34\6\21\17#\17\52&#\34\6\21"
  .."\17#\17\51\21>\1\51\50\22\2\34iJo\53FP;\57JI\57!c?Le\3"
  .."HEw\2s{\127\2p{\127\4``<?F\0\1\0\0\0\4\27\4{\0"
  .."\19\0,@\24\9\14\3\0\3\1\6\17\12\10\1\2\6\0J\13\9\6\11F\20"
  .."\16\50\49\0\47<\17\23\57\57\48\1\17#\17\52&#\34\6\21\17"
  .."#\17\51\21\54\54\51\50\22\4\27jq\49s\2J\2\4"
  .."``c\0\2\0\4H\4{\0\11\0\23\0#@\19\6\18\0\12\18\24\9\18"
  .."\15D\3\18\21>\24\16\49\0\16\16\48\1\34\6\21\20\22\51"
  .."\50\54\53\52&'\50\18\17\16\2#\34\2\17\16\18\2h"
  .."\3ڜ\1\45\1\31\1\30\1\46\0\0\2\0V\4T\4{\0"
  .."\16\0\28\0\51@\28\5\0\20\26\14\20\8\14\1\3\29\17\18\11"
  .."G\23\4\0\6\2F\29\16\50\50\49\0\16\16\17\57\57\48%\17"
  .."#\17\51\21\54\54\51\50\18\17\16\2#\34&\1\52&#\34\6\21\20\22\51"
  .."\50\54\1w\46df\1\6\10SWW\1"
  .."\0\0\2\0R\4\31\4w\0\11\0\28\0\51@\28\24\12\9\3\15\9\21"
  .."\15\27\25\29\24\12\6\6\26G\0\18\18>\29\16\50\50\49\0"
  .."\16\16\17\57\57\48\1\20\22\51\50\54\53\52&#\34\6\1\6\6"
  .."#\34\2\17\16\18\51\50\22\23\53\51\17#\1L\2\26\45e"
  .."d\46\2+SY\1\55\1\17\1\22\1:WS\0\1\1j\0\0\4"
  .."\4{\0\17\0O@\19\6\7\11\3\0\17\3\14\9\7\10\6\6\0\8\18\16"
  .."\50\49\0\47\17\57\17\57\48@%\16\0\16\1\16\17 \0 \1 \17"
  .."\48\0\48\1\51\16\48\17@\0@\1C\16@\17P\0P\1P\16P\17\18\93\1\46"
  System.VERA=System.VERA
  .."\1#\34\6\21\17#\17\51\21>\1\51\50\22\23\4;zI\46Dv\54\3"
  .."y\46*\4`w\127\34$\0\0\1\0\4\6\4{\0'\0u@@\13\12\2\14\11"
  .."\23\31\30\8\9\2\7\10\23\30\31\30B\29\30\24\10\11\30\31\4\21\0"
  .."\1\4\20\21\24\17\4%\17(\29\10\11\31\27\7\0O\27\6\14I"
  .."\7\6\20\34E(\16\17\18\57\57\57\57\49\0\16\16\16"
  .."\18\23\57\17\18\57\48KSX\7\16\14\17\23\57\7\14\17\23\57Y\34"
  .."\1\21&&#\34\6\21\20\22\23\23\22\22\21\20\6#\34&'\53\22\22\51"
  .."\50\54\53\52\47\2&&\53\52\54\51\50\22\3OS}{\92JSjgT"
  .."z\8EZ\4\57\46\46QSKJ#\14\26}##\53\53cY\49\2\14\31"
  .."\127!\0\1\0\0\0\4\8\5\0\19\0\49@\24\14\5\8\15\3\0\17\1"
  .."\8\10\8\11\9\2\4\0\6\16\18\14\20\16<<\50\57\57\49\0\47"
  .."<\50\17\57\57\48\1\17!\21!\17\20\22\51\51\21#\34&\53\17!"
  .."\53!\17\2f\1^^uϪ\1+\5|b\2`\1>\0\1\0\4\27"
  .."\4^\0\19\0,@\24\9\14\3\0\3\1\6\17\10\1\12\13\9\6\11J\2\6\0"
  .."F\20\16\50\49\0\47\50\17\23\57\57\48\19\17\51\17\20\22"
  .."\51\50\54\53\17\51\17#\53\6\6#\34&økp\49q\1\2J"
  .."\2yad\0\0\1\0d\0\0\4m\4`\0\6\0e@)\3\23\4\5\4\2\23\1\2\5"
  .."\5\4\2\23\3\2\6\0\6\1\23\0\0\6B\2\3\0\5\6\5\3\2\1\5\4I\0E\7"
  .."\16\23\57\49\0\47\50\57\48KSX\7\16\5\7\16\8\7\16\8\7\16"
  .."\5Y\34'\2\1\0\93@\14\7\0\7\1\8\3\8\4\4\5\2%\2\2\93\1\93\19"
  .."\51\9\1\51\1#d\1E\1Fr\4`T\3\0\1\0\0\0\0\4\4`\0\12\1"
  .."\17@E\11\2\3\2\10\9\10\3\3\2\10\11\10\4\5\4\9\5\5\4\6\23\7\8"
  .."\7\5\23\4\5\8\8\7\2\23\3\2\12\0\12\1\23\0\12B\10\5\2\3\8\3\6"
  .."\0\11\8\12\11\10\9\8\6\5\4\3\2\1\11\7\0\47\23\57\49\0\47<"
  .."<\17\23\57\48KSX\7\5\7\16\8\7\16\8\7\16\5\7\16\5\7\16\8"
  .."\7\16\8\7\16\5Y\34\15\10\1\0\93@\11\9\4\11\31\0\31\1\29"
  .."\2\26\3\28\4\25\5\28\9\27\10\26\11\31\12&\0&\1)\2&\5)\6)\7#\8"
  ..",\12\57\2\54\5\57\6\57\7\51\8<\12E\8I\9F\11J\12V\8X\9W\11Y\12"
  .."f\2i\3f\4i\5j\9e\11v\2z\5x\8|\9r\11\45\15\10\25\2\31\3\31\4\25"
  .."\5\31\10\31\10+\2+\5>\2>\5<\10H\10Y\10j\2i\5h\10{\2\127\3y\4"
  .."\127\4z\5|\10\127\10\24\93\1\93\17\51\27\1\51\27\1\51\1#\11\1"
  .."#àö\4`w\2B\3\2f\0\0\1\0L\0\0\4\4`\0\11\0"
  System.VERA=System.VERA
  .."@H\5\23\6\7\6\4\23\3\4\7\7\6\4\23\5\4\1\2\1\3\23\2\2\1\11\23"
  .."\0\1\0\10\23\9\10\1\1\0\10\23\11\10\7\8\7\9\23\8\8\7B\10\7\4"
  .."\1\4\8\0\5\2\10\7\4\1\4\8\0\2I\8\6E\12\16\17\23\57\49\0"
  .."\47<\50\23\57\48KSX\7\16\5\7\16\8\7\16\8\7\16\5\7\16\5"
  .."\7\16\8\7\16\8\7\16\5Y\34\7\10\1\0\93@\30\9\1\6\7f\1i\7v"
  .."\1y\7\6\7\1\7\7\6\10\21\10:\4\52\10Z\4V\10\8\93\1\93\9\2#\9\1"
  .."#\9\1\51\9\1\4^o\1\1o\1)\1'\4`\1?\2H\2\24k"
  .."\1\0\0\1\0hV\4\4`\0\18\0@E\13\23\14\13\2\3\2\10\11\2\9\12"
  .."\23\3\3\2\17\23\18\0\18\16\23\15\16\0\0\18\16\23\17\16\13\14"
  .."\13\15\23\14\14\13B\16\19\13\0\14\9\7\17\14\19\17\16\15\13"
  .."\10\7\0\7\18\8\18I\14E\19\16\17\23\57\49\0\16\50\17\57"
  .."\57\18\57\48KSX\7\16\5\7\16\8\7\16\8\7\16\5\7\16\5\17\23"
  .."\57\7\16\8Y\34\56\18\1\1\93@\26\4\16v\16\2\8\17\8\18\25\12"
  .."\25\13&\14&\15\56\17I\17I\18Y\13\10\93\0\93\1\6\7\2\7\14\1+\1"
  .."\53\51\50\54\55\1\51\9\1\51\3Z\46Gc\34\46\92mQ\92GO\1L\1"
  .."G\1hu:NN^\4N\3l\0\0\1\0\0\0\4\16\4b\0\9\0X@\28\3\23"
  .."\7\8\7\8\23\2\3\2B\8\0\3\5\8\3\0\4\1I\0\6E\10\16\50\17"
  .."\57\57\49\0\47\48KSX\7\16\5\7\16\5Y\34\56\8\1\1\93@\21"
  .."\54\3\56\8E\3J\8W\3X\8e\3j\8u\3z\8\10\93\19!\21\1!\21!\53\1!"
  .."\3\45}\2\2\4bܖ\3%\0\1\0\3\6\20\0$\0f@\53\25\15"
  .."\21\11\6%\9\26\16\21\29\11\5 !\3\0\11\9\0\1\9\21\19%\12"
  .."\9\10\5$\22\25\0\29\10\5\19\2\20\0 \25=\10\15\5%\16<<\50"
  .."\57\57\17\18\57\17\18\57\57\17\18\57\57\49\0\16\16\18\23"
  .."\57\18\57\17\57\57\17\18\57\17\18\57\57\48\5\21#\34&\53\53\52"
  .."&##\53\51\50\54\53\53\52\54\51\51\21#\34\6\21\21\20\6\7\22\22"
  .."\21\21\20\22\51\3@k>>j@FU\91noZUtrݓW"
  .."\25\27V\0\1\2\18\29\2\6\29\0\3\0\18\1\0\4\0\4\2\4\16"
  .."\49\0\16\48\1\17#\17\2\6\29\0\8\0\0\0\1\0\3\6\20\0"
  .."$\0j@\55\31%\27\22\12\15\8\27\11\21\25\15\4\5 \3\0\25\27\0"
  .."#\27\15\17%\28\25\26\21\15\1\4\0\8\26\21#\18\4\0\26\31\21"
  .."=\16\0\11\4%\16<\50<\17\18\57\57\17\18\57\17\18\57\57\17"
  .."\18\57\57\49\0\16\16\18\23\57\17\18\57\57\17\57\17\57\57"
  System.VERA=System.VERA
  .."\17\18\57\48\23\51\50\54\53\53\52\54\55&&\53\53\52&##\53\51\50"
  .."\22\21\21\20\22\51\51\21#\34\6\21\21\20\6##DVZon\91VD>k"
  .."@@k>X\27\25Xrtݔ\0\0\1\0X\1\4y\3\12\0\27"
  .."\0&@\18\1\11\4\15\0\14\4\25\18\0\11\28\0\14'\28\16\49\0\16"
  .."<\50\18\57\17\18\57\48\1\21\6\6#\34'&'&&#\34\6\7\53\54\54"
  .."\51\50\22\23\22\23\22\51\50\54\4yKOZq\22\11Mg\51OINS\53dJ"
  .."\12\21t\93F\3\12;\55\51\10\4!\24;?<\54\22\31\5\10\55=\0"
  .."%\0\0\4\7N\0'\0$\0\0\0\0\0\7\1\3\0\0\1u\0\3\0%\0\0\4\7m\0\11"
  .."\0\14\0!\0@W\12%\13\12\27\28\27\14%\28\27\30%\28\27\29%\28\28"
  .."\27 %\15!\31%\15!\13%!\15!\12%\14\12\15\15!B\12\27\15\9\30\13"
  .."\3\21\9\13 \28\29\28\24 !\31\13\18\6\30\14\24\12\6\27\0P\24"
  .."\15\6P\18\24K\28\47\18K!\34\16\16\50\16\50\17\57\17\57"
  .."\57\17\18\57\57\17\57\17\18\57\49\0\47<\16\18\57\57\57\48"
  .."KSX\7\16\8\7\16\5\7\5\7\5\7\16\5\7\5\7\5\7\16\8Y\34"
  .."\31\1\0\93@\20\13\14\30\31\4\12\12\13\14\30\5\93\1"
  .."\93\1\52&#\34\6\21\20\22\51\50\54\7\3!\1\46\1\53\52\54\51\50"
  .."\22\21\20\6\7\1#\3!\3#\3\0Y?@WX??Y\1:Arr@;\1nl\6"
  .."Z?YWA?XX\8\3P!yIrrIv$\1{\0\0u\4\49\5\0'\0&\0\0\0"
  .."\0\0\7\0\0d\0\0\0\0\0\4N\7k\0'\0(\0\0\0\0\0\7\1\4\0\18\1"
  .."u\0\0\0\4F\7^\0'\0\49\0\0\0\0\0\7\1\5\1u\0u\4\92\7N"
  .."\0'\0\50\0\0\0\0\0\7\1\3\0\0\1u\0\4=\7N\0'\0\56\0\0\0\0"
  .."\0\7\1\3\0\0\1u\0\4#\6f\0'\0D\0\0\0\0\0\7\0\0\0\0\0\0"
  .."\4#\6f\0'\0D\0\0\0\0\0\7\0C\0\0\0\0\0\4#\6f\0'\0D\0\0"
  .."\0\0\0\7\0\0\0\0\0\0\4#\6\16\0'\0D\0\0\0\0\0\7\0\0\0\0"
  .."\0\0\4#\6\55\0'\0D\0\0\0\0\0\7\0\0\0\0\0\0\4#\7\6"
  .."\0'\0D\0\0\0\0\0\7\0\0\0\0\0\0u\4%\4{\0'\0F\0\0\0\0\0\7"
  .."\0\0h\0\0\0{\4X\6f\0'\0H\0\0\0\0\0\7\0\0\14\0\0\0{"
  .."\4X\6f\0'\0H\0\0\0\0\0\7\0C\0\14\0\0\0{\4X\6f\0'\0H\0\0\0"
  .."\0\0\7\0\0\14\0\0\0{\4X\6\16\0'\0H\0\0\0\0\0\7\0\0\14\0"
  .."\0\0\0\0\4D\6f\0'\0\0\0\0\0\0\7\0\0\0\0\0\0\0\0\4D\6"
  .."f\0'\0\0\0\0\0\0\7\0C\0\0\0\0\0\0\0\4D\6f\0'\0\0\0\0\0\0"
  .."\7\0\0\0\0\0\0\0\0\4D\6\16\0'\0\0\0\0\0\0\7\0\0\0\0\0"
  System.VERA=System.VERA
  .."\0\0\0\4\27\6\55\0'\0Q\0\0\0\0\0\7\0\0\0\0\0\0\4H\6f"
  .."\0'\0R\0\0\0\0\0\7\0\0\0\0\0\0\4H\6f\0'\0R\0\0\0\0\0\7"
  .."\0C\0\0\0\0\0\4H\6f\0'\0R\0\0\0\0\0\7\0\0\0\0\0\0"
  .."\4H\6\16\0'\0R\0\0\0\0\0\7\0\0\0\0\0\0\4H\6\55\0'\0R\0"
  .."\0\0\0\0\7\0\0\0\0\0\0\4\27\6f\0'\0X\0\0\0\0\0\7\0\0\0"
  .."\0\0\0\4\27\6f\0'\0X\0\0\0\0\0\7\0C\0\0\0\0\0\4\27"
  .."\6f\0'\0X\0\0\0\0\0\7\0\0\0\0\0\0\4\27\6\16\0'\0X\0\0\0"
  .."\0\0\7\0\0\0\0\0\0\1\0;\4\47\5\0\11\0'@\20\8\4\10\2\0\6"
  .."\12\3R\5\1Q\9R\7\0\12\16<<\49\0\16<\50\48\1\51\17!\21"
  .."!\17#\17!\53!\2\16\1n\1n\5\92\4\93\0\0\2\1+\3u\3"
  .."\5\0\14\0\26\0 @\17\21\9\15\0\27\24S\6T\18S\12\27\16"
  .."\49\0\16\48\1\50\22\23\22\22\21\20\6#\34&\53\52\54\23\34"
  .."\6\21\20\22\51\50\54\53\52&\2hAu,\45\47OomOPqp\5\49\46"
  .."\45rBoPPlnNOp\0\0\2\0\4%\5\0\26\0!\0N@*\27\8\5\4\28"
  .."\0\1\28\9\8\5\12\28\22\24\21\15\12\13\34\27\21\14\7\23"
  .."\12\4\8\0\31\30\18E\34\16<<<\50\50\49\0\16\50<\16"
  .."\16\17\57\17\18\57\48\1\21&&'\17\54\54\55\21\6\6\7\17#\17"
  .."&\0\53\52\0\55\17\51\17\22\22\1\17\6\6\21\20\22\4%C??BI\57"
  .."g\1\7g\57ބ\4\53(,\4\5\45(\31\34\3\1\30\22\1\57"
  .."\1=\19\1\31\3\34+\3`\12츸\0\1\0\0\0\4X\5\0\27\0>@ \7"
  .."\22\1\18\10\20\8\12\1\0\4\25\16\12\14\0\13\9\11\7\30\15"
  .."\19\21\17\28\16<<\49\0\47\50\16<\50\18\57\57\48"
  .."\1\21&&#\34\6\21\21!\21!\17!\21!\53\51\17#\53\51\53\52\54\51"
  .."\50\22\4D>\127C\127\1s\2\25\51A\5,,ُ\47\1"
  .."\29\0\2\0=\4\12\5\0\50\0>\0j@<#$\30\57\51\11\17$*\4\1"
  .."\27\26\30\23\1\0\4\48\23?#\7\17<!*\54\11$\57\51\4\7!U"
  .."\20\7U\45\20<U\0&\14\45\26&\54U'?\16\16\16\17\23\57"
  .."\18\57\17\18\57\18\57\49\0\16\16\17\23\57\57\57\17\18"
  .."\57\48\1\21&&#\34\6\21\20\23\22\23\22\22\21\20\6\7\22\22\21\20"
  .."\6#\34&'\53\22\22\51\50\54\53\52''&&\53\52\54\55&&\53\52\54\51"
  .."\50\22\1\6\6\21\20\22\23\54\54\53\52&\3S\57ak\26\14Ԃ\91\93"
  .."=:̭IWW\57fq\24ր\93\91<;ȧH>=><\5''PGZs\15\8weZ"
  System.VERA=System.VERA
  .."\53\52m@\29\29''TLf{\14xf\91\49,pE\29\45Z\47L\45"
  .."Z\47L\0\0\1\1?\1\3\4!\0\11\0\18\9\3\12\6V\0\12\16\49\0"
  .."\16\48\1\52\54\51\50\22\21\20\6#\34&\1?}|}|\2|{|\0"
  .."\0\1\0j;\4\6\5\0\13\0#@\17\4\8\0\6\2\14\0\7W\5\3W\1\49\11"
  .."\14\16\57\49\0\16\50\48\1!\17#\17#\17#\17&&\53\52$\2"
  .."F\1\1\5\5f\6\31\3N\17ݸ\0\0\1\0\4}\6\20\0\47\0"
  .."V@\49\45'!\12\4\6\13 \0\4*\22\23\26\19*\3\19\46\12\9\13"
  .."\29 !'\9\1$'\6\6\29\6$\16\22\45\6\16D\0F\48\16\16\16"
  .."\17\57\57\18\57\18\57\49\0\47\16\18\23\57\23\57\48\19"
  .."\52\54\51\50\22\23\6\6\21\20\22\23\23\22\22\21\20\6#\34&'\53"
  .."\22\22\51\50\54\53\52&''&&\53\52\54\55&&#\34\6\21\17#\2"
  .."\55C:oEBL;lAxC\92\91\2yqyr\4q\14|d\49M*%\93t"
  .."\25\24\31\30aQG_J'\56O#kr\0\0\4\0\0\0}\4\5N\0\19\0"
  .."\28\0\52\0L\0@I\15\14\13\3\16\12\93\9\10\9\11\93\10\10\9B\12"
  .."\10\6\22\9\10\22\15\20\0\17\10A)\0\53)\29M\23\20\15\12"
  .."\4\0\6\16\9\26\3\21\16\92\18\26\92\10\3\91G\7#\18X;\7#Y\47\47"
  .."\16\16\50\17\18\57\17\57\57\23\57\49\0\16\16\50"
  .."\16\18\57\18\57\18\57\48KSX\7\16\5\7\16\4\17\23\57Y\34\1"
  .."\50\22\21\20\6\7\22\22\23\23#'&&##\17#\17\23#\21\51\50\54\53"
  .."\52&\3\50\22\23\22\22\21\20\6\7\6\6#\34&'&&\53\52\54\55\54\54"
  .."\23\34\6\7\6\6\21\20\22\23\22\22\51\50\54\55\54\54\53\52&'&&"
  .."\2XXP\19:&rk\49=\45\55ffZJJD\127ZZ\92\91\91\91~}\91\91"
  .."\91\92ZZ~jKKMMKLijLLKLKK\4LbeG\93\14\5C;P*\2T\54?"
  ..">\53\1VZZ\91~}\91\91\91\91\91\91}~\91ZZgJKKjhKLLLLLij"
  .."KKJ\0\3\0\0\0}\4\5N\0\25\0\49\0I\0D@'\13\14\10\17&>\1"
  .."\0\4\23\26>\50J\7\92\20\13\0^,\7\56\20 \7\56YD\47\16"
  .."\50\16\49\0\16\16\48\1\21&&#\34\6\21\20\22\51"
  .."\50\54\55\21\6\6#\34&\53\52\54\51\50\22'\34\6\7\6\6\21\20\22"
  .."\23\22\22\51\50\54\55\54\54\53\52&'&&'\50\22\23\22\22\21\20\6"
  .."\7\6\6#\34&'&&\53\52\54\55\54\54\3`:o:u\56g\50\52r=г=r"
  .."jKKMMKLijLLKLKKk\127ZZ\92\91\91\91~}\91\91\91\92ZZ\4"
  .."\47l\28\27\25\26h\23\22Ȭ\22JKKjhKLLLLLijKKJgZZ\91"
  System.VERA=System.VERA
  .."~}\91\91\91\91\91\91}~\91ZZ\0\2\0\0\3\4f\5\0\7\0\20\0h"
  .."@\54\15\9\10\9\14\10\10\9\17\8\9\8\16\9\9\8B\17\14\9\3\1\15\18"
  .."\12\3\5\1\10\8\0\21\16\15\10\9\8\5\17\13`\11\17`\19\0_\2`\4"
  .."_\6\47\17\23\57\49\0\16<<\50<<\17\23\57\48KSX\7\16"
  .."\5\7\16\4\7\16\4\7\16\5Y\34\1\21#\17#\17#\53!\19\19\51\17"
  .."#\17\3#\3\17#\17\1r\2}r\55q\5^\28\1^\0\1\0\1"
  .."\1\45\30\2B\0\1\1\4\3\6f\0\3\0\49@\9\2\0\4\1<\3\4\16"
  .."\49\0\16\48\0K\14TK\9T\91X\0\4\0\1\0\4\0\4\0@\56\17\55"
  .."\56Y\1\51\1#\2\6f\0\0\2\1?\5F\3\6\16\0\3\0\7\0\92@\14"
  .."\6\2\4\0\8\5a\4\1a\0\8\16\49\0\16<\50\48\0K\10TK\13"
  .."T\91K\14T\91X\0\8\0@\0\1\0\8\0\8\56\17\55\56Y\1K\13TK\14"
  .."T\91X\0\8\0\1\0\8\0\8\0@\56\17\55\56Y\1\51\21#%\51\21#\1?"
  .."\1\6\16\0\0\1\0X\0%\4y\4\0\19\0<@ \13\12\10\3\2\4\0"
  .."\6\12\14\10\18\6\16\8\20\18\14\13\12\8\4\3\2\8\9\5\15\0\20"
  .."\16<\50\23\57\49\0\16<\50<\16<\57\17\18\57\48\19!\19"
  .."\23\7\51\21!\7!\21!\3'\55#\53!\55!X\2}\2\6y}\1J"
  .."\3\1;fժhӬ\0\2\0\0\0\0\4\5\0\15\0\19\0g@\55\13%\15"
  .."\14\12%\15\14\17%\14\15\14\16%\15\15\14B\5\3\11\17\16\1\0"
  .."\7\17\3\13\9\17\16\15\13\12\5\14\10\0\4\8\6\2c\18\10\14\47"
  .."<\50\17\18\23\57\49\0\47<\50\16\16\48KSX\7\16\5"
  .."\7\16\5\7\5\7\5Y\34\1\21!\17!\21!\17!\21!\17!\3#\1\23\3!\17"
  .."\4\1\51\1ee\1x\1\53\5ժF\1\127\5ժ\3\4\0"
  .."\0\3\0\8\4\6\23\0\9\0\19\0+\0k@:+)&\11\10\9\0\4\14\29\31 "
  .."\20\14\3*&\30\3\26\14&\26\31\31\30, #\17*\20\23\11\10\9\0"
  .."\4\6\29#\17)\6+\6\50\23\54\17\50#\53,\16\18\57\17\18\57"
  .."\18\23\57\17\57\57\17\18\57\17\57\57\49\0\47\16\16\17\18"
  .."\57\57\18\57\18\23\57\17\57\57\48\1\22\22\51\50\18\17\52&'\1"
  .."\1&&#\34\2\17\20\22\1\22\18\21\16\2#\34&'\7'\55&\2\53\16\18\51"
  .."\50\22\23\55\23\1s\30T\10\10\1\25sV\5\2)+y=g %"
  .."s\57d\1\47NZ\1\25\1In\45\2QUPe\2QzQQFI\1"
  .."\6\1\1RPJ\0\0\3\0)\0\4\3\0\11\0\23\0\47\0\55@\28$\24\9"
  .."\21\3'!\15\9\45\27\48\12\0$\24\18\6d\30\18d*\48\16\17"
  System.VERA=System.VERA
  .."\57\57\57\57\49\0\16<\50<\50\17\57\57\48\1\22\22\51\50\54"
  .."\53\52&#\34\6\7&&#\34\6\21\20\22\51\50\54\55\54\54\51\50\22\21"
  .."\20\6#\34&'\6\6#\34&\53\52\54\51\50\22\2\57\91=G\91TFBi\56"
  .."\92=G\91SDCj~\47\91w~SNAU}^\2sdlkutcjmvu\127"
  .."۠d|k֥s\0\0\2\0X\0\0\4y\4\0\3\0\15\0\46@\24\9\11\7\4"
  .."\13\5\0\2\6\1\26\8\4\28\12\0\26\14\10\16\16<\50<\50\49"
  .."\0\47<<\48\55!\21!\1\17!\21!\17#\17!\53!\17X\4!\2d\1"
  .."CD\1\4\1L\1I\0\2\0V\0\0\4w\4?\0\6\0\10\0(@\22\6"
  .."\5\3\2\0\5\1\4\7\8\6\7\4\0(\9\2'\11\16<\50\50\57\49\0\47"
  .."\23\57\48\1\21\1\53\1\21\5\1\21!\53\4w\4!\3!\1\1L"
  .."\1K\10\0\0\2\0X\0\0\4y\4?\0\6\0\10\0(@\22\5\4\2\1\0\5\6"
  .."\3\7\9\1\8\4(\7\2\0'\11\16<<\50\57\49\0\47\23\57\48\19"
  .."%%\53\1\21\1\21!\21!X\3#\4!\4!\1V\0\1\0%\0\0"
  .."\4\5\0\24\0\127@D\3%\4\9\4\2%\1\2\9\9\4\2%\3\2\20\0\20\1%\0"
  .."\0\20B\2\7\5\16\12\18\10\23\5\21\7\3\0\14\24\1\17\2\15\8\5"
  .."\3\3\6\4<\11\6e\13\9\30\22\17e\0<\19\15\25\16<\50<\50\18"
  .."\23\57\18\57\17\57\57\49\0\47\50<\50<\50\17\18\57\48KSX"
  .."\7\16\5\7\16\8\7\16\8\7\16\5Y\34\19\51\1\1\51\1\51\21!\7"
  .."\21!\21!\17#\17!\53!\53'!\53\51%\1l\1kV\1oq\1Z"
  .."\5m\2o#o\2\12o#o\0\1\0T\4\4`\0 \0L@*\19\25\31\3"
  .."\22\6\3\9\12\3\1\18\6\15\28\22\0\10\1!\25\11\9 \31\2\0\18"
  .."\9\6\11J\2\6\0F!\16\17\18\57\57\17\18\57\49\0\16\50<"
  .."\17\23\57\17\18\23\57\48\19\17\51\17\20\22\51\50\54\53\17"
  .."\51\17\20\22\51\50\54\55\21\6\6#\34&'\6\6#\34&'\17øxo\127"
  .." !\9\29\28&D\34>K\12\46Y\92\127,T\6\12H\2;\56\10\13"
  .."\23\22OOPNLP\0\2\0\4\23\5\45\0\29\0)\0:@\14\0'!\9\27\6"
  .."'\21\6\15!\27\15\21\1\13@\10*\12$\3\0\30\18$\24*\16\57\57"
  .."\17\57\49\0\16\16\16\17\18\57\17\18\57\48\1\54\54\53\52"
  .."&#\34\6#\34&\53\52\54\51\50\18\17\16\0#\34&\53\52\18\51\50\22"
  .."\7\52&#\34\2\21\20\22\51\50\18\3J\15\15IH\55$$\48e՘"
  .."e\11WOmVPm\2mWKt,\31>bFأ\1\1\91t}t{\1\4\0"
  .."\0\1\0L\4=\5\0\11\0\55\11\5\12\9\0\1\15\0\2\0\9\1\15\0\7"
  System.VERA=System.VERA
  .."\1\14\0\2\1\16@\11\12\11\10\8\5\0\5\1\6\3\12\16<\23\57\49\0"
  .."\16\16\17\18\57\57\48\1!\21!\53\1\1\53!\21!\1\1L\2R\2%"
  .."\3#\2\10Չ\92\3\3P_\0\0\1\0L\4\57\5\0\7\0\31\0\5"
  .."\1\15@\11\1\3\0\8\4\2\6\0\8\16\49\0\16\50\48\19\17!"
  .."\17#\17!\17\3L\7^\7\30\0\0\1\0P\4\4L\0\23\0?@!\11"
  .."\20\14\10\4\17\2\7\14\22\18\2\0\14\20\0\24\21\10\1h\17g\3"
  .."\19g\21f\24\16\17\18\57\49\0\47\50\50\16\17\57\57\57"
  .."\17\18\57\48\19!\21#\17\20\22\51\50\54\55\21\6\6#\34&\53\17!"
  .."\17#\17#P\4\49\49\55\15,\7#J%q\92T\4L@H?\5\1\13\12\2"
  .."H\3\0\0\1\0\4L\6\14\0%\0\49\0 \1\18\0\26\13\1\18\0\19"
  .."\0\26\1\19\0\7\1\17@\9&\10\23\29\4&\16\49\0\16\16"
  .."\48\1\50\19\54\55\18\18\51\50\22\21\20\6#\34&'&&#\34\3\6\7"
  .."\2\2#\34&\53\52\54\51\50\22\23\22\22\1j\14\2\1\12Pd@\55*\57"
  .."\11\6\9\16k\14\4\4\17OeD=!\48\15\9\11\2l\57\2\3\1TA\54"
  .."?&#\15Hn!bSA\56?\29\28\17T\0\3\1\14\1\3\5\0\10\0%\0)"
  .."\0d@\54\9\6\0\25\31\11\23\14\6\0(&\0\23&\6\12\17 \31\28"
  .."\17#*&\31\20\0\23\9\3('\24\13\9j\11k\31\3j\20i*\16\50"
  .."\50\17\18\57\57\17\18\57\49\0\16\16\16\17\18\57"
  .."\18\57\17\57\17\18\57\48\1\34\6\21\20\22\51\50\54\53\53\55\17"
  .."#\53\6\6#\34&\53\52\54\51\51\53\52&#\34\6\7\53\54\54\51\50\22"
  .."\1!\21!\2|WHi\49Rwu\51}CD?k\2d\4PDN@Ms\29="
  .."@pABt\4Z\92#!\127\28\28\12{\0\0\3\0\1\3\5\0\11\0\23"
  .."\0\27\0\51@\28\26\24\6\18\0\12\28\25\15\9\24\21\3\9j\15"
  .."k\3j\21i\28\16\17\18\57\17\18\57\49\0\16\48\1\34\6"
  .."\21\20\22\51\50\54\53\52&'\50\22\21\20\6#\34&\53\52\54\3!\21"
  .."!\2hfssfeusgʫ˫\2\92\5{u༻߻`{\0\0\1\0J\0"
  .."\0\4\5\0\31\0>@#\24\8\30\18\14\3\1\16\0\2\30\27\14\17q\21"
  .."\30q\27\15r\21o\11p\0r\27o\5l \16\16\16\57\17\18\57\49"
  .."\0\47<\23\50\48\51\53\51&\2\53\16\0\51\50\0\17\20\2\7\51\21"
  .."!\53\54\18\53\52\2#\34\2\21\20\18\23\21J{n\1 \1!o{\49x"
  .."x\1 \1\55\1oȼ߅L\1I\1\9L\0\0\3\0)\4"
  .."\4{\0\10\0\19\0C\0@I=\55\15\48\12\18\3\54\11%\8\0\30C\11\1"
  System.VERA=System.VERA
  .."\31\30\27\8\34\55\54\15\46\11\20\1\51\15@:(\34D\2\5"
  .."\0\24%=\3\47\18\46\5\21\18M\47\0u\30\11M\20C\5M\54+sD\16"
  .."\50\18\57\17\18\23\57\17\18\57\49\0\16\50<\50<\50\16"
  .."\16<\17\18\57\18\57\17\57\17\18\23\57\17\18\57\48@\9\48"
  .."\53\48\54\48\55\48\56\4\93\1\53#\34\6\21\20\22\51\50\54\1\53"
  .."\52&#\34\6\29\1\5!\14\1\21\20\22\51\50\54\55\21\14\1#\34&'\14"
  .."\1#\34&\53\52\54;\1\53\52&#\34\6\7\53>\1\51\50\22\23>\1\51\50"
  .."\22\17\2\31\49xYS\92J\1MWWL\1\21\1\1epO\50\55Gn 'a"
  .."ȿuc^\56>M<\91|%!Y\1HZqYa\1\52+\15#\34\51\51"
  ..")+RNPPXx+'#!?@=B\0\0\3\0\47\4\4\0\9\0\19\0+\0s@"
  ..">+,&\31\29\26\19\10\1\0\4\13)& \20\13\4*&\30\26\4&\13\26&"
  ..",+,*\20\23\16 \30#\19\10\1\0\4\7)\23\16\29\7\31\7\18#D\16\18"
  .."\23>,\16\18\57\17\18\57\18\23\57\17\57\57\17\18\57\57\17"
  .."\57\49\0\16\16\16\16\17\18\57\57\18\57\18\23\57\17\57\57"
  .."\17\18\57\48\1\1\22\22\51\50\54\53\52&'&&#\34\6\21\20\22\23\7"
  .."&&\53\16\18\51\50\22\23\55\23\7\22\22\21\16\2#\34&'\7'\3m\49"
  .."$eA\12H#cC\14\14')d<\93*,g\57\92\3\12\47\47"
  .."\52o\48\46\48tGGq\1\30\1\46\55\56MBz;<L\0\0\2\0"
  .."\3\5\0!\0%\0@G\11\10\9\8\7\5\12\6%\25\26\25\3\4\2\2\5%"
  .."\26\26\25B!\26\5\2\4\6\25\0\16\15\12\0\34$\12\19$&\6#\25"
  .."\22\9\31\5\0\3\29\1\26#\9)\22\15\29\3\1\15\34\30#&\16\16"
  .."\17\57\17\18\23\57\17\18\57\18\57\49\0\16\16\16\18\57"
  .."\57\23\57\48KSX\7\16\4\17\23\57\7\16\4\17\23\57Y\34\1\51\21"
  .."\20\6\7\7\6\6\21\20\22\51\50\54\55\21\6\6#\34&\53\52\54\55\55"
  .."\54\54\53\52\53\54\53\19#\53\51\2%=TZ>\47mNb^hC^XC&\2"
  .."\4DbRY;X\49YnED\57\56L\92V@T?\1\4\23\19\1\14\0\2\2\4"
  .."\0\0\2\5\0\3\0\9\0\30@\14\6\0\1\4\7\6\8\2\3\4\0\10\16<"
  .."\50\57\57\49\0\47\48\1\53\51\21\3\17\19\51\19\17\2\4\21"
  .."\21\4)\2\1eq\0\0\1\0X\1s\4y\3^\0\5\0\24@\11\4\2\0\6"
  .."\3\28\1\0'\6\16\49\0\16\48\19!\17#\17!X\4!\3^\21\1"
  .."?\0\1\0;\4\6\0\10\0\47@\26\10\3\2\1\0\5\11\5\4\8\6\11\10"
  .."\9\8\7\4\3\2\7\5\0\11\5\1\11\16\18\57\17\23\57\49\0\16"
  System.VERA=System.VERA
  .."\18\23\57\48\19'%\19\1\51\21#\1#\3d)\1#\1Ӕ\47\6\127\2}b"
  .."%\5\3\57\0\1\0\0V\4\6\20\0#\0@N\8\23\29\30\29\2\3\4\5"
  .."\6\5\1\7\23\30\30\29\17\16\15\14\13\5\18\12\23\25\26\25\11\23"
  .."\26\26\25B\25\12\19\10\7\30\1\26\10\8\19\18\22\15\1\0\4"
  .."!\15\28\8$\30\29\27\26\25\12\11\9\8\7\10\0\18\47\23\57\49"
  .."\0\16\50\16\16\50\18\57\57\17\18\57\57\48KSX\7\16\5"
  .."\7\16\5\17\23\57\7\16\5\17\23\57\7\16\5Y\34\1\21&&#\34\6"
  .."\7\3!\21!\3\2\6#\34&'\53\22\22\51\50\54\55\19#\53!\19\54\54\51"
  .."\50\22\4$R,fs\18\45\1\47d+Ǻ\57f\46\49d\48`y\26u\1\19\49"
  .."\26Ɣ\49c\5\28\29|ɏ\21\22\31!\2\1J\18\0\2\0"
  .."X\1\49\4y\3\0\27\0\55\0K@&\29' \49\48+\3\53\28\1\11\4\15\25"
  .."\11\18\0\25\14\4* \53'\46\28\56\49\48\28\0*\14\56\16<\50"
  .."\57\57\49\0\16<\50<<\18\57\17\18\57\17\18\23\57\17\18"
  .."\57\48\1\21\6\6#\34'&'&&#\34\6\7\53\54\54\51\50\22\23\22\23\22"
  .."\51\50\54\19\21\6\6#\34'&'&&#\34\6\7\53\54\54\51\50\23\51\22"
  .."\23\22\51\50\54\4yKOZq\22\11Mg\51OINS\53dK\10\22t\93FJK"
  .."OZq\22\11Sc\49NJOR`\1\11\22t\93D\3ï;\55\51\10\4\34\24;@"
  .."<\55\22 \4\11\54<а;\56\51\10\5$\23<A>\55\55\5\10\55=\0\0"
  .."\2\0\0\4\5\0\3\0\6\0O@*\4i\5\4\2\3\2\6i\3\3\2\5i\0\1\0\4"
  .."i\6\4\1\1\0B\4\1\5\1\0\6\5\4\2\1\5\7\3\0\7\16\17\23\57\49"
  .."\0\47\17\57\48KSX\7\16\8\7\16\5\7\16\5\7\16\8Y\34#\1\51"
  .."\9\2!\6\2\6\2\8\2\5q\4\0\0\2\0w\0\4\18\4#\0\6\0\13"
  .."\0\47@\23\9\2\11\4\7\0\14\2\12\5\9\0\10\7v\12\3\0v\5\14\16"
  .."<\50\17\57\17\18\57\49\0\16<\50\57\57\48\1\21\1\1\21\1"
  .."\53\1\21\1\1\21\1\53\2L\1\45+\3\1\45+\4#\1R\1"
  .."\1R\0\0\2\0\0\4\92\4#\0\6\0\13\0\47@\23\12\5\10\3\7"
  .."\0\14\5\8\1\12\7\1v\3\0\8v\10\7\14\16<<\18\57\17\18\57\49"
  .."\0\16<\50\57\57\48\1\1\21\1\53\1\1%\1\21\1\53\1\1\2\1+\1"
  .."\45:\1+\1\45\4#^R^\1\12\1\12^R^\1\12\1\12\0\3\0"
  .."P\0\0\4\127\1\49\0\3\0\7\0\11\0#@\17\8\4\0\10\6\2\4\29\5\8\29"
  .."\9\1\29\0\12\16\49\0\47<<\50\50\48\19\51\17#\1\51\17#"
  .."\1\51\17#P\3\51f\1\49\1\49\1\49\0%\0\0\4\7k\0"
  System.VERA=System.VERA
  .."'\0$\0\0\0\0\0\7\1\6\0\0\1u\0%\0\0\4\7^\0'\0$\0\0\0\0\0\7"
  .."\1\5\0\0\1u\0u\4\92\7^\0'\0\50\0\0\0\0\0\7\1\5\0\0\1u\0\2"
  .."\0H\0\0\4\5\0\16\0\25\0;@\31\14\12\17\10\8\23\0\12\1\23"
  .."\17\8\2\20\15\11\30\24\9\13\0\45\20\30\5\26\16\50\18\57"
  .."\57\57\57\49\0\47\50\50\16\48%\21! \2\17\16\18!!\21!\17"
  .."!\21!\17\1\34\6\17\16\22\51\51\17\4\1(\2R\1H"
  .."=\1M\1\1\1KF\4\4\0\3\0\14\4\4{\0\10\0\22"
  .."\0\56\0i@\57\50\47\9\6\0\25\31\23& \11\56\23\0 \31\11\0\23"
  .."\28\11#\23\17\6\53\47)#\57\0\3\50&\24\9M\14u\31\3M\23C\20"
  .."M,s\57\16\50\57\57\17\57\49\0\16\50<\50\16\50\16"
  .."\16\17\18\57\17\18\57\17\18\57\17\18\57\17\57\48\1\52\54\53"
  .."\52&#\34\6\21\21\1\50\54\53\16&#\34\6\17\16\22\1!\21\20\22\51"
  .."\50\54\55\21\6\6#\34&'\6\6#\34\2\17\16\18\51\50\22\23\54\54\51"
  .."\50\22\17\4\23\2PVWMfRPhgPP\3\21cpP\47;}Jb\48\52T"
  .."Y\47%W\2\11&\9+\1#\1T\53\51+)CBDA\1\20"
  .."\1\56\1\56\1\20>A>A\0\1\0\0\1\4\2y\0\3\0\16\2\0\4\1\0"
  .."\47\49\0\16\48\17!\21!\4\47\2y\0\0\1\0\0\1\4\2y\0\3\0"
  .."\15\2\0\4\1\0\47\49\0\16\48\17!\21!\4\47\2y\0\2\0\3"
  .."\3\6\20\0\5\0\11\0%@\18\6\0\9\3\12\3\4\0\29\1\7\29\6\9\10"
  .."\12\16\49\0\16<\50\48\1#\53\19\51\3\5#\53\19\51\3\3"
  .."Ěb\53Ǚb\3\1~\1~\0\2\0\3\3\6\20\0\5\0\11\0'@"
  .."\19\9\3\6\0\12\9\10\6\3\4\1\29\0\6\29\7\12\16\16\49"
  .."\0\16<\50\48\1\51\21\3#\19%\51\21\3#\19\3\0řb\53Ěb\6\20"
  .."\1\127\1\127\0\1\1\3\3\45\6\20\0\5\0\24@\11\0\3\6"
  .."\3\4\0\29\1\6\16\49\0\16\48\1#\53\19\51\3\2Ěb\3\1"
  .."~\0\0\1\1\3\3\45\6\20\0\5\0\24@\11\3\0\6\3\4\1\29\0\6\16"
  .."\49\0\16\48\1\51\21\3#\19\2\49řb\6\20\1\127\0\0\3"
  .."\0X\0\4y\4o\0\3\0\7\0\11\0'@\19\2\0\4\6\8\0\10\12\9\5\1w"
  .."\8\4\0\12\16<<\49\0\16\16\48\1\51\21#\17\51\21#\5!"
  .."\21!\1j\4!\1\3\0\0\2\0u#\4\92\6u\0\3\0\7\0\34"
  .."@\17\2\6\0\8\4\6\8\6\4\3\2\1\0\6\5\7\8\16\23\57\49\0\16\17"
  .."\57\18\57\48\9\7\2h\127\1\1\127\1\12\13\5\3\57\4"
  System.VERA=System.VERA
  .."%\4\45\0hV\4\6\16\0'\0\92\0\0\0\0\0\7\0\0\0\0\0\0"
  .."%\0\0\4\7N\0'\0<\0\0\0\0\0\7\1\3\0\0\1u\0\1\0fB\4\55\5\0\3"
  .."\0\24@\11\2\0\4\1\30\0\2\30\3\4\16\49\0\16\48\1\51\1#"
  .."\3y\5m\0\2\0\0\4L\4B\0\11\0\47\0@\26 \22\27\23\14(\45"
  .."\13\24\30\27\9*\12\45'!\21\15\4\3\9\31\23\27\1\0@'\3)\13\45"
  .."\48\31)$ \13\23\18\14!'$\6\15\21\18*\30\24\12\4\6\0x\22\14\18"
  .."y\6x( $\48\16\50\50\17\23\57\17\57\57\17\18\57\57\17\18"
  .."\57\57\17\18\57\57\49\0\16\50\50\17\23\57\18\57\57\17\18"
  .."\57\57\17\18\57\57\17\18\57\57\48\1\52&#\34\6\21\20\22\51\50"
  .."\54\3\55\23\7\22\22\21\20\6\7\23\7'\6\6#\34&'\7'\55&&\53\52\54"
  .."\55'\55\23\54\54\51\50\22\3d|\91Z}}Z\91|\24Z\30\29\30\31^"
  .."\46\91\50\48`\48\92\31\29\31\31^\46\91\51\46^\2Z{{Z\92"
  .."}~\1t\93\49\93\48\50\91\45^\31\30\29\28Z\51\93\46\50\93"
  .."\45_\31\30\29\0\0\1\1Z\0\3\47\4#\0\6\0\26@\12\2\4\0\7\2"
  .."\3\0v\5\7\16\50\57\49\0\16\57\48\1\21\1\1\21\1\53\3\47"
  .."\1\45+\4#\1R\0\1\1\0\3y\4#\0\6\0\26@\12\5\3\0\7\5"
  .."\1v\3\0\7\16<\57\49\0\16\57\48\1\1\21\1\53\1\1\1\1+\1"
  .."\45\4#^R^\1\12\1\12\0\0\2\0#\0\0\4\55\6\20\0\3\0\25\0N@"
  .."*\20\9\22\2\18\14\10\5\4\2\0\4\10\16\12\6\25\9\4\13\0\6"
  .."\1\4\15\9\6\11\1J\19E\21\17E\26\16<\50<\16\50\17\18\57"
  .."\57\49\0\47<\16\16\50\18\57\57\57\48\1\51\21#'\21#\34\6"
  .."\21\21!\17#\17!\17#\17#\53\51\53\52\54\51\3\127wcM\2%"
  .."ɩ\6\18Qge\3\47\3яN\0\1\0#\0\0\4\55\6\20\0\21\0B"
  .."@#\16\7\18\3\14\10\8\3\0\8\12\1\4\21\9\7\2\6\0\9\11\7\6\0"
  .."J\15E\17\13E\22\16<<\16\17\18\57\57\49\0\47<\16\50"
  .."\18\57\57\57\48\1\17#\17!\34\6\21\21!\21!\17#\17#\53\51\53\52"
  .."\54\51\4\55cM\1%۸ɩ\6\20\5{Qge\47\3яN\0\1\0;"
  .."\4\47\5\0\19\0<@\31\18\6\0\16\8\14\10\12\4\0\2\12\20\15"
  .."\0R\17\13\1Q\9\5R\11\7\3\20\16<<\50<<\50\49\0\16\50\16"
  .."<\50\16\50\48%!\17#\17!\53!\17!\53!\17\51\17!\21!\17!\4\47"
  .."\1n\1n\1n\1n\92\1\2\31\1\92\0\1\1\2\47\2"
  .."\3`\0\3\0\21\0\2\1\1\0\4\1\29\0\4\16\49\0\16\48\1\51\17"
  System.VERA=System.VERA
  .."#\1\3`\0\0\1\1\2\1\47\0\5\0\26\3\0\1\1\6\3\4\1\29"
  .."\0\6\16\49\0\16\48\1\51\21\3#\19\1Śc\1\47\1\127\0"
  .."\0\2\0\3\1\47\0\5\0\11\0*\9\3\6\0\1\1@\13\12\9\10\6\3"
  .."\4\1\29\0\6\29\7\12\16\16\49\0\16<\50\48\1\51\21\3"
  .."#\19%\51\21\3#\19\3\0řb\53Ěb\1\47\1\127\1\127\0\0"
  .."\7\0\0\0\0\4\5\0\3\0\15\0\27\0'\0\51\0?\0K\0t@\14\3\2%\31\1"
  .."\49\0=\13\19\31\49\1\2%+C\19\1\2@&\55\7I\25\3F\2:\52"
  .."\1(\0\28\16:PFz\52P@\10P\22z\4P\16\34P\46z\16\28P@(\47\16"
  .."\16\17\18\57\18\57\17\18\57\17\57\49\0\47<\50\50"
  .."\16\50\57\18\57\17\18\57\57\48\19'\1\23\1\20\22\51\50\54\53"
  .."\52&#\34\6\7\52\54\51\50\22\21\20\6#\34&\19\20\22\51\50\54\53"
  .."\52&#\34\6\7\52\54\51\50\22\21\20\6#\34&\1\20\22\51\50\54\53"
  .."\52&#\34\6\7\52\54\51\50\22\21\20\6#\34&H%\4\20'H_EDbcCE_y"
  .."xxwyLaEEacCEayyxxy\3\12aEF`bDEayyxxy\2\55a\1`JG"
  .."acECcaEyxy\3EaaECcaExxy\34GaaGCcaExxy\0%\0\0"
  .."\4\7m\0'\0$\0\0\0\0\0\7\1\7\0\0\1u\0\0\0\4N\7m\0'\0(\0\0"
  .."\0\0\0\7\1\7\0\18\1u\0%\0\0\4\7k\0'\0$\0\0\0\0\0\7\1\4\0\0"
  .."\1u\0\0\0\4N\7N\0'\0(\0\0\0\0\0\7\1\3\0\18\1u\0\0\0\4N"
  .."\7k\0'\0(\0\0\0\0\0\7\1\6\0\18\1u\0\0\0\4\6\7k\0'\0,\0\0\0"
  .."\0\0\7\1\4\0\0\1u\0\0\0\4\6\7m\0'\0,\0\0\0\0\0\7\1\7\0\0\1"
  .."u\0\0\0\4\6\7N\0'\0,\0\0\0\0\0\7\1\3\0\0\1u\0\0\0\4\6\7"
  .."k\0'\0,\0\0\0\0\0\7\1\6\0\0\1u\0u\4\92\7k\0'\0\50\0\0\0\0"
  .."\0\7\1\4\0\0\1u\0u\4\92\7m\0'\0\50\0\0\0\0\0\7\1\7\0\0\1"
  .."u\0u\4\92\7k\0'\0\50\0\0\0\0\0\7\1\6\0\0\1u\0\4=\7k"
  .."\0'\0\56\0\0\0\0\0\7\1\4\0\0\1u\0\4=\7m\0'\0\56\0\0\0\0"
  .."\0\7\1\7\0\0\1u\0\4=\7k\0'\0\56\0\0\0\0\0\7\1\6\0\0\1u\0"
  .."\1\0\0\0\4D\4`\0\9\0\34@\18\8\0\6\2\4\3L\1\6\5L\0K\7\10\16"
  .."\49\0\47\50\48\1!\17!\21!\53!\17!\1\0\1\1mn\1m\4"
  .."`\47\3B\0\1\1)\4\3\6f\0\6\0\55@\12\4\5\2\0\7\4\2\11\6"
  .."\7\16\57\49\0\16\50\57\48\0K\9TK\14T\91X\0\7\0\1\0\7"
  .."\0\7\0@\56\17\55\56Y\1\51\19#'\7#\2\31\6f\0\1\1\31"
  .."\5\29\3\6\55\0\27\0@!\0\18\7\14\11\4\1\18\7\15\11\4\18\25"
  System.VERA=System.VERA
  .."\7\4\21\11\28\15\1\14\0\7\21P\22\7P\8\28\16\17\57\57\57"
  .."\57\49\0\16<<\17\18\57\17\18\57\17\18\57\17\18\57\48\0K"
  .."\9TK\12T\91X\0\28\0\1\0\28\0\28\0@\56\17\55\56Y\0K\15TX"
  .."\0\28\0@\0\1\0\28\0\28\56\17\55\56Y@?\9\0\12\10\12\11\12\12"
  .."\11\15\11\16\15\17\15\18\15\19\15\20\15\21\15\22\15\23\9\27\25"
  .."\0\25\1\27\10\27\11\27\12\27\13\27\14\27\15\27\16\27\17\27\18"
  .."\27\19\31\20\31\21\31\22\26\23\25\27\31\1\93\1'\46\1#\34\6\7"
  .."#>\1\51\50\22\31\1\30\1\51\50\54\55\51\14\1#\34&\2d\57\21!\14"
  .."&$\2|\1f\91'@%\57\21!\13'$\1}\1f\91'@\5Z\55\20\19JQ\28!\55"
  .."\20\19JQ\28\0\0\1\1=\5b\3\5\0\3\0\17\2\0\4\1\0\4\16\49"
  .."\0\16\48\1!\21!\1=\2V\5\0\1\1\47\5)\3\6H\0\13\0\56\0"
  .."\11\1\3@\12\4\7\0\14\7P\8\1P\0\14\16\49\0\16<\48\0K"
  .."\9TX\0\14\0\1\0\14\0\14\0@\56\17\55\56Y\1\51\30\1\51\50\54"
  .."\55\51\14\1#\34&\1\47w\11`WU`\14w\11\6HLJJL\0\1\2\2\5"
  .."D\2\6\16\0\3\0\54@\9\2\0\4\1a\0\4\16\49\0\16\48\0K\10"
  .."TK\13T\91K\14T\91X\0\4\0@\0\1\0\4\0\4\56\17\55\56Y\1\51"
  .."\21#\2\2\6\16\0\0\2\1V\4\3{\7\6\0\11\0\23\0W\15\9\1\4"
  .."@\12\21\3\24\12P\0{\18P\6\24\16\49\0\16\48\0K\9TK"
  .."\12T\91X\0\24\0\1\0\24\0\24\0@\56\17\55\56Y\1K\9TX\0\24"
  .."\0@\0\1\0\24\0\24\56\17\55\56Y\1\20\6#\34&\53\52\54\51\50\22"
  .."\7\52&#\34\6\21\20\22\51\50\54\3{tsst{X@@WW@@X\5sss"
  .."s?XW@AWX\0\0\1\1u\3)\0\0\0\19\0'\9\6\10\13\1\6\0\6\1\5@\9"
  .."\0\9\16\19\0\16|\3\20\16\16\49\0\47\18\57\48!\22\22\21"
  .."\20\6#\34&'\53\22\22\51\50\54\53\52&'\2\56\53xv\45W,\34K\47"
  ..":=,,>i\48Y\91\12\12\17\15\48\46\30W=\0\2\1X\4\4\23\6f\0\3\0"
  .."\7\0Z@\17\6\2\4\0\8\0\7\3\4\1\5\7\1\3\8\16\17\57\17\18"
  .."\57\49\0\16<\50\48\0K\9TK\14T\91X\0\8\0\1\0\8\0\8\0@\56"
  .."\17\55\56Y\1K\9TX\0\8\0@\0\1\0\8\0\8\56\17\55\56Y\1\51\3"
  .."#\1\51\3#\2\23\2\12\6f\1x\0\1\1u\3\25\0\0\0\19\0"
  .."\34\11\14\10\7\1\6@\9\14\0\1\0\10\4|\17\20\16\49\0\47"
  .."\18\57\48!\51\6\6\21\20\22\51\50\54\55\21\6\6#\34&\53\52\54"
  .."\2\16w\45+\55\54 >\31&D\30zs\53=X\31\46\46\15\15\10\10W\93\48"
  System.VERA=System.VERA
  .."i\0\1\1)\4\3\6f\0\6\0\55@\12\3\0\4\1\7\3\5\11\1\7\16\57"
  .."\49\0\16<\57\48\0K\9TK\14T\91X\0\7\0\1\0\7\0\7\0@\56\17"
  .."\55\56Y\1\3\51\23\55\51\3\2\31\4\1x\0\1\0\0\4s\5"
  .."\0\13\0\55@\30\12\11\10\4\3\2\6\0\6\0\8\3\4\7\1\11\14\0\12"
  .."\5\1\30\7\49\9\0\52\14\16<\50\46\17\18\57\17\18\57\57\49\0"
  .."\47\17\23\57\48\19\51\17%\23\1\17!\21!\17\7'\55\1;Nw\2"
  .."dP\5o\2;jn\0\0\1\0L\0\0\4\10\6\31\0\21\0>@!\20\19"
  .."\18\12\11\10\6\9\0\3\14\16\3\5\11\12\22\15\19\3\6\20\4\17"
  .."\0\6\15\13\9\22\16<<\50\57\57\57\17\18\57\57\49\0\47\17"
  .."\57\57\23\57\48\1\20\22\51\51\21#\34&\53\17\5'\1\17!\53!\17%"
  .."\23\1\2\127\91Y饵P\1{\1\1;Pu\1|~\1$o\1\8\2\47"
  .."n\0\4J\7m\0'\0\54\0\0\0\0\0\7\1\8\0\0\1u\0\4\6"
  .."\6f\0'\0V\0\0\0\0\0\7\0\0\0\0\0\0\0\0\4\7m\0'\0=\0\0\0\0"
  .."\0\7\1\8\0\0\1u\0\0\0\4\16\6f\0'\0\93\0\0\0\0\0\7\0\0\0\0"
  .."\0\0\2\2\18\2\5\0\3\0\7\0!\0\5\1\7\0\4\0\0\1\7\1\8\4\0"
  .."\4\6\2\8\16<\50\49\0\16\48\1\17#\17\19\17#\17\2\5"
  .."\10\2\0\10\2\0\2\0\8\0\0\4N\5\0\12\0\25\0;@!\23\8\10\19"
  .."\0\13\21\10\6\19\13\6\0\4\22\20\16\50\3\49\9\48\24\20\30\11"
  .."\7\48\26\16<\50\16\23\57\49\0\47\50\16\50\48\1 \0"
  .."\17\16\0!!\17#\53\51\17\1\50\54\17\16&!#\17!\21!\17\1\1V\1D"
  .."}}\1\47\0`\1\8\5\2ŕ\2{\1H\1K+\0"
  .."\0\2\0\4H\6\20\0\26\0)\0@O\18\23\19\18\1\0\13\14\15\16\4"
  .."\17\23\0\1\0\22\23\23\24\23\21\23\20\21\24\24\23B\26\25\24\21"
  .."\20\19\6\22\15\30\18\0\22\30\12$\6\12\22*\18\21\24\3'\20"
  .."\19\22\3!\9\26\25\3\15\0!'\18\3D!\18\9>*\16\17\57\57\17\57"
  .."\57\17\18\23\57\17\23\57\49\0\16\16\18\57\57\18\57\18\23"
  .."\57\48KSX\7\16\8\7\16\5\7\16\5\23\57\7\8Y\34\1\22\18\21\16"
  .."\2#\34\2\17\16\18\51\50\22\23&&'\5'\55'\51\23%\23\3&&#\34\6\21"
  .."\20\22\51\50\54\53\52&\2Ŷ\34#\15!H&\30\127\1!!"
  .."#R\45:\5\47\1(\1\12\1\9\1(\2\2\45Y,\92bPȑ^b\23"
  .."\13\13n\0%\0\0\4\7k\0'\0<\0\0\0\0\0\7\1\4\0\0\1u"
  .."\0hV\4\6f\0'\0\92\0\0\0\0\0\7\0\0\0\0\0\0\2\0\0\0\4\5\0"
  System.VERA=System.VERA
  .."\8\0\21\0\52\1\18\0\11\1\8@\19\9\20\8\2\18\12\0\5\50\15"
  .."\56\19\10\0\30\9\51\22\16\50\50\17\57\57\57\57\49\0\47"
  .."\48\1\17\51\50\54\53\52&#\1\51\17\51 \22\21\20\6!#\17#\1"
  .."ꞝL\1\4\4!󄃃\1\0\0\2\0V\4T\6\31\0"
  .."\16\0\28\0\51@\28\5\0\26\20\8\26\14\8\1\3\29\17\18\11G"
  .."\23\4\0\6\2F\29\16\50\50\49\0\16\16\17\57\57\48%\17"
  .."#\17\51\17\54\54\51\50\18\17\16\2#\34&\1\52&#\34\6\21\20\22\51"
  .."\50\54\1w\46df\1\7SWW\1"
  .."\0\1\0X\2\45\4y\2\0\3\0\17\0\2\4\1\0\4\16\49\0\16\48"
  .."\19!\21!X\4!\2ת\0\0\1\0\0\4;\4T\0\11\0\46@\28\10\8\7\6\4"
  .."\2\1\0\8\11\9\5\3\12\11\10\9\8\7\5\4\3\1\9\6\2\0\12\16<\23"
  .."\57\49\0\16<\50\23\57\48\19\1\1\55\1\1\23\1\1\7\1\1\1^t"
  .."\1^\1_t\1\92t\1%\1\92\1^u\1^uw\1^\0\0\1\1X\2\3"
  .."\5\0\10\0\57A\11\0\7\0\0\1\9\0\9\0\3\1\9\0\4\0\9\1\10\0\2\1"
  .."\9@\13\5\11\8a\6W\3}\0a\1\11\16\49\0\16\16\50\48"
  .."\1\51\17\7\53\55\51\17\51\21!\1j\3\10\2c)t'+n\0\0\1\1"
  .."B\2\3}\5\0\24\0a@\19\0W\4\5\4\22\23\2\21\24W\5\5\4B\5\24\14"
  .."\0A\9\1\9\0\2\0\14\1\9\0\15\0\2\1\10\0\11\1\9@\14\18\25\5\0"
  .."\24\14\8\127\1\21\14\3\25\16\17\57\57\57\49\0\16\16"
  .."\17\57\57\48KSX\7\16\4\17\23\57\7\16\5Y\34\1!\21!\53\55\54"
  .."\54\53\52&#\34\6\7\53\54\54\51\50\22\21\20\6\7\1\1eQdR\49"
  .."q?Ay;Jw\3\14rnaz\51=L$$}\28\28k\57wu\0\0\1\1F\2\3\5\0"
  .."(\0\92A\20\0\0\0\19\1\9\0\21\0\10\1\9\0\9\1\11\0\21\0\13\1\9"
  .."\0\6\0\31\1\9\0 \1\11\0\6\1\10\0\28\1\9@\19#)\22\19\13\0\3\20"
  .."\25\127&\16\127\3\31\20\9)\16\17\23\57\57\49\0\16"
  .."\16\16\57\48\1\22\22\21\20\6#\34&'\53\22\22\51\50\54\53"
  .."\52&##\53\51\50\54\53\52&#\34\6\7\53\54\54\51\50\22\21\20\6\2"
  .."^c:r;Eq\45evnmBJ\93b`W,p;Eu\50X\4`\21lP|\21\20y\27\26Q"
  .."DJLl?<\56?\24\23y\17\18vcG\93\0\27\4Z\6{\0'\0\0\0'\1"
  .."\9\0\0\0\0\0\7\1\10\0V\0\27\4Z\6{\0'\0\0\0'\1\9\0\0"
  .."\0\0\0\7\0\0V\0\27\4Z\6\0'\0\29\0\0'\1\9\0\0\0\0\0"
  .."\7\1\10\0V\0f\4P\7m\0'\0*\0\0\0\0\0\7\1\11\0\0\1u\0{"
  System.VERA=System.VERA
  .."H\4\18\6H\0'\0J\0\0\0\0\0\7\0\0\0\0\0\0\0\0\4\6\7P\0'\0"
  ..",\0\0\0\0\0\7\1\12\0\0\1u\0u\4J\5\0'\0\54\0\0\0\0\0\7\0"
  .."\0\0\0\0\0u\4\6\4{\0'\0V\0\0\0\0\0\7\0\0\0\0\0\0\4"
  .."\49\7k\0'\0&\0\0\0\0\0\7\1\4\0Z\1u\0\4%\6f\0'\0F\0\0\0\0"
  .."\0\7\0\0Z\0\0\0\4\49\7m\0'\0&\0\0\0\0\0\7\1\8\0Z\1u\0"
  .."\4%\6f\0'\0F\0\0\0\0\0\7\0\0Z\0\0\0\2\0{\4\6\20\0\24\0"
  .."$\0H@\9\13\0\34\28\7\3\9\1\1\12@\28\34\22\28\16\22\5\11"
  .."\2\31\12\4\3\0\6\8\10\6G\25\18\19H%\16<\23<\49\0\47"
  .."\16<\50\17\18\57\57\48\1\17!\53!\53\51\21\51\21#\17#\53\6"
  .."\6#\34\2\17\16\18\51\50\22\1\20\22\51\50\54\53\52&#\34\6\3Z"
  .."\1\49\46de\15\3\1\53yySW\1;\1\21\1"
  .."\17\1\55W\11\0\0\1\1d\1\3m\2\0\3\0\17\0\2\4\1\0\4"
  .."\16\49\0\16\48\1!\21!\1d\2\9\2\0\1\1\2\47\2\3`\0\3"
  .."\0\21\0\2\1\1\0\4\1\29\0\4\16\49\0\16\48\1\51\17#\1"
  .."\3`\0\0\1\0%\4%\5\0\51\0p@<\13\0\49\15&\24\22\31 \28"
  .."(\22#\7\6\10\3#\52\51('\49)\45\24\22\16\3\19\15\23\14&"
  .."\0\45\25\13\23\19\14\50'\19\30\31\6\23\45\52\16\50\50\17"
  .."\18\57\57\18\57\57\17\18\57\17\23\57\18\57\57\17\57\57\49\0\16"
  .."\16\50\16\50<\50\48\19\18\0\51\50\22\23\21&&#\34"
  .."\6\7!\7!\6\6\21\20\22\23!\7!\22\22\51\50\54\55\21\6\6#\34\0\3"
  .."#\55\51&'&\53\52\55\54\55#\55\48\1\18TJBN\24\1\49F\2"
  .."\1\1\1\1i\49\23OCHU,\49u\1\1\2\2\1\1\49\3\1\27\1"
  .."!(*=Dl\20\45\46\15&\23nC>*(\1 \1\28n\12\20\45\15\18\47"
  .."\19\11l\0\2\1?\5\14\3\5\0\3\0\7\0Q@\13\4\0\6\2\8\5a\4\1a\0"
  .."\8\16\49\0\16<\50\48\0K\14TX\0\8\0@\0\1\0\8\0\8\56"
  .."\17\55\56Y\1K\14TK\13T\91X\0\8\0\1\0\8\0\8\0@\56\17\55\56"
  .."Y\1\51\21#%\51\21#\1?\1\5\0\1\1\4\3Z\5\0\3\0k\0"
  .."\2\4\1\3\4\16\49\0\16\48\0K\12TX\0\4\0\1\0\4\0\4\0@\56"
  .."\17\55\56Y\0K\14TX\0\4\0@\0\1\0\4\0\4\56\17\55\56Y@&\15\0"
  .."\15\1\10\2\10\3\31\0\31\1\31\2\31\3\47\0\47\1\47\2\47\3\12\15"
  .."\0\15\1\31\0\31\1\47\0\47\1\6\93\1\93\1\51\3#\2\5\0\1"
  .."\1\31\5\14\3\5\0\29\0@\30\22\16\15\3\19\12\7\1\0\3\8\4\23"
  System.VERA=System.VERA
  .."\12\19\27\8\30\16\1\15\0\7\22\24\7\9\30\16\17\57\57\57\57"
  .."\49\0\16<<\17\23\57\17\18\23\57\48\0K\14TK\17T\91X\0\30"
  .."\0@\0\1\0\30\0\30\56\17\55\56Y@t\9\0\9\1\15\11\15\12\15\13"
  .."\13\14\15\15\15\16\15\17\15\18\15\19\15\20\15\21\15\22\15\23"
  .."\15\24\11\25\26\0\26\1\29\11\29\12\29\13\30\14\31\15\31\16\31"
  .."\17\31\18\31\19\31\20\31\21\31\22\31\23\31\24!\15\1\15\2\15\3"
  .."\15\4\15\5\15\11\15\12\15\13\15\21\15\22\15\23\15\24\31\1\31"
  .."\2\31\3\31\4\31\5\31\11\31\12\31\13\31\21\31\22\31\23\31\24\24"
  .."\93\1\93\1'\46\1#\34\6\29\1#\52\54\51\50\22\31\1\30\1\51\50\54"
  .."=\1\51\14\1#\34&\2d\57\25\31\12#(}gU$=\49\57\22#\15\31(}\2fT"
  .."\34<\5\57!\14\11\50\45\6ev\16\27\30\13\12\51)\6dw\16\0\1\1y\4"
  .."\2\5\0\3\0i\0\1\4\1\3\4\16\49\0\16\48\0K\12TX\0\4"
  .."\0\1\0\4\0\4\0@\56\17\55\56Y\0K\14TX\0\4\0@\0\1\0\4\0\4"
  .."\56\17\55\56Y\1K\14TX\0\4\0@\0\1\0\4\0\4\56\17\55\56Y@\13"
  .."\15\0\15\3\31\0\31\3\47\0\47\3\6\0\93\1\19#\3\2\49Ś\5\1"
  .."\8\0\1\1\55\4\3\5\0\6\0\93@\9\4\0\5\2\7\4\2\6\7\16\57\49"
  .."\0\16<\57\48\0K\12TX\0\7\0\1\0\7\0\7\0@\56\17\55\56Y\0"
  .."K\14TX\0\7\0@\0\1\0\7\0\7\56\17\55\56Y@\19\15\0\15\1\12\4"
  .."\31\0\31\1\28\4\47\0\47\1,\4\9\93\1\51\19#'\7#\2\10ӌ\5"
  .."\0\1\1\55\4\3\5\0\6\0i@\9\3\4\1\0\7\3\5\1\7\16\57\49"
  .."\0\16\50\57\48\0K\14TX\0\7\0@\0\1\0\7\0\7\56\17\55\56Y"
  .."\0K\12TX\0\7\0\1\0\7\0\7\0@\56\17\55\56Y@\31\15\1\15\2\10"
  .."\3\15\4\15\5\31\1\31\2\26\3\31\4\31\5\47\1\47\2*\3\47\4\47\5"
  .."\15\93\1\3\51\23\55\51\3\2\10ӌ\4\1\10\0\1\0\27\1\4"
  .."Z\3j\0\3\0\25@\10\1\0\3\2\4\2\0\3\1\4\16\57\57\49\0\16"
  .."\48\19'\1\23\51\24\4$\27\1l\1\6l\0\2\1\12\2\3\5\0\10\0\13"
  .."\0\53\11\0\12\2\1\9\8\4\6\1\10\0\0\1\21@\11\14\12\9\11\7"
  .."W\3\5\1\9\14\16<\50\17\57\49\0\16<\50\17\57\48\1\51\17"
  .."\51\21#\21#\53!\53\1\1!\2wtt}\1\1\18\5oy\1c\0\0"
  .."\1\1\47\5\6\3\5\0\13\0\31\7\0\4\1\3@\9\11\14\7P\8\1P\0\14"
  .."\16\49\0\16\50\48\1\51\22\22\51\50\54\55\51\6\6#\34&\1"
  .."\47w\12dRSa\15w\11\5\54\57\55\56w{z\0\0\1\2\2\5\14\2\5"
  System.VERA=System.VERA
  .."\0\3\0\18\0\2\4\1a\0\4\16\49\0\16\48\1\51\21#\2\2\5"
  .."\0\0\0\0\2\0\1\0\0\0\0\0\20\0\3\0\1\0\0\1\26\0\0\1\6\0\0\1"
  .."\0\0\0\0\0\0\0\1\3\0\0\0\2\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\1\0"
  .."\0\3\4\5\6\7\8\9\10\11\12\13\14\15\16\17\18\19\20\21\22\23\24"
  .."\25\26\27\28\29\30\31 !\34#$%&'()*+,\45\46\47\48\49\50\51\52"
  .."\53\54\55\56\57:;<=>?@ABCDEFGHIJKLMNOPQRSTUVWXYZ\91\92\93^_`"
  .."a\0bcdefghijklmnopqrstuvwxyz{|}~\127"
  .."\0"
  .."\0\4\2>\0\0\0:\0 \0\4\0\26\0~\0\1\7\1\17\1\31"
  .."\1\49\1B\1S\1a\1x\1~\1\2\2\3\3 & \48 : !\34\34\6\34\30"
  .."\34+\34H\34e%\2\0\0\0 \0\1\6\1\12\1\30\1\48\1A\1R\1^\1x"
  .."\1}\1\2\2\3\3 \19 \48 \57 !\34\34\2\34\15\34+\34H\34`%"
  .."\1\0\0\0\0\0\0^\0\0Ch\20\0\0\0\0\0\0"
  .."Vj\0\0\0\0q_\0\0\5\0\1\0\0\0\56\0\0\0\0\0\0\0\0\0\0"
  .."\0\0\0\0\0\0\0\0\0\0\0\0\0\1\2\0\0\0\0\0\0\0\0\1 \1(\0\0\0"
  .."\0\1B\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\1\0"
  .."\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  .."\0\0\0b\0c\0\0d\0\0e\0\0\0\0\0\0\0\0f\0\0\0\0"
  .."\0g\0\0\0\0\0\0h\0\0\0\0j\0i\0k\0m\0l\0n\0\0o\0q\0p"
  .."\0r\0s\0u\0t\0v\0w\0\0x\0z\0y\0{\0}\0|\0\0\0\127\0~\0\0"
  .."\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  .."\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  .."\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  .."\0\0\0\0\0\0\1\1\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\4\0"
  .."h\0\0\0\0\4\0\0\4\0\0\4\2\4\4\1R\4\0\2\4\0\4\0!\4\0"
  .."\57\4\2\16\4\1\4\1\92\4\0\4\0X\4\1\4\1d\4\1\4\0"
  .."f\4\0\4\0\4\0\4\0\4\0f\4\0\4\0\4\0\4\0\4\0"
  .."\127\4\1\4\1\4\0X\4\0X\4\0X\4\0\4\0\27\4\0%\4\0"
  .."\4\0\4\0\4\0\4\0\4\0f\4\0\4\0\4\0m\4\0\4\0"
  .."\4\0V\4\0\4\0u\4\0\4\0u\4\0\4\0\4\0\47\4\0\4\0"
  .."\57\4\0\0\4\0\18\4\0%\4\0\4\1\4\0f\4\1Z\4\0H\4\0\0"
  .."\4\1\23\4\0\4\0\4\0\4\0{\4\0{\4\0\4\0{\4\0\4\0"
  System.VERA=System.VERA
  .."\4\0\4\0\4\0\4\0m\4\0\4\0\4\0\4\0\4\1j\4\0"
  .."\4\0\4\0\4\0d\4\0\0\4\0L\4\0h\4\0\4\0\4\2\18\4"
  .."\0\4\0X\4\0%\4\0%\4\0\4\0\4\0\4\0u\4\0\4\0\4"
  .."\0\4\0\4\0\4\0\4\0\4\0\4\0{\4\0{\4\0{\4\0{\4"
  .."\0\4\0\4\0\4\0\4\0\4\0\4\0\4\0\4\0\4\0\4"
  .."\0\4\0\4\0\4\0\4\0\4\1+\4\0\4\0\4\0\4\1?\4"
  .."\0j\4\0\4\0\0\4\0\0\4\0\0\4\1\4\1?\4\0X\4\0\0\4\0"
  .."\8\4\0)\4\0X\4\0V\4\0X\4\0%\4\0\4\0\4\0\4\0\4\0"
  .."P\4\0\4\1\14\4\0\4\0J\4\0)\4\0\47\4\0\4\2\4\4\0X"
  .."\4\0;\4\0\0\4\0X\4\4\0w\4\0\4\0P\4\0\0\4\0%\4\0"
  .."%\4\0u\4\0H\4\0\14\4\0\0\4\0\0\4\0\4\0\4\1\4\1\4"
  .."\0X\4\0u\4\0h\4\0%\4\0f\4\0\4\1Z\4\1\4\0#\4\0#\4"
  .."\0\4\1\4\1\4\0\4\0\0\4\0%\4\0\4\0%\4\0\4\0\4"
  .."\0\4\0\4\0\4\0\4\0u\4\0u\4\0u\4\0\4\0\4\0\4"
  .."\0\4\1)\4\1\31\4\1=\4\1\47\4\2\2\4\1V\4\1\4\1X\4"
  .."\1\4\1)\4\4\0L\4\0\4\0\4\0\4\0\4\2\18\4\0\8\4"
  .."\0\4\0%\4\0h\4\0\4\0\4\0X\4\0\4\1X\4\1B\4\1F\4"
  .."\0\27\4\0\27\4\0\27\4\0f\4\0{\4\0\4\0\4\0\4\0\4"
  .."\0\4\0\4\0\4\0{\4\1d\4\1\4\0%\4\1?\4\1\4\1\31"
  .."\4\1y\4\1\55\4\1\55\4\0\27\4\1\12\4\1\47\4\2\2\0\2\0\0"
  .."\0\0\0\0+\0\0\0\0\1\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\1\13\0"
  .."\0\0\1\0\2\0\3\0\4\0\5\0\6\0\7\0\8\0\9\0\10\0\11\0\12\0\13\0"
  .."\14\0\15\0\16\0\17\0\18\0\19\0\20\0\21\0\22\0\23\0\24\0\25\0"
  .."\26\0\27\0\28\0\29\0\30\0\31\0 \0!\0\34\0#\0$\0%\0&\0'\0(\0)"
  .."\0*\0+\0,\0\45\0\46\0\47\0\48\0\49\0\50\0\51\0\52\0\53\0\54\0"
  .."\55\0\56\0\57\0:\0;\0<\0=\0>\0?\0@\0A\0B\0C\0D\0E\0F\0G\0H\0"
  .."I\0J\0K\0L\0M\0N\0O\0P\0Q\0R\0S\0T\0U\0V\0W\0X\0Y\0Z\0\91\0\92"
  .."\0\93\0^\0_\0`\0a\0b\0c\0d\0e\0f\0g\0h\0i\0j\0k\0l\0m\0n\0o\0"
  .."p\0q\0r\0s\0t\0u\0v\0w\0x\0y\0z\0{\0|\0}\0~\0\127\0\0\0\0"
  .."\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  .."\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  .."\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  System.VERA=System.VERA
  .."\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  .."\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  .."\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"
  .."\0\0\1\0\1\1\1\2\1\3\1\4\1\5\1\6\1\7\1\8\1\9\1\10\1\11\1\12"
  .."\1\13\1\14\9sfthyphen\14periodcentered\4Euro\5c\54\52\53\57\5"
  .."c\54\52\54\48\5c\54\52\54\49\5c\54\52\54\56\5c\54\52\55\48\5"
  .."c\54\52\55\50\5c\54\52\55\55\5c\54\52\55\56\5c\54\52\55\53\5"
  .."c\54\52\55\54\0\0\0\0\0%\0%\0%\0%\0K\0m\0\1J\1\2z\2\2\2"
  .."\3\54\3b\3\127\3\3\3\4\4\5\10\5i\5\5\6P\6~\6\7A\7b\7"
  .."\7\7\7\8j\8\9\92\9\9\10\46\10\91\10\10\10\11)\11^\11"
  .."\11\12A\12\12\13\7\13\91\13\14?\14`\14\14\15m\15\16\50"
  .."\16l\16\16\16\16\17\1\17)\17\17\18*\18r\18\19\1\19d\19"
  .."\19\20\11\20\20\21O\21\21\22\11\22T\22\23\16\23J\23\23"
  .."\24l\24\25V\25\25\26\21\26|\26\26\27c\27p\27}\27\27\27"
  .."\27\27\27\27\27\27\27\28\12\28\25\28&\28\51\28@\28M\28"
  .."Z\28g\28t\28\28\28\28\28\28\28\28\28\29\21\29P\29\29"
  .."\30\30\30\31J\31  !\12!M!!\34l\34#\4#\51#a#$#$$"
  .."$% %u%&\45&'('(#(J(f()\21))*\5*A*m*m*z***+k++++"
  ..",\12,),V,,,,\45?\45`\45\45\46\22\46W\46o\46\46\47e\47"
  .."r\47\127\47\47\47\47\47\47\47\47\47\48\1\48\14\48\27"
  .."\48(\48O\48|\49\7\49\29\49S\49{\49\50\1\50C\50t\50\50\51\34"
  .."\51\47\51<\51I\51V\51{\51\52S\52`\52m\52\52\53\12\53E\53x"
  .."\53\54\57\54J\54\91\54l\54y\54\54\54\54\54\54\54\54"
  .."\55>\55T\55l\55\56\47\56r\57\8\57K\57\57\57:$:N:d\0\1\0\0"
  .."\1\13\0M\0\7\0F\0\4\0\2\0\16\0@\0\7\0\0\5W\7\27\0\3\0\1\0\1\0"
  .."\0\7m\29\0\0\4\4\0\1\0\0\0\0\0\0\0\0\0\0\0\0\0\0\1\13"
  .."\0\1\4\1\0\5\0\4\5G\4\0\0B\5G\4\0\0\2S\0\2f\8\2\2\11\6"
  .."\9\3\8\4\2\2\4\0\0\16\0 J\0\0\0\0\0\0\0\0Bits\0@\0 \2\6\20"
  .."\20\1\7m\1\0\0\0\1\0\0\0\0\0\0\0\1\0\0B\0\29\4\4`\0\0#c"
  .."\5\0\0VeraSansMono\0\0\0\0\54\54\50\56R\48\48\0\0@\0"
  .."\0\0\0\0\0\20\0\0\1\16\9\5\5\0\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5"
  .."\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5"
  System.VERA=System.VERA
  .."\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5"
  .."\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5"
  .."\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5"
  .."\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5"
  .."\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5"
  .."\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5"
  .."\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5\5"
  .."\5\5\5\5\5\5\5\5\5\5\5\5\0\10\6\6\0\6\6\6\6\6\6\6\6\6\6\6\6\6"
  .."\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6"
  .."\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6"
  .."\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6"
  .."\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6"
  .."\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6"
  .."\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6"
  .."\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6"
  .."\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6\6"
  .."\6\6\6\6\6\6\6\6\6\6\6\6\6\6\0\11\7\7\0\7\7\7\7\7\7\7\7\7\7\7"
  .."\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7"
  .."\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7"
  .."\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7"
  .."\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7"
  .."\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7"
  .."\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7"
  .."\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7"
  .."\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7"
  .."\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\0\12\7\7\0\7\7\7\7\7\7\7\7\7"
  .."\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7"
  .."\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7"
  .."\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7"
  .."\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7"
  .."\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7"
  .."\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7"
  System.VERA=System.VERA
  .."\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7"
  .."\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7"
  .."\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\7\0\13\8\8\0\8\8\8\8\8\8\8"
  .."\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8"
  .."\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8"
  .."\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8"
  .."\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8"
  .."\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8"
  .."\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8"
  .."\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8"
  .."\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8"
  .."\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\0\14\8\8\0\8\8\8\8\8"
  .."\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8"
  .."\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8"
  .."\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8"
  .."\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8"
  .."\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8"
  .."\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8"
  .."\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8"
  .."\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8"
  .."\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\8\0\15\9\9\0\9\9\9"
  .."\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9"
  .."\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9"
  .."\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9"
  .."\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9"
  .."\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9"
  .."\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9"
  .."\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9"
  .."\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9"
  .."\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\9\0\16\10\10\0"
  .."\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10"
  .."\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10"
  System.VERA=System.VERA
  .."\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10"
  .."\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10"
  .."\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10"
  .."\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10"
  .."\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10"
  .."\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10"
  .."\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10"
  .."\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10"
  .."\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10"
  .."\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10"
  .."\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10"
  .."\10\10\10\10\10\10\10\0\17\10\10\0\10\10\10\10\10\10\10\10\10"
  .."\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10"
  .."\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10"
  .."\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10"
  .."\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10"
  .."\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10"
  .."\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10"
  .."\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10"
  .."\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10"
  .."\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10"
  .."\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10"
  .."\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10"
  .."\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10"
  .."\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\10\0\18\11"
  .."\11\0\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11"
  .."\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11"
  .."\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11"
  .."\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11"
  .."\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11"
  .."\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11"
  .."\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11"
  System.VERA=System.VERA
  .."\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11"
  .."\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11"
  .."\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11"
  .."\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11"
  .."\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11"
  .."\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11"
  .."\11\11\11\11\11\11\11\11\0\19\11\11\0\11\11\11\11\11\11\11\11"
  .."\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11"
  .."\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11"
  .."\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11"
  .."\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11"
  .."\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11"
  .."\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11"
  .."\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11"
  .."\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11"
  .."\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11"
  .."\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11"
  .."\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11"
  .."\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11"
  .."\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\11\0\20"
  .."\12\12\0\12\12\12\12\12\12\12\12\12\12\12\12\12\12\12\12\12\12"
  .."\12\12\12\12\12\12\12\12\12\12\12\12\12\12\12\12\12\12\12\12"
  .."\12\12\12\12\12\12\12\12\12\12\12\12\12\12\12\12\12\12\12\12"
  .."\12\12\12\12\12\12\12\12\12\12\12\12\12\12\12\12\12\12\12\12"
  .."\12\12\12\12\12\12\12\12\12\12\12\12\12\12\12\12\12\12\12\12"
  .."\12\12\12\12\12\12\12\12\12\12\12\12\12\12\12\12\12\12\12\12"
  .."\12\12\12\12\12\12\12\12\12\12\12\12\12\12\12\12\12\12\12\12"
  .."\12\12\12\12\12\12\12\12\12\12\12\12\12\12\12\12\12\12\12\12"
  .."\12\12\12\12\12\12\12\12\12\12\12\12\12\12\12\12\12\12\12\12"
  .."\12\12\12\12\12\12\12\12\12\12\12\12\12\12\12\12\12\12\12\12"
  .."\12\12\12\12\12\12\12\12\12\12\12\12\12\12\12\12\12\12\12\12"
  .."\12\12\12\12\12\12\12\12\12\12\12\12\12\12\12\12\12\12\12\12"
  System.VERA=System.VERA
  .."\12\12\12\12\12\12\12\12\12\12\12\12\12\12\12\12\12\12\12\12"
  .."\12\12\12\12\12\12\12\12\12\0\21\13\13\0\13\13\13\13\13\13\13"
  .."\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13"
  .."\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13"
  .."\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13"
  .."\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13"
  .."\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13"
  .."\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13"
  .."\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13"
  .."\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13"
  .."\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13"
  .."\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13"
  .."\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13"
  .."\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13"
  .."\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13"
  .."\0\22\13\13\0\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13"
  .."\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13"
  .."\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13"
  .."\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13"
  .."\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13"
  .."\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13"
  .."\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13"
  .."\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13"
  .."\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13"
  .."\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13"
  .."\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13"
  .."\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13"
  .."\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13\13"
  .."\13\13\13\13\13\13\13\13\13\13\13\0\23\14\14\0\14\14\14\14\14"
  .."\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14"
  .."\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14"
  .."\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14"
  System.VERA=System.VERA
  .."\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14"
  .."\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14"
  .."\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14"
  .."\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14"
  .."\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14"
  .."\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14"
  .."\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14"
  .."\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14"
  .."\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14"
  .."\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14"
  .."\14\14\0\24\14\14\0\14\14\14\14\14\14\14\14\14\14\14\14\14\14"
  .."\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14"
  .."\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14"
  .."\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14"
  .."\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14"
  .."\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14"
  .."\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14"
  .."\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14"
  .."\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14"
  .."\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14"
  .."\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14"
  .."\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14"
  .."\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14\14"
  .."\14\14\14\14\14\14\14\14\14\14\14\14\14\0\25\15\15\0\15\15\15"
  .."\15\15\15\15\15\15\15\15\15\15\15\15\15\15\15\15\15\15\15\15"
  .."\15\15\15\15\15\15\15\15\15\15\15\15\15\15\15\15\15\15\15\15"
  .."\15\15\15\15\15\15\15\15\15\15\15\15\15\15\15\15\15\15\15\15"
  .."\15\15\15\15\15\15\15\15\15\15\15\15\15\15\15\15\15\15\15\15"
  .."\15\15\15\15\15\15\15\15\15\15\15\15\15\15\15\15\15\15\15\15"
  .."\15\15\15\15\15\15\15\15\15\15\15\15\15\15\15\15\15\15\15\15"
  .."\15\15\15\15\15\15\15\15\15\15\15\15\15\15\15\15\15\15\15\15"
  .."\15\15\15\15\15\15\15\15\15\15\15\15\15\15\15\15\15\15\15\15"
  System.VERA=System.VERA
  .."\15\15\15\15\15\15\15\15\15\15\15\15\15\15\15\15\15\15\15\15"
  .."\15\15\15\15\15\15\15\15\15\15\15\15\15\15\15\15\15\15\15\15"
  .."\15\15\15\15\15\15\15\15\15\15\15\15\15\15\15\15\15\15\15\15"
  .."\15\15\15\15\15\15\15\15\15\15\15\15\15\15\15\15\15\15\15\15"
  .."\15\15\15\15\15\15\15\15\15\15\15\15\15\15\15\15\15\15\15\15"
  .."\15\15\15\15\0\26\16\16\0\16\16\16\16\16\16\16\16\16\16\16\16"
  .."\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16"
  .."\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16"
  .."\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16"
  .."\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16"
  .."\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16"
  .."\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16"
  .."\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16"
  .."\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16"
  .."\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16"
  .."\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16"
  .."\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16"
  .."\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16"
  .."\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\0\27\16\16\0\16"
  .."\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16"
  .."\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16"
  .."\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16"
  .."\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16"
  .."\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16"
  .."\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16"
  .."\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16"
  .."\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16"
  .."\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16"
  .."\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16"
  .."\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16"
  .."\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16"
  .."\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16\16"
  System.VERA=System.VERA
  .."\16\16\16\16\16\16\0\28\17\17\0\17\17\17\17\17\17\17\17\17\17"
  .."\17\17\17\17\17\17\17\17\17\17\17\17\17\17\17\17\17\17\17\17"
  .."\17\17\17\17\17\17\17\17\17\17\17\17\17\17\17\17\17\17\17\17"
  .."\17\17\17\17\17\17\17\17\17\17\17\17\17\17\17\17\17\17\17\17"
  .."\17\17\17\17\17\17\17\17\17\17\17\17\17\17\17\17\17\17\17\17"
  .."\17\17\17\17\17\17\17\17\17\17\17\17\17\17\17\17\17\17\17\17"
  .."\17\17\17\17\17\17\17\17\17\17\17\17\17\17\17\17\17\17\17\17"
  .."\17\17\17\17\17\17\17\17\17\17\17\17\17\17\17\17\17\17\17\17"
  .."\17\17\17\17\17\17\17\17\17\17\17\17\17\17\17\17\17\17\17\17"
  .."\17\17\17\17\17\17\17\17\17\17\17\17\17\17\17\17\17\17\17\17"
  .."\17\17\17\17\17\17\17\17\17\17\17\17\17\17\17\17\17\17\17\17"
  .."\17\17\17\17\17\17\17\17\17\17\17\17\17\17\17\17\17\17\17\17"
  .."\17\17\17\17\17\17\17\17\17\17\17\17\17\17\17\17\17\17\17\17"
  .."\17\17\17\17\17\17\17\17\17\17\17\17\17\17\17\17\17\0\0\0\0\2"
  .."\0\8\0\2\0\3\0\1\0\0\0\2\0\0䥉_\15<\0\31\8\0\0\0\0\0"
  .."\0\0\0\0l\5\29\4\7m\0\0\0\8\0\1\0\0\0\0\0\000"
  System.VERA=string.format("%s",System.VERA)

  System.Fntbuf = pge.texture.create(64,64)

  function System.VeraInit()
  --This function is needed because Font load from memory 
  --isn't working (?).
    System.fpath = System.EbPath..System.FDV..System.TTFONT
    if pge.file.exists(System.fpath) then
      System.Font1 = pge.font.load(System.fpath,System.FBHGT,PGE_RAM)
    else
      --write out System.VERA to file if not found
      fontfile = io.open(System.fpath,"w+")
      fontfile:setvbuf("full")
      fontfile:write(System.VERA)
      fontfile:flush()
      fontfile:close()
      System.Font1 = pge.font.load(System.fpath,System.FBHGT,PGE_RAM)
      pge.file.remove(System.fpath)
    end
  end
  System.VeraInit()

  --System Font relative character dimensions
  System.fwids =
  {
    0,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,20,
    20,20,20,20,20,20,20,20,20,20,20,10,13,15,26,21,31,25,9,13,13,
    16,26,10,12,9,11,20,20,20,21,20,20,20,21,20,20,11,11,26,26,26,
    17,32,22,21,23,24,20,18,25,24,9,9,21,18,27,24,25,19,25,22,20,
    20,24,22,32,22,19,21,13,11,13,27,17,16,20,21,18,21,20,11,21,21,
    9,9,19,9,31,21,20,21,21,13,17,13,21,19,26,19,19,16,21,11,21,26,
    20,
  }

  Font =
  {
       --methods
       createProportional,
       createMonoSpaced,
       load,
   
       --properties
       PGEFont,       -- PGE Font
       ftyp,          -- Font type identifier
       wpx,hpx,       -- pixel size
  }
  
  --methods

  Font.createProportional = function()
    local fnt = {} ; setmetatable(fnt,{__index=Font})
    fnt.ftyp = System.FPROPR
    fnt.PGEFont = System.Font1
    fnt.wpx,fnt.hpx = System.FPWDF,System.FPHDF
    return fnt
  end

  Font.createMonoSpaced = function()
    local fnt = {} ; setmetatable(fnt,{__index=Font})
    fnt.ftyp = System.FMSPAC
    fnt.PGEFont = System.Font1
    fnt.wpx,fnt.hpx = System.FPWDF,System.FPHDF
    return fnt
  end

  Font.load = function(filepath)
    local fnt = {} ; setmetatable(fnt,{__index=Font})
    fnt.ftyp = System.F_LOAD
    if pge.file.exists(filepath) then
      fnt.PGEFont = pge.font.load(filepath,System.FBHGT)
    end
    if not fnt.PGEFont then fnt.PGEFont = System.Font1 end
    fnt.wpx,fnt.hpx = System.FPWDF,System.FPHDF
    return fnt
  end

  --metamethods

  function Font:setPixelSizes(fpx,fpy)
    local fnt = self
    if type(fpx)~=System.NUMBER then fpx = fnt.wpx end
    if type(fpy)~=System.NUMBER then fpy = fnt.hpx end
    fpx = math.max(fpx,0) ; fpx = math.min(fpx,System.FWDMX)
    fpy = math.max(fpy,1) ; fpy = math.min(fpy,System.FHGMX)

    if fpx==0 then
      fpx = math.ceil(fpy*0.75)  --fpx proportional to fpy
    end

    self.wpx,self.hpx = fpx,fpy
  end

  function Font:setCharSize(width,height,dpiX,dpiY)
    self:setPixelSizes(width,height)
  end

  function Font:getTextSize(str)
  --Returns the width and height, which will be used, if the
  --specified text is drawn with this font and the current 
  --font size.
    local fnt = self
    local txtwd,txthg = 0,0
    if type(str)==System.STRING and str~=System.NEWSTR then
      Image.wdf = fnt.wpx/30
      for ch = 1,string.len(str) do
        Image.ci = string.sub(str,ch,ch)
        if fnt.ftyp~=System.FPROPR then
          Image.ciwd = fnt.PGEFont:measure(Image.ci)
        else
          Image.ciwd = System.fwids[string.byte(Image.ci)+1]*System.FWDFC0
        end
        Image.chwid = math.floor(Image.ciwd*Image.wdf)
        txtwd = txtwd+Image.chwid
      end
      txthg = math.floor(fnt.hpx*System.FHGFAC)
    end
    return {width=txtwd,height=txthg}
  end


--GRAPHICS--

  Image =
  {
     --methods
     createEmpty,
     load,
  
     --properties
     PGETexture,      --texture
     wd,hg,           --dimensions
  }
  
  --8x8 transparent black PNG in RAM
  Image.apng8 = "\137PNG\13\10\26\10\0\0\0\13IHDR\0\0\0\8"..
                "\0\0\0\8\8\6\0\0\0\196\15\190\139\0\0\0\15"..
                "IDAT\24\149c\96\24\5\12\12\12\12\0\1\8\0\1"..
                "\125A\165\206\0\0\0\0IEND\174B\96\130"
  
  --32x32 transparent black PNG file in RAM
  Image.apng32 = "\137PNG\13\10\26\10\0\0\0\13IHDR\0\0\0\32\0\0\0"..
                 "\32\8\6\0\0\0szz\244\0\0\0\26IDATX\133\237\193\1"..
                 "\1\0\0\0\130\32\255\175nH\64\1\0\0\0\239\6\16\32"..
                 "\0\1G\1\160\136\0\0\0\0IEND\174B\96\130"
  
  
  Image.createEmpty = function(width,height)
  --Creates and returns an empty image, initially cleared.
  --Max. width and height is 512.
    
    local img = {} ; setmetatable(img,{__index=Image})
    collectgarbage("stop")
    img.PGETexture = pge.texture.create(width,height)
    if not img.PGETexture then
      error("texture creation error")
    end
    img.wd,img.hg = width,height
    collectgarbage("step") ; collectgarbage("restart")
    return img
  end
  
  Image.load = function(filename)
  -- Loads an image. Returns an Image object.
  -- Currently only PNG files are supported.
    local img = {} ; setmetatable(img,{__index=Image})
    System.pgegfx()
    collectgarbage("stop")
    local imld = pge.texture.load(filename)
    if not imld then error("PNG load error") end
    img.wd,img.hg = imld:width(),imld:height()
    pge.gfx.startdrawing()
    img.PGETexture = pge.texture.create(img.wd,img.hg,PGE_PIXEL_FORMAT_8888,PGE_VRAM)
    collectgarbage("collect")
    if not img.PGETexture then
      pge.delay(10000)
      img.PGETexture = pge.texture.create(img.wd,img.hg,PGE_PIXEL_FORMAT_8888,PGE_VRAM)
      if not img.PGETexture then
        pge.delay(10000)
        img.PGETexture = pge.texture.create(img.wd,img.hg)
        if not img.PGETexture then
          error("Image.load: Couldn't create new image in VRRAM")
        end
        img.PGETexture:tovram()
      end
    end
    img.PGETexture:settarget()
    imld:activate()
    pge.delay(5000)
    imld:draweasy(0,0)
    pge.delay(5000)        --(toram() fails without this delay (?))
    img.PGETexture:toram()
    pge.gfx.enddrawing()

    pge.gfx.startdrawing()
    imld = nil
    collectgarbage("step") ; collectgarbage("restart")
    return img
  end
  
  System.pgegfx = function()
  --enable the PGE API
    if System.quickImage then
      collectgarbage("stop")
      --move current enabled image to RAM
      if not pge.texture.toram(System.quickImage) then
        pge.delay(5000)
        if not pge.texture.toram(System.quickImage) then

-- comment out this error (?) 
--          error("texture RRAM move error")
--  
        end
      end
      System.quickImage = nil
      collectgarbage("collect"); collectgarbage("restart")
      pge.delay(5000)
    end
  end
  System.pgegfx()
  
  --metamethods
  
  function Image:gfxenable()
  --enable PGE graphics to an Image by moving it to VRAM
  --if not already there
  
    local img = self.PGETexture
    if System.quickImage==nil or img~=System.quickImage then
      System.pgegfx()
      --move image to VRAM
      System.quickImage = img
      pge.delay(7000)
      if not pge.texture.tovram(img) then
        pge.delay(7000)
        if not img:tovram() then
          error("texture VRRAM move error")
        end
      end
      collectgarbage("step"); collectgarbage("restart")
      pge.delay(7000)
      return 
    end
  end
  
  function Image:save(filename)
  --Saves an image to memory stick.
  --PNG files only are supported.
    local img = self.PGETexture
    collectgarbage("stop")
    img:activate()
    img:save(filename)
    collectgarbage("step"); collectgarbage("restart")
  end
  
  function Image:width()
  --Returns the width of an image.
    return self.wd
  end     
  
  function Image:height()
  --Returns the height of an image.
    return self.hg
  end
  
  Image.frec = pge.texture.create(8,8) --fill colour texture
  Image.frec:tovram()
 
  function Image:clear(color)
  --clear Image to color
    if type(color)==Image.TCTYPE then color = color.PGEColor
                                 else color = System.FBCOL
    end
    local img = self.PGETexture

    pge.gfx.startdrawing()
    Image.frec:settarget()
    pge.gfx.clearscreen(color)
    Image.frec:activate()
    self:gfxenable() ; img:settarget() 
    Image.frec:draw(0,0,img:width(),img:height(),0,0,3,3,0,255)

    pge.gfx.enddrawing()
  end
  

  function System.fontPrint(fnt,x,y,str,colr,bcolr,img)

    if type(str)~=System.STRING or str=="" then return end
    if type(colr)~=Image.TCTYPE then return end
    if type(bcolr)==Image.TCTYPE then bcolr = bcolr.PGEColor
                                 else bcolr = System.FBCOL
    end
    collectgarbage("stop")
    if img then img:tovram() ; collectgarbage("step") end
    
    fnt.wpx = fnt.wpx or System.FPWDF
    fnt.hpx = fnt.wpx or System.FPHDF
    Image.wdf = fnt.wpx/30
    System.Fntbuf:tovram()  
    for ch = 1,string.len(str) do
      pge.gfx.startdrawing()
      Image.ci = string.sub(str,ch,ch)
      if fnt.ftyp~=System.FPROPR then
        Image.ciwd = fnt.PGEFont:measure(Image.ci)
      else
        Image.ciwd = System.fwids[string.byte(Image.ci)+1]*System.FWDFC0
      end
      Image.chwid = math.floor(Image.ciwd*Image.wdf)
      Image.chhgt = math.floor(fnt.hpx*System.FHGFAC)

      pge.font.activate(fnt.PGEFont)
      System.Fntbuf:settarget()
      pge.gfx.clearscreen(bcolr)
      fnt.PGEFont:print(0,0,colr.PGEColor,Image.ci)
      System.Fntbuf:activate()
      if img then img:settarget()
             else pge.gfx.rendertoscreen()
      end
      System.Fntbuf:draw(x,y,Image.chwid,Image.chhgt,0,0,Image.ciwd+System.FCHSPC,System.FBHGT)
      x = x+Image.chwid
      pge.gfx.enddrawing()
    end
    System.Fntbuf:toram()

    if img then img:toram() end
    collectgarbage("step") ; collectgarbage("restart")
  end  
  
  function Image:fontPrint(fnt,x,y,str,colr,bcolr)
    System.fontPrint(fnt,x,y,str,colr,bcolr,self.PGETexture)
  end

  function Image:pixel(x,y,colr)
  --set/get the color of a pixel.
    local img = self.PGETexture
    local clr
  
    pge.gfx.startdrawing()
    self:gfxenable(true) ; img:settarget() 
    if not colr then
      local pcol = pge.texture.pixel(img,x,y)
      clr = {} ; setmetatable(clr,{__index=Color})
      clr.PGEColor = pcol
      clr.ctab =
      {
         r = pge.gfx.red(pcol),
         g = pge.gfx.green(pcol),
         b = pge.gfx.blue(pcol),
         a = pge.gfx.alpha(pcol),
      }
    else
      pge.texture.pixel(img,x,y,colr.PGEColor)
    end
    pge.gfx.enddrawing()
    return clr
  end
  
  function Image:fillRect(x,y,width,height,color)
  --Draws a filled rectangle.
    if type(color)==Image.TCTYPE then color = color.PGEColor
                                 else color = System.FBCOL
    end
    local img = self.PGETexture
    pge.gfx.startdrawing()
  
    Image.frec:settarget()
    pge.gfx.clearscreen(color)
    Image.frec:activate()
  
    self:gfxenable() ; img:settarget() 
    Image.frec:draw(x,y,width+1,height+1,0,0,3,3,0,255)
    pge.gfx.enddrawing()
  end
  
  function Image:drawLine(x0,y0,x1,y1,color)
  --Draws a line.
    if type(color)==Image.TCTYPE then color = color.PGEColor
                                 else color = System.FBCOL
    end
    local img = self.PGETexture
    pge.gfx.startdrawing()
    self:gfxenable() ; img:settarget() 
    if x0==x1 and y0==y1 then
      pge.gfx.drawrect(x0,y0,1,1,color)
    else
      pge.gfx.drawline(x0,y0,x1,y1,color)
    end
    pge.gfx.enddrawing()
  end
  
  function Image:blit(x,y,imgS,srcx,srcy,width,height,alpha)
  --Blit Image imgS to image at pixel coordinate (x,y).
  --(srcx,srcy) is the position in the source image, from
  --where a rectangle of size (width,height) is copied.
  --defaults: (0,0),(imgS:width(),imgS:height())
  --(alpha) is a bool flag to enable/disable transparency,default:true
    local img = self.PGETexture
    local simg = imgS.PGETexture
    System.argc = select("#",x,y,imgS,srcx,srcy,width,height,alpha)
    if System.argc<=4 then
      if System.argc==4 then alpha = srcx end
      srcx,srcy = 0,0
      width,height = simg:width(),simg:height()
    end
  
    if not srcx or type(srcx)~=System.NUMBER then srcx = 0 end
    if not srcy or type(srcy)~=System.NUMBER then srcy = 0 end
    if not width or type(width)~=System.NUMBER then
      width = simg:width()
    end
    if not height or type(height)~=System.NUMBER then
      height = simg:height()
    end
    pge.gfx.startdrawing()
    self:gfxenable() ; img:settarget() 
    collectgarbage("stop")
    if img==simg then

  --blit to self  --this code's not working (?)
      System.pgegfx()
      System.newImg = pge.texture.create(simg:width(),simg:height(),PGE_PIXEL_FORMAT_8888,PGE_VRAM)
      System.newImg:settarget()
      simg:activate()
      simg:draweasy(0,0)
      simg:draw(x,y,width,height,srcx,srcy,srcx+width,srcy+height,0,255)
      imgS.PGETexture = System.newImg
      self.PGETexture = System.newImg
      pge.delay(5000)
      System.newImg:toram()
  --

    else
      self:gfxenable() ; img:settarget() 
      simg:activate()
      simg:draw(x,y,width,height,srcx,srcy,srcx+width,srcy+height,0,255)
    end
    pge.gfx.enddrawing()
    collectgarbage("step") ; collectgarbage("restart")
  end
  
  --character map for System.print
  Image.chmap =
  {    --map--                             --ascii--
     "\0\0\0\0\0\0\0\0",                    -- 0
     "\60\66\165\129\165\153\66\60",        -- 1
     "\60\126\219\255\255\219\102\60",      -- 2
     "\108\254\254\254\124\56\16\0",        -- 3
     "\16\56\124\254\124\56\16\0",          -- 4
     "\16\56\84\254\84\16\56\0",            -- 5
     "\16\56\124\254\254\16\56\0",          -- 6
     "\0\0\0\48\48\0\0\0",                  -- 7
     "\255\255\255\231\231\255\255\255",    -- 8
     "\56\68\130\130\130\68\56\0",          -- 9
     "\199\187\125\125\125\187\199\255",    -- 10
     "\15\3\5\121\136\136\136\112",         -- 11
     "\56\68\68\68\56\16\124\16",           -- 12
     "\48\40\36\36\40\32\224\192",          -- 13
     "\60\36\60\36\36\228\220\24",          -- 14
     "\16\84\56\238\56\84\16\0",            -- 15
     "\16\16\16\124\16\16\16\16",           -- 16
     "\16\16\16\255\0\0\0\0",               -- 17
     "\0\0\0\255\16\16\16\16",              -- 18
     "\16\16\16\240\16\16\16\16",           -- 19
     "\16\16\16\31\16\16\16\16",            -- 20
     "\16\16\16\255\16\16\16\16",           -- 21
     "\16\16\16\16\16\16\16\16",            -- 22
     "\0\0\0\255\0\0\0\0",                  -- 23
     "\0\0\0\31\16\16\16\16",               -- 24
     "\0\0\0\240\16\16\16\16",              -- 25
     "\16\16\16\31\0\0\0\0",                -- 26
     "\16\16\16\240\0\0\0\0",               -- 27
     "\129\66\36\24\24\36\66\129",          -- 28
     "\1\2\4\8\16\32\64\128",               -- 29
     "\128\64\32\16\8\4\2\1",               -- 30
     "\0\16\16\255\16\16\0\0",              -- 31
     "\0\0\0\0\0\0\0\0",                    -- 32
     "\32\32\32\32\0\0\32\0",               -- 33
     "\80\80\80\0\0\0\0\0",                 -- 34
     "\80\80\248\80\248\80\80\0",           -- 35
     "\32\120\160\112\40\240\32\0",         -- 36
     "\192\200\16\32\64\152\24\0",          -- 37
     "\64\160\64\168\144\152\96\0",         -- 38
     "\16\32\64\0\0\0\0\0",                 -- 39
     "\16\32\64\64\64\32\16\0",             -- 40
     "\64\32\16\16\16\32\64\0",             -- 41
     "\32\168\112\32\112\168\32\0",         -- 42
     "\0\32\32\248\32\32\0\0",              -- 43
     "\0\0\0\0\0\32\32\64",                 -- 44
     "\0\0\0\120\0\0\0\0",                  -- 45
     "\0\0\0\0\0\96\96\0",                  -- 46
     "\0\0\8\16\32\64\128\0",               -- 47
     "\112\136\152\168\200\136\112\0",      -- 48
     "\32\96\160\32\32\32\248\0",           -- 49
     "\112\136\8\16\96\128\248\0",          -- 50
     "\112\136\8\48\8\136\112\0",           -- 51
     "\16\48\80\144\248\16\16\0",           -- 52
     "\248\128\224\16\8\16\224\0",          -- 53
     "\48\64\128\240\136\136\112\0",        -- 54
     "\248\136\16\32\32\32\32\0",           -- 55
     "\112\136\136\112\136\136\112\0",      -- 56
     "\112\136\136\120\8\16\96\0",          -- 57
     "\0\0\32\0\0\32\0\0",                  -- 58
     "\0\0\32\0\0\32\32\64",                -- 59
     "\24\48\96\192\96\48\24\0",            -- 60
     "\0\0\248\0\248\0\0\0",                -- 61
     "\192\96\48\24\48\96\192\0",           -- 62
     "\112\136\8\16\32\0\32\0",             -- 63
     "\112\136\8\104\168\168\112\0",        -- 64
     "\32\80\136\136\248\136\136\0",        -- 65
     "\240\72\72\112\72\72\240\0",          -- 66
     "\48\72\128\128\128\72\48\0",          -- 67
     "\224\80\72\72\72\80\224\0",           -- 68
     "\248\128\128\240\128\128\248\0",      -- 69
     "\248\128\128\240\128\128\128\0",      -- 70
     "\112\136\128\184\136\136\112\0",      -- 71
     "\136\136\136\248\136\136\136\0",      -- 72
     "\112\32\32\32\32\32\112\0",           -- 73
     "\56\16\16\16\144\144\96\0",           -- 74
     "\136\144\160\192\160\144\136\0",      -- 75
     "\128\128\128\128\128\128\248\0",      -- 76
     "\136\216\168\168\136\136\136\0",      -- 77
     "\136\200\200\168\152\152\136\0",      -- 78
     "\112\136\136\136\136\136\112\0",      -- 79
     "\240\136\136\240\128\128\128\0",      -- 80
     "\112\136\136\136\168\144\104\0",      -- 81
     "\240\136\136\240\160\144\136\0",      -- 82
     "\112\136\128\112\8\136\112\0",        -- 83
     "\248\32\32\32\32\32\32\0",            -- 84
     "\136\136\136\136\136\136\112\0",      -- 85
     "\136\136\136\136\80\80\32\0",         -- 86
     "\136\136\136\168\168\216\136\0",      -- 87
     "\136\136\80\32\80\136\136\0",         -- 88
     "\136\136\136\112\32\32\32\0",         -- 89
     "\248\8\16\32\64\128\248\0",           -- 90
     "\112\64\64\64\64\64\112\0",           -- 91
     "\0\0\128\64\32\16\8\0",               -- 92
     "\112\16\16\16\16\16\112\0",           -- 93
     "\32\80\136\0\0\0\0\0",                -- 94
     "\0\0\0\0\0\0\248\0",                  -- 95
     "\64\32\16\0\0\0\0\0",                 -- 96
     "\0\0\112\8\120\136\120\0",            -- 97
     "\128\128\176\200\136\200\176\0",      -- 98
     "\0\0\112\136\128\136\112\0",          -- 99
     "\8\8\104\152\136\152\104\0",          -- 100
     "\0\0\112\136\248\128\112\0",          -- 101
     "\16\40\32\248\32\32\32\0",            -- 102
     "\0\0\104\152\152\104\8\112",          -- 103
     "\128\128\240\136\136\136\136\0",      -- 104
     "\32\0\96\32\32\32\112\0",             -- 105
     "\16\0\48\16\16\16\144\96",            -- 106
     "\64\64\72\80\96\80\72\0",             -- 107
     "\96\32\32\32\32\32\112\0",            -- 108
     "\0\0\208\168\168\168\168\0",          -- 109
     "\0\0\176\200\136\136\136\0",          -- 110
     "\0\0\112\136\136\136\112\0",          -- 111
     "\0\0\176\200\200\176\128\128",        -- 112
     "\0\0\104\152\152\104\8\8",            -- 113
     "\0\0\176\200\128\128\128\0",          -- 114
     "\0\0\120\128\240\8\240\0",            -- 115
     "\64\64\240\64\64\72\48\0",            -- 116
     "\0\0\144\144\144\144\104\0",          -- 117
     "\0\0\136\136\136\80\32\0",            -- 118
     "\0\0\136\168\168\168\80\0",           -- 119
     "\0\0\136\80\32\80\136\0",             -- 120
     "\0\0\136\136\152\104\8\112",          -- 121
     "\0\0\248\16\32\64\248\0",             -- 122
     "\24\32\32\64\32\32\24\0",             -- 123
     "\32\32\32\0\32\32\32\0",              -- 124
     "\192\32\32\16\32\32\192\0",           -- 125
     "\64\168\16\0\0\0\0\0",                -- 126
     "\0\0\32\80\248\0\0\0"                 -- 127
  }
  
  Image.PRWD = 8              --character width
  Image.PRHG = 8              --character height
  
  Image.PRWM1 = Image.PRWD-1  --character width-1
  Image.PRWM2 = Image.PRWD-2  --character width-2
  Image.PRHM1 = Image.PRHG-1  --character height-1
  Image.MPWD  = Image.PRWD*32 --sub-drawmap width
  
  System.BLACK = Color.new(0,0,0)
  Image.TCTYPE = type(System.BLACK)
  
  function System.print(x,y,str,colr,img)
  --print string to image or screen using the system bitmap font
    local I = Image
  
    if type(x)~=System.NUMBER or type(y)~=System.NUMBER or
       type(str)~=System.STRING or type(colr)~=I.TCTYPE then
        return
    end
    I.nstr = string.len(str)
    if I.nstr<1 then return end
  
    x,y = math.floor(x),math.floor(y)
  
    if img then
      I.dwd,I.dhg = img.PGETexture:width(),img.PGETexture:height()
    else
      I.dwd,I.dhg = System.SCRW,System.SCRH
    end
    I.pxr,I.apwd = x,I.nstr*Image.PRWD
  
    --invisibility test (clipped chars are invisible)
    if I.nstr<1 or (x+I.apwd<Image.PRWD) or (y<0) or 
       (x>=I.dwd-Image.PRWD) or (y>=I.dhg-Image.PRHG) then
      return
    end

    --print characters
    if img then
      img:gfxenable()
      img.PGETexture:settarget()
    else
      pge.gfx.rendertoscreen()
    end
    collectgarbage("stop")
    for i = 1,I.nstr do
      --move to next character position
      I.px = I.pxr ; I.pxr = I.pxr+Image.PRWD
  
      --clip to image RH edge
      if I.px>=I.dwd then break end
  
      if I.px>=0 then   --print next character
        I.chrb = string.byte(str,i,i)
        I.cstr = I.chmap[I.chrb+1]
        if I.chrb>=1 and I.chrb<=127 and I.chrb~=32 then
          --render character (Xpixel x Ypixel)
          for row = y,y+7 do
            I.col = I.px+I.PRWM1
            I.rbyt = string.byte(I.cstr,(row-y)+1)
            while I.rbyt>0 do
              I.rbd2 = math.floor(I.rbyt/2)
              if (I.rbd2+I.rbd2)~=I.rbyt then
                pge.gfx.drawrect(I.col,row,1,1,colr.PGEColor)
              end
              I.rbyt,I.col = I.rbd2,I.col-1
            end
          end
        end
      end
    end
    pge.gfx.enddrawing()
    collectgarbage("step") ; collectgarbage("restart")
  end

  

  function Image:print(x,y,str,colr)
  --print string to Image using system bitmap font
    System.print(x,y,str,colr,self)
  end


--screen object
  screen =
  {
     --properties
     vBtimer,
     vBlankTime,
     vBSyncTime,
     mSinceVB,
     mStoVB,
  }
  
  setmetatable(screen,{__index=screen})
  
  --vBlank Sync
  screen.vBtimer = pge.timer.create()
  pge.gfx.swapbuffers(true)
  screen.vBtimer:getdelta()
  pge.gfx.swapbuffers(true)
  screen.vBlankTime = screen.vBtimer:getdelta()
  
  --methods
  
  function screen.flip(vflg)
    if vflg and type(vflg)==System.BOOL then vflg = true
                                        else vflg = false
    end
    
    pge.gfx.enddrawing()
    pge.gfx.swapbuffers(vflg)
    screen.vBtimer:getdelta()
    pge.gfx.startdrawing()
  end
  
  function screen.waitVblankStart(count)
  --wait for screen Vblank
    if not count or type(count)~=System.NUMBER then count = 1 end
    screen.mSinceVB = math.fmod(screen.vBtimer:peekdelta(),screen.vBlankTime)
    screen.mStoVB = screen.vBlankTime-screen.mSinceVB
    screen.mStoVB = screen.mStoVB+((count-1)*screen.vBlankTime)
    repeat until screen.vBtimer:peekdelta()>=screen.mStoVB
  end
  
  --metamethods
  function screen:width()  return System.SCRW end     
  function screen:height() return System.SCRH end
       
  function screen:clear(color)
    if type(color)==Image.TCTYPE then color = color.PGEColor
                                 else color = System.FBCOL
    end

    pge.gfx.startdrawing()
    pge.gfx.rendertoscreen()
    pge.gfx.clearscreen(color)
    pge.gfx.enddrawing()
  end
  
  function screen:pixel(x,y,colr)
  --set/get the color of a pixel on screen.
    local clr
  
    pge.gfx.startdrawing()
    pge.gfx.rendertoscreen()
    if not colr then

      --the only way to implement this in PGE atm is by saving then
      -- reading back a screenshot - completely impractical.
      --Using a 480x272 texture as a screen buffer could work,
      -- but obviously involves a heavy speed cost.

      --default return RED--
      local clr = {} ; setmetatable(clr,{__index=Color})
      --default return RED--
      clr.ctab = {r=255,g=0,b=0,a=255}                                            
      clr.PGEColor = System.SPXDF
      return clr
    else
      pge.gfx.drawrect(x,y,1,1,colr.PGEColor)
    end
    pge.gfx.enddrawing()
  end
  
  function screen:fillRect(x,y,width,height,color)
    pge.gfx.startdrawing()
    pge.gfx.rendertoscreen()
    pge.gfx.drawrect(x,y,width,height,color.PGEColor)
    pge.gfx.enddrawing()
  end
  
  function screen:drawLine(x0,y0,x1,y1,color)
    pge.gfx.startdrawing()
    pge.gfx.rendertoscreen()
    if x0==x1 and y0==y1 then
      pge.gfx.drawrect(x0,y0,1,1,color.PGEColor)
    else
      pge.gfx.drawline(x0,y0,x1,y1,color.PGEColor)
    end
    pge.gfx.enddrawing()
  end
  
  function screen:blit(x,y,imgS,srcx,srcy,width,height,alpha)
    System.imb = imgS.PGETexture
    System.argc = select("#",x,y,imgS,srcx,srcy,width,height,alpha)
    if System.argc<=4 then
      if System.argc==4 then alpha = srcx end
      srcx,srcy = 0,0
      width,height = System.imb:width(),System.imb:height()
    end
  
    if not srcx or type(srcx)~=System.NUMBER then srcx = 0 end
    if not srcy or type(srcy)~=System.NUMBER then srcy = 0 end
    if not width or type(width)~=System.NUMBER then
      width = System.imb:width()
    end
    if not height or type(height)~=System.NUMBER then
      height = System.imb:height()
    end                 
    collectgarbage("stop")
    pge.gfx.startdrawing()
    pge.gfx.rendertoscreen()
    System.imb:activate()
    System.imb:draw(x,y,width,height,srcx,srcy,srcx+width,srcy+height,0,255)
    pge.gfx.enddrawing()
    collectgarbage("restart") ; collectgarbage("step")
  end
  
  function screen:print(x,y,str,colr)
  --print string to screen using system bitmap font
    System.print(x,y,str,colr)
  end

  function screen:fontPrint(fnt,x,y,str,colr,bcolr)
    System.fontPrint(fnt,x,y,str,colr,bcolr)
  end

  function screen:save(filename) pge.gfx.screenshot(filename) end


--SOUND / MUSIC
  Sound =
  {
     --methods
     load,

     --properties
     PGEwav,
  }

  Voice =
  {
     --properties
     srcSound,
  }

  --methods

  Sound.load = function(fname,lp)
    if type(fname)~=System.STRING then return end
    if type(lp)~=System.BOOL then lp = false end

    local snd = {} ; setmetatable(snd,{__index=Sound})

    snd.PGEwav = pge.wav.load(fname)
    if snd.PGEwav and lp then pge.wav.loop(snd.PGEwav,true) end
    return snd
  end

  --metamethods

  function Sound:play()
    self.PGEwav:play()
    local vc = {} ; setmetatable(vc,{__index=Voice})
    vc.srcSound = self
    return vc
  end

  function Voice:stop()
    vc.srcSound.PGEwav:stop()
  end

  function Voice:volume(v)
    vc.srcSound.PGEwav:volume(math.floor(v/255))
  end

  function Voice:pan(p)
    vc.srcSound.PGEwav:volume(255-p,p)  
  end

  function Voice:frequency(f)
    vc.srcSound.PGEwav:pitch(f)
  end

  function Voice:playing()
    vc.srcSound.PGEwav:isplaying()
  end

  Music = {}
  Music.playFile = function(file,loop)
  --Plays a music in one of the following formats:
  -- UNI, IT, XM, S3M, MOD, MTM, STM, DSM, MED, FAR, ULT or 669.
  end
  Music.pause = function() end
  Music.resume = function() end
  Music.stop = function() end
  Music.playing = function() return false end
  Music.volume = function(v) return 0 end

  SoundSystem = {}
  SoundSystem.SFXVolume = function(v) end
  SoundSystem.reverb = function(r) end
  SoundSystem.panoramicSeparation = function(pS) end

--WLAN

  Wlan = {}

  Wlan.init = function() end
  Wlan.term = function() end
  Wlan.getConnectionConfigs = function() return{} end
  Wlan.useConnectionConfig = function(number) end
  Wlan.getIPAddress = function() return System.NEWSTR end

  Socket =
  {
     --methods
     connect,
  }
  Socket.connect = function(host,port)
  --Create a new TCP/IP Socket object and start
  -- the connection process to the specified host and port.
  -- All sockets are non-blocking.
    local skt = {} ; setmetatable(skt,{__index=Socket})
    return skt
  end

  --metamethods

  function Socket:isConnected() return false end
  function Socket:createServerSocket(port)
  --Creates a server socket, which listens on the specified
  -- port for incoming connections.
    local sck = self
    local ssk = {} ; setmetatable(ssk,{__index=Socket})
    return ssk
  end
  function Socket:accept() end
  function Socket:recv() return System.NEWSTR end
  function Socket:send(string) return 0 end
  function Socket:close() end

end--System.LP2PGE()--




--[[
*******************************************************************
*******************************************************************
THIS VERSION 1.0 by dangee October '08
A dangee.net production

DISCLAIMER
 Homebrew.
 no copyright, no guarantee, totally irresponsible of all
 consequences arising as from or out of users total freedom
 to reproduce, use at own risk copy destroy debug modify
 plagiarise or abuse unreasonable or otherwise and wheresofore
 delete as appropriate

Mods/BugFixes: Add to the Changelog below to claim co-disclaimancy.

*******************************************************************

ChangeLog
---------

VERSION 1.0: 4/10/08 by dangee file name: LP2PGE.LUA


*******************************************************************
]]--
